@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -50,43 +50,25 @@
  *
  */
 
-
 package org.mariadb.jdbc;
 
-import java.io.InputStream;
-import java.io.Reader;
-import java.math.BigDecimal;
-import java.net.URL;
-import java.sql.Array;
-import java.sql.Blob;
-import java.sql.CallableStatement;
-import java.sql.Clob;
+import org.mariadb.jdbc.internal.*;
+import org.mariadb.jdbc.internal.com.read.resultset.*;
+import org.mariadb.jdbc.internal.util.exceptions.*;
+
+import java.io.*;
+import java.math.*;
+import java.net.*;
 import java.sql.Date;
-import java.sql.NClob;
-import java.sql.ParameterMetaData;
-import java.sql.Ref;
-import java.sql.RowId;
-import java.sql.SQLException;
-import java.sql.SQLType;
-import java.sql.SQLXML;
-import java.sql.Statement;
-import java.sql.Time;
-import java.sql.Timestamp;
-import java.sql.Types;
-import java.util.Calendar;
-import java.util.List;
-import java.util.Map;
-import org.mariadb.jdbc.internal.ColumnType;
-import org.mariadb.jdbc.internal.com.read.resultset.SelectResultSet;
-import org.mariadb.jdbc.internal.util.exceptions.ExceptionMapper;
+import java.sql.*;
+import java.util.*;
 
-public abstract class CallableProcedureStatement extends MariaDbPreparedStatementServer implements
-    CallableStatement, Cloneable {
+public abstract class CallableProcedureStatement extends ServerSidePreparedStatement
+    implements CallableStatement, Cloneable {
 
-  /**
-   * Information about parameters, merely from registerOutputParameter() and setXXX() calls.
-   */
+  /** Information about parameters, merely from registerOutputParameter() and setXXX() calls. */
   protected List<CallParameter> params;
+
   protected int[] outputParameterMapper = null;
   protected CallableParameterMetaData parameterMetadata;
   protected boolean hasInOutParameters;
@@ -94,19 +76,17 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
   /**
    * Constructor for getter/setter of callableStatement.
    *
-   * @param connection           current connection
-   * @param sql                  query
-   * @param resultSetScrollType  one of the following <code>ResultSet</code> constants:
-   *                             <code>ResultSet.TYPE_FORWARD_ONLY</code>,
-   *                             <code>ResultSet.TYPE_SCROLL_INSENSITIVE</code>, or
-   *                             <code>ResultSet.TYPE_SCROLL_SENSITIVE</code>
+   * @param connection current connection
+   * @param sql query
+   * @param resultSetScrollType one of the following <code>ResultSet</code> constants: <code>
+   *     ResultSet.TYPE_FORWARD_ONLY</code>, <code>ResultSet.TYPE_SCROLL_INSENSITIVE</code>, or
+   *     <code>ResultSet.TYPE_SCROLL_SENSITIVE</code>
    * @param resultSetConcurrency a concurrency type; one of <code>ResultSet.CONCUR_READ_ONLY</code>
-   *                             or
-   *                             <code>ResultSet.CONCUR_UPDATABLE</code>
+   *     or <code>ResultSet.CONCUR_UPDATABLE</code>
    * @throws SQLException is prepareStatement connection throw any error
    */
-  public CallableProcedureStatement(MariaDbConnection connection, String sql,
-      int resultSetScrollType, int resultSetConcurrency)
+  public CallableProcedureStatement(
+      MariaDbConnection connection, String sql, int resultSetScrollType, int resultSetConcurrency)
       throws SQLException {
     super(connection, sql, resultSetScrollType, resultSetConcurrency, Statement.NO_GENERATED_KEYS);
   }
@@ -128,9 +108,7 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
     return clone;
   }
 
-  /**
-   * Set in/out parameters value.
-   */
+  /** Set in/out parameters value. */
   public void setParametersVariables() {
     hasInOutParameters = false;
     for (CallParameter param : params) {
@@ -166,7 +144,6 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
     throw new SQLException("there is no parameter with the name " + parameterName);
   }
 
-
   /**
    * Convert parameter name to output parameter index in the query.
    *
@@ -180,9 +157,11 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
       String name = parameterMetadata.getName(i + 1);
       if (name != null && name.equalsIgnoreCase(parameterName)) {
         if (outputParameterMapper[i] == -1) {
-          //this is not an outputParameter
-          throw new SQLException("Parameter '" + parameterName
-              + "' is not declared as output parameter with method registerOutParameter");
+          // this is not an outputParameter
+          throw new SQLException(
+              "Parameter '"
+                  + parameterName
+                  + "' is not declared as output parameter with method registerOutParameter");
         }
         return outputParameterMapper[i];
       }
@@ -200,17 +179,19 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
   private int indexToOutputIndex(int parameterIndex) throws SQLException {
     try {
       if (outputParameterMapper[parameterIndex - 1] == -1) {
-        //this is not an outputParameter
-        throw new SQLException("Parameter in index '" + parameterIndex
-            + "' is not declared as output parameter with method registerOutParameter");
+        // this is not an outputParameter
+        throw new SQLException(
+            "Parameter in index '"
+                + parameterIndex
+                + "' is not declared as output parameter with method registerOutParameter");
       }
       return outputParameterMapper[parameterIndex - 1];
     } catch (ArrayIndexOutOfBoundsException arrayIndexOutOfBoundsException) {
       if (parameterIndex < 1) {
         throw new SQLException("Index " + parameterIndex + " must at minimum be 1");
       }
-      throw new SQLException("Index value '" + parameterIndex
-          + "' is incorrect. Maximum value is " + params.size());
+      throw new SQLException(
+          "Index value '" + parameterIndex + "' is incorrect. Maximum value is " + params.size());
     }
   }
 
@@ -381,7 +362,6 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
     return getOutputResult().getTimestamp(nameToOutputIndex(parameterName));
   }
 
-
   @Override
   public Timestamp getTimestamp(String parameterName, Calendar cal) throws SQLException {
     return getOutputResult().getTimestamp(nameToOutputIndex(parameterName), cal);
@@ -394,8 +374,8 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
 
   @Override
   public Object getObject(int parameterIndex) throws SQLException {
-    Class<?> classType = ColumnType
-        .classFromJavaType(getParameter(parameterIndex).getOutputSqlType());
+    Class<?> classType =
+        ColumnType.classFromJavaType(getParameter(parameterIndex).getOutputSqlType());
     if (classType != null) {
       return getOutputResult().getObject(indexToOutputIndex(parameterIndex), classType);
     }
@@ -412,7 +392,6 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
     return getOutputResult().getObject(indexToOutputIndex(index));
   }
 
-
   @Override
   public Object getObject(String parameterName, Map<String, Class<?>> map) throws SQLException {
     return getOutputResult().getObject(nameToOutputIndex(parameterName), map);
@@ -478,7 +457,6 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
     return getOutputResult().getURL(nameToOutputIndex(parameterName));
   }
 
-
   @Override
   public RowId getRowId(int parameterIndex) throws SQLException {
     throw ExceptionMapper.getFeatureNotSupportedException("RowIDs not supported");
@@ -540,33 +518,31 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
   }
 
   /**
-   * <p>Registers the designated output parameter.
-   * This version of the method <code>registerOutParameter</code> should be used for a user-defined
-   * or <code>REF</code> output parameter.  Examples of user-defined types include:
-   * <code>STRUCT</code>, <code>DISTINCT</code>,
-   * <code>JAVA_OBJECT</code>, and named array types.</p>
-   * <p>All OUT parameters must be registered
-   * before a stored procedure is executed.</p>
-   * <p>  For a user-defined parameter, the fully-qualified SQL
-   * type name of the parameter should also be given, while a <code>REF</code> parameter requires
-   * that the fully-qualified type name of the referenced type be given.  A JDBC driver that does
-   * not need the type code and type name information may ignore it.   To be portable, however,
-   * applications should always provide these values for user-defined and <code>REF</code>
-   * parameters.</p>
-   * <p>Although it is intended for user-defined and <code>REF</code> parameters,
-   * this method may be used to register a parameter of any JDBC type. If the parameter does not
-   * have a user-defined or <code>REF</code> type, the
-   * <i>typeName</i> parameter is ignored.</p>
-   * <p><B>Note:</B> When reading the value of an out parameter, you
-   * must use the getter method whose Java type corresponds to the parameter's registered SQL
-   * type.</p>
+   * Registers the designated output parameter. This version of the method <code>
+   * registerOutParameter</code> should be used for a user-defined or <code>REF</code> output
+   * parameter. Examples of user-defined types include: <code>STRUCT</code>, <code>DISTINCT</code>,
+   * <code>JAVA_OBJECT</code>, and named array types.
+   *
+   * <p>All OUT parameters must be registered before a stored procedure is executed.
+   *
+   * <p>For a user-defined parameter, the fully-qualified SQL type name of the parameter should also
+   * be given, while a <code>REF</code> parameter requires that the fully-qualified type name of the
+   * referenced type be given. A JDBC driver that does not need the type code and type name
+   * information may ignore it. To be portable, however, applications should always provide these
+   * values for user-defined and <code>REF</code> parameters.
+   *
+   * <p>Although it is intended for user-defined and <code>REF</code> parameters, this method may be
+   * used to register a parameter of any JDBC type. If the parameter does not have a user-defined or
+   * <code>REF</code> type, the <i>typeName</i> parameter is ignored.
+   *
+   * <p><B>Note:</B> When reading the value of an out parameter, you must use the getter method
+   * whose Java type corresponds to the parameter's registered SQL type.
    *
    * @param parameterIndex the first parameter is 1, the second is 2,...
-   * @param sqlType        a value from {@link Types}
-   * @param typeName       the fully-qualified name of an SQL structured type
-   * @throws SQLException                    if the parameterIndex is not valid; if a database
-   *                                         access error occurs or this method is called on a
-   *                                         closed <code>CallableStatement</code>
+   * @param sqlType a value from {@link Types}
+   * @param typeName the fully-qualified name of an SQL structured type
+   * @throws SQLException if the parameterIndex is not valid; if a database access error occurs or
+   *     this method is called on a closed <code>CallableStatement</code>
    * @see Types
    */
   public void registerOutParameter(int parameterIndex, int sqlType, String typeName)
@@ -583,23 +559,22 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
   }
 
   /**
-   * <p>Registers the parameter in ordinal position
-   * <code>parameterIndex</code> to be of JDBC type
-   * <code>sqlType</code>. All OUT parameters must be registered
-   * before a stored procedure is executed.</p>
-   * <p>The JDBC type specified by <code>sqlType</code> for an OUT
-   * parameter determines the Java type that must be used in the <code>get</code> method to read the
-   * value of that parameter.</p>
-   * <p>This version of <code>registerOutParameter</code> should be
-   * used when the parameter is of JDBC type <code>NUMERIC</code> or <code>DECIMAL</code>.</p>
+   * Registers the parameter in ordinal position <code>parameterIndex</code> to be of JDBC type
+   * <code>sqlType</code>. All OUT parameters must be registered before a stored procedure is
+   * executed.
+   *
+   * <p>The JDBC type specified by <code>sqlType</code> for an OUT parameter determines the Java
+   * type that must be used in the <code>get</code> method to read the value of that parameter.
+   *
+   * <p>This version of <code>registerOutParameter</code> should be used when the parameter is of
+   * JDBC type <code>NUMERIC</code> or <code>DECIMAL</code>.
    *
    * @param parameterIndex the first parameter is 1, the second is 2, and so on
-   * @param sqlType        the SQL type code defined by <code>java.sql.Types</code>.
-   * @param scale          the desired number of digits to the right of the decimal point.  It must
-   *                       be greater than or equal to zero.
-   * @throws SQLException                    if the parameterIndex is not valid; if a database
-   *                                         access error occurs or this method is called on a
-   *                                         closed <code>CallableStatement</code>
+   * @param sqlType the SQL type code defined by <code>java.sql.Types</code>.
+   * @param scale the desired number of digits to the right of the decimal point. It must be greater
+   *     than or equal to zero.
+   * @throws SQLException if the parameterIndex is not valid; if a database access error occurs or
+   *     this method is called on a closed <code>CallableStatement</code>
    * @see Types
    */
   @Override
@@ -621,14 +596,12 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
     registerOutParameter(nameToIndex(parameterName), sqlType, scale);
   }
 
-
   @Override
   public void registerOutParameter(String parameterName, int sqlType, String typeName)
       throws SQLException {
     registerOutParameter(nameToIndex(parameterName), sqlType, typeName);
   }
 
-
   @Override
   public void registerOutParameter(int parameterIndex, SQLType sqlType) throws SQLException {
     registerOutParameter(parameterIndex, sqlType.getVendorTypeNumber());
@@ -765,7 +738,6 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
     setBinaryStream(nameToIndex(parameterName), inputStream, length);
   }
 
-
   @Override
   public void setBinaryStream(String parameterName, InputStream inputStream) throws SQLException {
     setBinaryStream(nameToIndex(parameterName), inputStream);
@@ -812,7 +784,6 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
   @Override
   public void setBoolean(String parameterName, boolean booleanValue) throws SQLException {
     setBoolean(nameToIndex(parameterName), booleanValue);
-
   }
 
   @Override
@@ -891,7 +862,6 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
     setTimestamp(nameToIndex(parameterName), timestamp, cal);
   }
 
-
   @Override
   public void setObject(String parameterName, Object obj, int targetSqlType, int scale)
       throws SQLException {
@@ -919,5 +889,4 @@ public abstract class CallableProcedureStatement extends MariaDbPreparedStatemen
       throws SQLException {
     setObject(nameToIndex(parameterName), obj, targetSqlType.getVendorTypeNumber());
   }
-
 }
