@@ -1,10 +1,9 @@
-
 /*
  *
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -53,27 +52,19 @@
 
 package org.mariadb.jdbc;
 
-import java.sql.ParameterMetaData;
-import java.sql.ResultSet;
-import java.sql.ResultSetMetaData;
-import java.sql.SQLException;
-import java.sql.SQLSyntaxErrorException;
-import java.sql.Statement;
-import java.util.ArrayList;
-import java.util.List;
-import org.mariadb.jdbc.internal.com.read.dao.Results;
-import org.mariadb.jdbc.internal.com.read.resultset.SelectResultSet;
-import org.mariadb.jdbc.internal.com.send.parameters.ParameterHolder;
-import org.mariadb.jdbc.internal.logging.Logger;
-import org.mariadb.jdbc.internal.logging.LoggerFactory;
-import org.mariadb.jdbc.internal.util.dao.ClientPrepareResult;
-import org.mariadb.jdbc.internal.util.exceptions.ExceptionMapper;
+import org.mariadb.jdbc.internal.com.read.dao.*;
+import org.mariadb.jdbc.internal.com.read.resultset.*;
+import org.mariadb.jdbc.internal.com.send.parameters.*;
+import org.mariadb.jdbc.internal.logging.*;
+import org.mariadb.jdbc.internal.util.dao.*;
+import org.mariadb.jdbc.internal.util.exceptions.*;
 
+import java.sql.*;
+import java.util.*;
 
 public class ClientSidePreparedStatement extends BasePrepareStatement {
 
-  private static final Logger logger = LoggerFactory
-      .getLogger(ClientSidePreparedStatement.class);
+  private static final Logger logger = LoggerFactory.getLogger(ClientSidePreparedStatement.class);
   private final List<ParameterHolder[]> parameterList = new ArrayList<>();
   private ClientPrepareResult prepareResult;
   private String sqlQuery;
@@ -84,30 +75,29 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
   /**
    * Constructor.
    *
-   * @param connection           connection
-   * @param sql                  sql query
-   * @param resultSetScrollType  one of the following <code>ResultSet</code> constants:
-   *                             <code>ResultSet.TYPE_FORWARD_ONLY</code>,
-   *                             <code>ResultSet.TYPE_SCROLL_INSENSITIVE</code>, or
-   *                             <code>ResultSet.TYPE_SCROLL_SENSITIVE</code>
+   * @param connection connection
+   * @param sql sql query
+   * @param resultSetScrollType one of the following <code>ResultSet</code> constants: <code>
+   *     ResultSet.TYPE_FORWARD_ONLY</code>, <code>ResultSet.TYPE_SCROLL_INSENSITIVE</code>, or
+   *     <code>ResultSet.TYPE_SCROLL_SENSITIVE</code>
    * @param resultSetConcurrency a concurrency type; one of <code>ResultSet.CONCUR_READ_ONLY</code>
-   *                             or
-   *                             <code>ResultSet.CONCUR_UPDATABLE</code>
-   * @param autoGeneratedKeys    a flag indicating whether auto-generated keys should be returned;
-   *                             one of
-   *                             <code>Statement.RETURN_GENERATED_KEYS</code>
-   *                             or <code>Statement.NO_GENERATED_KEYS</code>
+   *     or <code>ResultSet.CONCUR_UPDATABLE</code>
+   * @param autoGeneratedKeys a flag indicating whether auto-generated keys should be returned; one
+   *     of <code>Statement.RETURN_GENERATED_KEYS</code> or <code>Statement.NO_GENERATED_KEYS</code>
    * @throws SQLException exception
    */
-  public ClientSidePreparedStatement(MariaDbConnection connection, String sql,
+  public ClientSidePreparedStatement(
+      MariaDbConnection connection,
+      String sql,
       int resultSetScrollType,
-      int resultSetConcurrency, int autoGeneratedKeys) throws SQLException {
+      int resultSetConcurrency,
+      int autoGeneratedKeys)
+      throws SQLException {
     super(connection, resultSetScrollType, resultSetConcurrency, autoGeneratedKeys);
     sqlQuery = sql;
 
     if (options.rewriteBatchedStatements) {
-      prepareResult = ClientPrepareResult
-          .rewritableParts(sqlQuery, protocol.noBackslashEscapes());
+      prepareResult = ClientPrepareResult.rewritableParts(sqlQuery, protocol.noBackslashEscapes());
     } else {
       prepareResult = ClientPrepareResult.parameterParts(sqlQuery, protocol.noBackslashEscapes());
     }
@@ -136,18 +126,16 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
    * Executes the SQL statement in this <code>PreparedStatement</code> object, which may be any kind
    * of SQL statement. Some prepared statements return multiple results; the <code>execute</code>
    * method handles these complex statements as well as the simpler form of statements handled by
-   * the methods <code>executeQuery</code> and <code>executeUpdate</code>.
-   * <br>
+   * the methods <code>executeQuery</code> and <code>executeUpdate</code>. <br>
    * The <code>execute</code> method returns a <code>boolean</code> to indicate the form of the
-   * first result.  You must call either the method
-   * <code>getResultSet</code> or <code>getUpdateCount</code>
-   * to retrieve the result; you must call <code>getInternalMoreResults</code> to move to any
-   * subsequent result(s).
+   * first result. You must call either the method <code>getResultSet</code> or <code>getUpdateCount
+   * </code> to retrieve the result; you must call <code>getInternalMoreResults</code> to move to
+   * any subsequent result(s).
    *
-   * @return <code>true</code> if the first result is a <code>ResultSet</code>
-   *     object; <code>false</code> if the first result is an update count or there is no result
+   * @return <code>true</code> if the first result is a <code>ResultSet</code> object; <code>false
+   *     </code> if the first result is an update count or there is no result
    * @throws SQLException if a database access error occurs; this method is called on a closed
-   *                      <code>PreparedStatement</code> or an argument is supplied to this method
+   *     <code>PreparedStatement</code> or an argument is supplied to this method
    * @see Statement#execute
    * @see Statement#getResultSet
    * @see Statement#getUpdateCount
@@ -158,15 +146,14 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
   }
 
   /**
-   * Executes the SQL query in this <code>PreparedStatement</code> object and returns the
-   * <code>ResultSet</code> object generated by the query.
+   * Executes the SQL query in this <code>PreparedStatement</code> object and returns the <code>
+   * ResultSet</code> object generated by the query.
    *
    * @return a <code>ResultSet</code> object that contains the data produced by the query; never
-   * <code>null</code>
+   *     <code>null</code>
    * @throws SQLException if a database access error occurs; this method is called on a closed
-   *                      <code>PreparedStatement</code> or the SQL statement does not return a
-   *                      <code>ResultSet</code>
-   *                      object
+   *     <code>PreparedStatement</code> or the SQL statement does not return a <code>ResultSet
+   *     </code> object
    */
   public ResultSet executeQuery() throws SQLException {
     if (execute()) {
@@ -175,18 +162,15 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     return SelectResultSet.createEmptyResultSet();
   }
 
-
   /**
    * Executes the SQL statement in this <code>PreparedStatement</code> object, which must be an SQL
-   * Data Manipulation Language (DML) statement, such as <code>INSERT</code>, <code>UPDATE</code>
-   * or
+   * Data Manipulation Language (DML) statement, such as <code>INSERT</code>, <code>UPDATE</code> or
    * <code>DELETE</code>; or an SQL statement that returns nothing, such as a DDL statement.
    *
    * @return either (1) the row count for SQL Data Manipulation Language (DML) statements or (2) 0
    *     for SQL statements that return nothing
    * @throws SQLException if a database access error occurs; this method is called on a closed
-   *                      <code>PreparedStatement</code> or the SQL statement returns a
-   *                      <code>ResultSet</code> object
+   *     <code>PreparedStatement</code> or the SQL statement returns a <code>ResultSet</code> object
    */
   public int executeUpdate() throws SQLException {
     if (execute()) {
@@ -197,26 +181,37 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
 
   protected boolean executeInternal(int fetchSize) throws SQLException {
 
-    //valid parameters
+    // valid parameters
     for (int i = 0; i < prepareResult.getParamCount(); i++) {
       if (parameters[i] == null) {
         logger.error("Parameter at position {} is not set", (i + 1));
         ExceptionMapper.throwException(
             new SQLException("Parameter at position " + (i + 1) + " is not set", "07004"),
-            connection, this);
+            connection,
+            this);
       }
     }
 
     lock.lock();
     try {
       executeQueryPrologue(false);
-      results = new Results(this, fetchSize, false, 1, false, resultSetScrollType,
-          resultSetConcurrency, autoGeneratedKeys,
-          protocol.getAutoIncrementIncrement(), sqlQuery, parameters);
+      results =
+          new Results(
+              this,
+              fetchSize,
+              false,
+              1,
+              false,
+              resultSetScrollType,
+              resultSetConcurrency,
+              autoGeneratedKeys,
+              protocol.getAutoIncrementIncrement(),
+              sqlQuery,
+              parameters);
       if (queryTimeout != 0 && canUseServerTimeout) {
-        //timer will not be used for timeout to avoid having threads
-        protocol.executeQuery(protocol.isMasterConnection(), results, prepareResult, parameters,
-            queryTimeout);
+        // timer will not be used for timeout to avoid having threads
+        protocol.executeQuery(
+            protocol.isMasterConnection(), results, prepareResult, parameters, queryTimeout);
       } else {
         protocol.executeQuery(protocol.isMasterConnection(), results, prepareResult, parameters);
       }
@@ -232,16 +227,14 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
       executeEpilogue();
       lock.unlock();
     }
-
   }
 
   /**
-   * Adds a set of parameters to this <code>PreparedStatement</code> object's batch of send.
-   * <br>
+   * Adds a set of parameters to this <code>PreparedStatement</code> object's batch of send. <br>
    * <br>
    *
    * @throws SQLException if a database access error occurs or this method is called on a closed
-   *                      <code>PreparedStatement</code>
+   *     <code>PreparedStatement</code>
    * @see Statement#addBatch
    * @since 1.2
    */
@@ -250,10 +243,13 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     for (int i = 0; i < holder.length; i++) {
       holder[i] = parameters[i];
       if (holder[i] == null) {
-        logger.error("You need to set exactly " + prepareResult.getParamCount()
-            + " parameters on the prepared statement");
-        throw ExceptionMapper
-            .getSqlException("You need to set exactly " + prepareResult.getParamCount()
+        logger.error(
+            "You need to set exactly "
+                + prepareResult.getParamCount()
+                + " parameters on the prepared statement");
+        throw ExceptionMapper.getSqlException(
+            "You need to set exactly "
+                + prepareResult.getParamCount()
                 + " parameters on the prepared statement");
       }
     }
@@ -271,9 +267,7 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     throw new SQLException("Cannot do addBatch(String) on preparedStatement");
   }
 
-  /**
-   * Clear batch.
-   */
+  /** Clear batch. */
   @Override
   public void clearBatch() {
     parameterList.clear();
@@ -281,9 +275,7 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     this.parameters = new ParameterHolder[prepareResult.getParamCount()];
   }
 
-  /**
-   * {inheritdoc}.
-   */
+  /** {inheritdoc}. */
   public int[] executeBatch() throws SQLException {
     checkClose();
     int size = parameterList.size();
@@ -354,22 +346,35 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
    */
   private void executeInternalBatch(int size) throws SQLException {
     executeQueryPrologue(true);
-    results = new Results(this, 0, true, size, false, resultSetScrollType,
-            resultSetConcurrency, autoGeneratedKeys, protocol.getAutoIncrementIncrement(), null, null);
-    if (protocol
-        .executeBatchClient(protocol.isMasterConnection(), results, prepareResult, parameterList,
-            hasLongData)) {
+    results =
+        new Results(
+            this,
+            0,
+            true,
+            size,
+            false,
+            resultSetScrollType,
+            resultSetConcurrency,
+            autoGeneratedKeys,
+            protocol.getAutoIncrementIncrement(),
+            null,
+            null);
+    if (protocol.executeBatchClient(
+        protocol.isMasterConnection(), results, prepareResult, parameterList, hasLongData)) {
       return;
     }
 
-    //send query one by one, reading results for each query before sending another one
+    // send query one by one, reading results for each query before sending another one
     SQLException exception = null;
 
     if (queryTimeout > 0) {
       for (int batchQueriesCount = 0; batchQueriesCount < size; batchQueriesCount++) {
         protocol.stopIfInterrupted();
         try {
-          protocol.executeQuery(protocol.isMasterConnection(), results, prepareResult,
+          protocol.executeQuery(
+              protocol.isMasterConnection(),
+              results,
+              prepareResult,
               parameterList.get(batchQueriesCount));
         } catch (SQLException e) {
           if (options.continueBatchOnError) {
@@ -383,7 +388,10 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     } else {
       for (int batchQueriesCount = 0; batchQueriesCount < size; batchQueriesCount++) {
         try {
-          protocol.executeQuery(protocol.isMasterConnection(), results, prepareResult,
+          protocol.executeQuery(
+              protocol.isMasterConnection(),
+              results,
+              prepareResult,
               parameterList.get(batchQueriesCount));
         } catch (SQLException e) {
           if (options.continueBatchOnError) {
@@ -397,28 +405,22 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     if (exception != null) {
       throw exception;
     }
-
   }
 
   /**
    * Retrieves a <code>ResultSetMetaData</code> object that contains information about the columns
-   * of the
-   * <code>ResultSet</code> object that will be returned when this <code>PreparedStatement</code>
-   * object is executed.
-   * <br>
+   * of the <code>ResultSet</code> object that will be returned when this <code>PreparedStatement
+   * </code> object is executed. <br>
    * Because a <code>PreparedStatement</code> object is precompiled, it is possible to know about
-   * the
-   * <code>ResultSet</code> object that it will return without having to execute it.  Consequently,
-   * it is possible to invoke the method <code>getMetaData</code> on a
-   * <code>PreparedStatement</code> object rather than waiting to execute it and then invoking the
-   * <code>ResultSet.getMetaData</code> method on the <code>ResultSet</code> object that is
-   * returned.
+   * the <code>ResultSet</code> object that it will return without having to execute it.
+   * Consequently, it is possible to invoke the method <code>getMetaData</code> on a <code>
+   * PreparedStatement</code> object rather than waiting to execute it and then invoking the <code>
+   * ResultSet.getMetaData</code> method on the <code>ResultSet</code> object that is returned.
    *
    * @return the description of a <code>ResultSet</code> object's columns or <code>null</code> if
    *     the driver cannot return a <code>ResultSetMetaData</code> object
-   * @throws SQLException                    if a database access error occurs or this method is
-   *                                         called on a closed
-   *                                         <code>PreparedStatement</code>
+   * @throws SQLException if a database access error occurs or this method is called on a closed
+   *     <code>PreparedStatement</code>
    */
   public ResultSetMetaData getMetaData() throws SQLException {
     checkClose();
@@ -436,7 +438,7 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
    * Set parameter.
    *
    * @param parameterIndex index
-   * @param holder         parameter holder
+   * @param holder parameter holder
    * @throws SQLException if index position doesn't correspond to query parameters
    */
   public void setParameter(final int parameterIndex, final ParameterHolder holder)
@@ -444,10 +446,17 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     if (parameterIndex >= 1 && parameterIndex < prepareResult.getParamCount() + 1) {
       parameters[parameterIndex - 1] = holder;
     } else {
-      String error = "Could not set parameter at position " + parameterIndex
-          + " (values was " + holder.toString() + ")\n"
-          + "Query - conn:" + protocol.getServerThreadId()
-          + "(" + (protocol.isMasterConnection() ? "M" : "S") + ") ";
+      String error =
+          "Could not set parameter at position "
+              + parameterIndex
+              + " (values was "
+              + holder.toString()
+              + ")\n"
+              + "Query - conn:"
+              + protocol.getServerThreadId()
+              + "("
+              + (protocol.isMasterConnection() ? "M" : "S")
+              + ") ";
 
       if (options.maxQuerySizeToLog > 0) {
         error += " - \"";
@@ -466,15 +475,15 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     }
   }
 
-
   /**
    * Retrieves the number, types and properties of this <code>PreparedStatement</code> object's
    * parameters.
    *
    * @return a <code>ParameterMetaData</code> object that contains information about the number,
-   *     types and properties for each parameter marker of this <code>PreparedStatement</code> object
+   *     types and properties for each parameter marker of this <code>PreparedStatement</code>
+   *     object
    * @throws SQLException if a database access error occurs or this method is called on a closed
-   *                      <code>PreparedStatement</code>
+   *     <code>PreparedStatement</code>
    * @see ParameterMetaData
    * @since 1.4
    */
@@ -487,40 +496,41 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
   }
 
   private void loadParametersData() throws SQLSyntaxErrorException {
-    try (ServerSidePreparedStatement ssps = new ServerSidePreparedStatement(connection,
-        sqlQuery,
-        ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY,
-        Statement.NO_GENERATED_KEYS)) {
+    try (ServerSidePreparedStatement ssps =
+        new ServerSidePreparedStatement(
+            connection,
+            sqlQuery,
+            ResultSet.TYPE_SCROLL_INSENSITIVE,
+            ResultSet.CONCUR_READ_ONLY,
+            Statement.NO_GENERATED_KEYS)) {
       resultSetMetaData = ssps.getMetaData();
       parameterMetaData = ssps.getParameterMetaData();
     } catch (SQLSyntaxErrorException sqlSyntaxErrorException) {
-      //if error is due to wrong SQL syntax, better to throw exception immediately
+      // if error is due to wrong SQL syntax, better to throw exception immediately
       throw sqlSyntaxErrorException;
     } catch (SQLException sqle) {
       parameterMetaData = new MariaDbParameterMetaData(null);
     }
   }
 
-
   /**
    * Clears the current parameter values immediately.
    *
-   * <P>In general, parameter values remain in
-   * force for repeated use of a statement. Setting a parameter value automatically clears its
-   * previous value.  However, in some cases it is useful to immediately release the resources used
-   * by the current parameter values; this can be done by calling the method
-   * <code>clearParameters</code>.</p>
+   * <p>In general, parameter values remain in force for repeated use of a statement. Setting a
+   * parameter value automatically clears its previous value. However, in some cases it is useful to
+   * immediately release the resources used by the current parameter values; this can be done by
+   * calling the method <code>clearParameters</code>.
    */
   public void clearParameters() {
     parameters = new ParameterHolder[prepareResult.getParamCount()];
   }
 
-
   // Close prepared statement, maybe fire closed-statement events
   @Override
   public void close() throws SQLException {
     super.close();
-    if (connection == null || connection.pooledConnection == null
+    if (connection == null
+        || connection.pooledConnection == null
         || connection.pooledConnection.noStmtEventListeners()) {
       return;
     }
@@ -532,9 +542,7 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     return prepareResult.getParamCount();
   }
 
-  /**
-   * {inherit}.
-   */
+  /** {inherit}. */
   @Override
   public String toString() {
     StringBuilder sb = new StringBuilder("sql : '" + sqlQuery + "'");
@@ -554,9 +562,7 @@ public class ClientSidePreparedStatement extends BasePrepareStatement {
     return sb.toString();
   }
 
-
   protected ClientPrepareResult getPrepareResult() {
     return prepareResult;
   }
-
 }
