@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -20,30 +20,21 @@
  *
  */
 
-
 package org.mariadb.jdbc;
 
-import java.io.Closeable;
-import java.io.PrintWriter;
-import java.sql.Connection;
-import java.sql.SQLException;
-import java.sql.SQLFeatureNotSupportedException;
-import java.util.Collections;
-import java.util.List;
-import java.util.Properties;
-import java.util.logging.Logger;
-import javax.sql.DataSource;
-import javax.sql.XAConnection;
-import javax.sql.XADataSource;
-import org.mariadb.jdbc.internal.util.DefaultOptions;
-import org.mariadb.jdbc.internal.util.Options;
-import org.mariadb.jdbc.internal.util.constant.HaMode;
-import org.mariadb.jdbc.internal.util.exceptions.ExceptionMapper;
-import org.mariadb.jdbc.internal.util.pool.Pool;
-import org.mariadb.jdbc.internal.util.pool.Pools;
+import org.mariadb.jdbc.internal.util.constant.*;
+import org.mariadb.jdbc.internal.util.exceptions.*;
+import org.mariadb.jdbc.internal.util.pool.*;
+import org.mariadb.jdbc.util.*;
 
+import javax.sql.*;
+import java.io.*;
+import java.sql.*;
+import java.util.*;
+import java.util.logging.*;
 
-public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeable, AutoCloseable {
+public class MariaDbPoolDataSource
+    implements ConnectionPoolDataSource, DataSource, XADataSource, Closeable, AutoCloseable {
 
   private UrlParser urlParser;
   private Pool pool;
@@ -66,7 +57,7 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
    * Constructor.
    *
    * @param hostname hostname (ipv4, ipv6, dns name)
-   * @param port     server port
+   * @param port server port
    * @param database database name
    */
   public MariaDbPoolDataSource(String hostname, int port, String database) {
@@ -79,12 +70,8 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
     this.url = url;
   }
 
-  /**
-   * Default constructor. hostname will be localhost, port 3306.
-   */
-  public MariaDbPoolDataSource() {
-
-  }
+  /** Default constructor. hostname will be localhost, port 3306. */
+  public MariaDbPoolDataSource() {}
 
   /**
    * Gets the name of the database.
@@ -224,7 +211,7 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
    *
    * @param serverName the server name
    * @throws SQLException if error in URL
-   **/
+   */
   public void setServerName(String serverName) throws SQLException {
     checkNotInitialized();
     hostname = serverName;
@@ -268,15 +255,17 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
         return pool.getConnection();
       }
 
-      if ((urlParser.getUsername() != null ? urlParser.getUsername().equals(username)
-          : username == null)
-          && (urlParser.getPassword() != null ? urlParser.getPassword().equals(password)
-          : (password == null || password.isEmpty()))) {
+      if ((urlParser.getUsername() != null
+              ? urlParser.getUsername().equals(username)
+              : username == null)
+          && (urlParser.getPassword() != null
+              ? urlParser.getPassword().equals(password)
+              : (password == null || password.isEmpty()))) {
         return pool.getConnection();
       }
 
-      //username / password are different from the one already used to initialize pool
-      //-> return a real new connection.
+      // username / password are different from the one already used to initialize pool
+      // -> return a real new connection.
 
       UrlParser urlParser = (UrlParser) this.urlParser.clone();
       urlParser.setUsername(username);
@@ -290,17 +279,42 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
     }
   }
 
+  /**
+   * Attempts to establish a physical database connection that can be used as a pooled connection.
+   *
+   * @return a <code>PooledConnection</code> object that is a physical connection to the database
+   *     that this <code>ConnectionPoolDataSource</code> object represents
+   * @throws SQLException if a database access error occurs if the JDBC driver does not support this
+   *     method
+   */
+  public PooledConnection getPooledConnection() throws SQLException {
+    return new MariaDbPooledConnection((MariaDbConnection) getConnection());
+  }
+
+  /**
+   * Attempts to establish a physical database connection that can be used as a pooled connection.
+   *
+   * @param user the database user on whose behalf the connection is being made
+   * @param password the user's password
+   * @return a <code>PooledConnection</code> object that is a physical connection to the database
+   *     that this <code>ConnectionPoolDataSource</code> object represents
+   * @throws SQLException if a database access error occurs
+   */
+  public PooledConnection getPooledConnection(String user, String password) throws SQLException {
+    return new MariaDbPooledConnection((MariaDbConnection) getConnection(user, password));
+  }
+
   /**
    * Retrieves the log writer for this <code>DataSource</code> object.
    *
    * <p>The log writer is a character output stream to which all logging and tracing messages for
-   * this data source will be printed.  This includes messages printed by the methods of this
-   * object, messages printed by methods of other objects manufactured by this object, and so on.
-   * Messages printed to a data source specific log writer are not printed to the log writer
-   * associated with the <code>java.sql.DriverManager</code> class.</p>
+   * this data source will be printed. This includes messages printed by the methods of this object,
+   * messages printed by methods of other objects manufactured by this object, and so on. Messages
+   * printed to a data source specific log writer are not printed to the log writer associated with
+   * the <code>java.sql.DriverManager</code> class.
    *
-   * <p>When a <code>DataSource</code> object is created, the log writer is initially null; in other words,
-   * the default is for logging to be disabled.</p>
+   * <p>When a <code>DataSource</code> object is created, the log writer is initially null; in other
+   * words, the default is for logging to be disabled.
    *
    * @return the log writer for this data source or null if logging is disabled
    * @see #setLogWriter
@@ -310,28 +324,27 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
   }
 
   /**
-   * Sets the log writer for this <code>DataSource</code> object to the given
-   * <code>java.io.PrintWriter</code> object.
+   * Sets the log writer for this <code>DataSource</code> object to the given <code>
+   * java.io.PrintWriter</code> object.
    *
-   * <p>The log writer is a character output stream to which all logging and tracing messages for this
-   * data source will be printed.  This includes messages printed by the methods of this object,
-   * messages printed by methods of other objects manufactured by this object, and so on.  Messages
+   * <p>The log writer is a character output stream to which all logging and tracing messages for
+   * this data source will be printed. This includes messages printed by the methods of this object,
+   * messages printed by methods of other objects manufactured by this object, and so on. Messages
    * printed to a data source- specific log writer are not printed to the log writer associated with
-   * the <code>java.sql.DriverManager</code> class. When a
-   * <code>DataSource</code> object is created the log writer is initially null; in other words,
-   * the default is for logging to be disabled.</p>
+   * the <code>java.sql.DriverManager</code> class. When a <code>DataSource</code> object is created
+   * the log writer is initially null; in other words, the default is for logging to be disabled.
    *
    * @param out the new log writer; to disable logging, set to null
    * @see #getLogWriter
    * @since 1.4
    */
   public void setLogWriter(final PrintWriter out) {
-    //not implemented
+    // not implemented
   }
 
   /**
    * Gets the maximum time in seconds that this data source can wait while attempting to connect to
-   * a database.  A value of zero means that the timeout is the default system timeout if there is
+   * a database. A value of zero means that the timeout is the default system timeout if there is
    * one; otherwise, it means that there is no timeout. When a <code>DataSource</code> object is
    * created, the login timeout is initially zero.
    *
@@ -348,7 +361,7 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
 
   /**
    * Sets the maximum time in seconds that this data source will wait while attempting to connect to
-   * a database.  A value of zero specifies that the timeout is the default system timeout if there
+   * a database. A value of zero specifies that the timeout is the default system timeout if there
    * is one; otherwise, it specifies that there is no timeout. When a <code>DataSource</code> object
    * is created, the login timeout is initially zero.
    *
@@ -371,8 +384,8 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
    * receiver. If the receiver is a wrapper and the wrapped object implements the interface then the
    * result is the wrapped object or a proxy for the wrapped object. Otherwise return the the result
    * of calling <code>unwrap</code> recursively on the wrapped object or a proxy for that result. If
-   * the receiver is not a wrapper and does not implement the interface, then an
-   * <code>SQLException</code> is thrown.</p>
+   * the receiver is not a wrapper and does not implement the interface, then an <code>SQLException
+   * </code> is thrown.
    *
    * @param iface A Class defining an interface that the result must implement.
    * @return an object that implements the interface. May be a proxy for the actual implementing
@@ -396,19 +409,18 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
   /**
    * Returns true if this either implements the interface argument or is directly or indirectly a
    * wrapper for an object that does. Returns false otherwise. If this implements the interface then
-   * return true, else if this is a wrapper then return the result of recursively calling
-   * <code>isWrapperFor</code> on the wrapped object. If this does not implement the interface and
-   * is not a wrapper, return false. This method should be implemented as a low-cost operation
-   * compared to <code>unwrap</code> so that callers can use this method to avoid expensive
-   * <code>unwrap</code> calls that may fail. If this method returns true then calling
-   * <code>unwrap</code> with the
-   * same argument should succeed.
+   * return true, else if this is a wrapper then return the result of recursively calling <code>
+   * isWrapperFor</code> on the wrapped object. If this does not implement the interface and is not
+   * a wrapper, return false. This method should be implemented as a low-cost operation compared to
+   * <code>unwrap</code> so that callers can use this method to avoid expensive <code>unwrap</code>
+   * calls that may fail. If this method returns true then calling <code>unwrap</code> with the same
+   * argument should succeed.
    *
    * @param interfaceOrWrapper a Class defining an interface.
    * @return true if this implements the interface or directly or indirectly wraps an object that
    *     does.
    * @throws SQLException if an error occurs while determining whether this is a wrapper for an
-   *                      object with the given interface.
+   *     object with the given interface.
    * @since 1.6
    */
   public boolean isWrapperFor(final Class<?> interfaceOrWrapper) throws SQLException {
@@ -465,8 +477,8 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
   }
 
   /**
-   * Get minimum pool size (pool will grow at creation untile reaching this size).
-   * Null mean use the pool maximum pool size.
+   * Get minimum pool size (pool will grow at creation untile reaching this size). Null mean use the
+   * pool maximum pool size.
    *
    * @return current value.
    */
@@ -590,26 +602,26 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
         options.poolValidMinDelay = poolValidMinDelay;
       }
 
-      urlParser = new UrlParser(database,
-          Collections.singletonList(
-              new HostAddress(
-                  (hostname == null || hostname.isEmpty()) ? "localhost" : hostname,
-                  port == null ? 3306 : port)),
-          options,
-          HaMode.NONE);
+      urlParser =
+          new UrlParser(
+              database,
+              Collections.singletonList(
+                  new HostAddress(
+                      (hostname == null || hostname.isEmpty()) ? "localhost" : hostname,
+                      port == null ? 3306 : port)),
+              options,
+              HaMode.NONE);
     }
   }
 
-  /**
-   * Close datasource.
-   */
+  /** Close datasource. */
   public void close() {
     try {
       if (pool != null) {
         pool.close();
       }
     } catch (InterruptedException interrupted) {
-      //eat
+      // eat
     }
   }
 
@@ -655,5 +667,4 @@ public class MariaDbPoolDataSource implements DataSource, XADataSource, Closeabl
   public Pool testGetPool() {
     return pool;
   }
-
 }
