@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,48 +52,52 @@
 
 package org.mariadb.jdbc;
 
-import java.sql.SQLException;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Locale;
-import java.util.Properties;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-import org.mariadb.jdbc.internal.logging.LoggerFactory;
-import org.mariadb.jdbc.internal.util.DefaultOptions;
-import org.mariadb.jdbc.internal.util.Options;
-import org.mariadb.jdbc.internal.util.constant.HaMode;
-import org.mariadb.jdbc.internal.util.constant.ParameterConstant;
+import org.mariadb.jdbc.credential.*;
+import org.mariadb.jdbc.internal.logging.*;
+import org.mariadb.jdbc.internal.util.constant.*;
+import org.mariadb.jdbc.util.*;
+
+import java.sql.*;
+import java.util.*;
+import java.util.regex.*;
 
 /**
- * <p>parse and verification of URL.</p>
+ * parse and verification of URL.
+ *
  * <p>basic syntax :<br>
- * {@code jdbc:(mysql|mariadb):[replication:|failover|loadbalance:|aurora:]//<hostDescription>[,<hostDescription>]/[database>]
+ * {@code
+ * jdbc:(mysql|mariadb):[replication:|failover|loadbalance:|aurora:]//<hostDescription>[,<hostDescription>]/[database>]
  * [?<key1>=<value1>[&<key2>=<value2>]] }
- * </p>
- * <p>
- * hostDescription:<br> - simple :<br> {@code <host>:<portnumber>}<br> (for example
- * localhost:3306)<br><br> - complex :<br> {@code address=[(type=(master|slave))][(port=<portnumber>)](host=<host>)}<br>
- * <br><br>
- * type is by default master<br> port is by default 3306<br>
- * </p>
- * <p>
- * host can be dns name, ipv4 or ipv6.<br> in case of ipv6 and simple host description, the ip must
- * be written inside bracket.<br> exemple : {@code jdbc:mariadb://[2001:0660:7401:0200:0000:0000:0edf:bdd7]:3306}<br>
- * </p>
- * <p>
- * Some examples :<br> {@code jdbc:mariadb://localhost:3306/database?user=greg&password=pass}<br>
- * {@code jdbc:mariadb://address=(type=master)(host=master1),address=(port=3307)(type=slave)(host=slave1)/database?user=greg&password=pass}<br>
- * </p>
+ *
+ * <p>hostDescription:<br>
+ * - simple :<br>
+ * {@code <host>:<portnumber>}<br>
+ * (for example localhost:3306)<br>
+ * <br>
+ * - complex :<br>
+ * {@code address=[(type=(master|slave))][(port=<portnumber>)](host=<host>)}<br>
+ * <br>
+ * <br>
+ * type is by default master<br>
+ * port is by default 3306<br>
+ *
+ * <p>host can be dns name, ipv4 or ipv6.<br>
+ * in case of ipv6 and simple host description, the ip must be written inside bracket.<br>
+ * exemple : {@code jdbc:mariadb://[2001:0660:7401:0200:0000:0000:0edf:bdd7]:3306}<br>
+ *
+ * <p>Some examples :<br>
+ * {@code jdbc:mariadb://localhost:3306/database?user=greg&password=pass}<br>
+ * {@code
+ * jdbc:mariadb://address=(type=master)(host=master1),address=(port=3307)(type=slave)(host=slave1)/database?user=greg&password=pass}
+ * <br>
  */
 public class UrlParser implements Cloneable {
 
   private static final String DISABLE_MYSQL_URL = "disableMariaDbDriver";
-  private static final Pattern URL_PARAMETER = Pattern
-      .compile("(\\/([^\\?]*))?(\\?(.+))*", Pattern.DOTALL);
-  private static final Pattern AWS_PATTERN = Pattern
-      .compile("(.+)\\.([a-z0-9\\-]+\\.rds\\.amazonaws\\.com)",
-          Pattern.CASE_INSENSITIVE);
+  private static final Pattern URL_PARAMETER =
+      Pattern.compile("(\\/([^\\?]*))?(\\?(.+))*", Pattern.DOTALL);
+  private static final Pattern AWS_PATTERN =
+      Pattern.compile("(.+)\\.([a-z0-9\\-]+\\.rds\\.amazonaws\\.com)", Pattern.CASE_INSENSITIVE);
 
   private String database;
   private Options options = null;
@@ -101,12 +105,21 @@ public class UrlParser implements Cloneable {
   private HaMode haMode;
   private String initialUrl;
   private boolean multiMaster;
+  private CredentialPlugin credentialPlugin;
 
-  private UrlParser() {
-  }
+  private UrlParser() {}
 
-  protected UrlParser(String database, List<HostAddress> addresses, Options options,
-      HaMode haMode) {
+  /**
+   * Constructor.
+   *
+   * @param database database
+   * @param addresses list of hosts
+   * @param options connection option
+   * @param haMode High availability mode
+   * @throws SQLException if credential plugin cannot be loaded
+   */
+  public UrlParser(String database, List<HostAddress> addresses, Options options, HaMode haMode)
+      throws SQLException {
     this.options = options;
     this.database = database;
     this.addresses = addresses;
@@ -122,8 +135,8 @@ public class UrlParser implements Cloneable {
         }
       }
     }
-
-    DefaultOptions.optionCoherenceValidation(options);
+    this.credentialPlugin = CredentialPluginLoader.get(options.credentialType);
+    DefaultOptions.postOptionProcess(options, credentialPlugin);
     setInitialUrl();
     loadMultiMasterValue();
   }
@@ -136,8 +149,9 @@ public class UrlParser implements Cloneable {
    * @return true if url string correspond.
    */
   public static boolean acceptsUrl(String url) {
-    return (url != null) && (url.startsWith("jdbc:mariadb:")
-        || (url.startsWith("jdbc:mysql:") && !url.contains(DISABLE_MYSQL_URL)));
+    return (url != null)
+        && (url.startsWith("jdbc:mariadb:")
+            || (url.startsWith("jdbc:mysql:") && !url.contains(DISABLE_MYSQL_URL)));
   }
 
   public static UrlParser parse(final String url) throws SQLException {
@@ -147,15 +161,15 @@ public class UrlParser implements Cloneable {
   /**
    * Parse url connection string with additional properties.
    *
-   * @param url  connection string
+   * @param url connection string
    * @param prop properties
    * @return UrlParser instance
    * @throws SQLException if parsing exception occur
    */
   public static UrlParser parse(final String url, Properties prop) throws SQLException {
     if (url != null
-        && (url.startsWith("jdbc:mariadb:") || url.startsWith("jdbc:mysql:") && !url
-        .contains(DISABLE_MYSQL_URL))) {
+        && (url.startsWith("jdbc:mariadb:")
+            || url.startsWith("jdbc:mysql:") && !url.contains(DISABLE_MYSQL_URL))) {
       UrlParser urlParser = new UrlParser();
       parseInternal(urlParser, url, (prop == null) ? new Properties() : prop);
       return urlParser;
@@ -167,8 +181,8 @@ public class UrlParser implements Cloneable {
    * Parses the connection URL in order to set the UrlParser instance with all the information
    * provided through the URL.
    *
-   * @param urlParser  object instance in which all data from the connection url is stored
-   * @param url        connection URL
+   * @param urlParser object instance in which all data from the connection url is stored
+   * @param url connection URL
    * @param properties properties
    * @throws SQLException if format is incorrect
    */
@@ -193,8 +207,8 @@ public class UrlParser implements Cloneable {
       if ((dbIndex < paramIndex && dbIndex < 0) || (dbIndex > paramIndex && paramIndex > -1)) {
         hostAddressesString = urlSecondPart.substring(0, paramIndex);
         additionalParameters = urlSecondPart.substring(paramIndex);
-      } else if ((dbIndex < paramIndex && dbIndex > -1) || (dbIndex > paramIndex
-          && paramIndex < 0)) {
+      } else if ((dbIndex < paramIndex && dbIndex > -1)
+          || (dbIndex > paramIndex && paramIndex < 0)) {
         hostAddressesString = urlSecondPart.substring(0, dbIndex);
         additionalParameters = urlSecondPart.substring(dbIndex);
       } else {
@@ -221,15 +235,18 @@ public class UrlParser implements Cloneable {
    * through the additional parameters given in order to extract the database and the options for
    * the connection.
    *
-   * @param urlParser            object instance in which all data from the connection URL is
-   *                             stored
-   * @param properties           properties
-   * @param hostAddressesString  string that holds all the host addresses
+   * @param urlParser object instance in which all data from the connection URL is stored
+   * @param properties properties
+   * @param hostAddressesString string that holds all the host addresses
    * @param additionalParameters string that holds all parameters defined for the connection
+   * @throws SQLException if credential plugin cannot be loaded
    */
-  private static void defineUrlParserParameters(UrlParser urlParser, Properties properties,
+  private static void defineUrlParserParameters(
+      UrlParser urlParser,
+      Properties properties,
       String hostAddressesString,
-      String additionalParameters) {
+      String additionalParameters)
+      throws SQLException {
 
     if (additionalParameters != null) {
       //noinspection Annotator
@@ -238,9 +255,8 @@ public class UrlParser implements Cloneable {
       if (matcher.find()) {
 
         urlParser.database = matcher.group(2);
-        urlParser.options = DefaultOptions
-            .parse(urlParser.haMode, matcher.group(4), properties, urlParser.options);
-        DefaultOptions.optionCoherenceValidation(urlParser.options);
+        urlParser.options =
+            DefaultOptions.parse(urlParser.haMode, matcher.group(4), properties, urlParser.options);
         if (urlParser.database != null && urlParser.database.isEmpty()) {
           urlParser.database = null;
         }
@@ -248,28 +264,27 @@ public class UrlParser implements Cloneable {
       } else {
 
         urlParser.database = null;
-        urlParser.options = DefaultOptions
-            .parse(urlParser.haMode, "", properties, urlParser.options);
-        DefaultOptions.optionCoherenceValidation(urlParser.options);
-
+        urlParser.options =
+            DefaultOptions.parse(urlParser.haMode, "", properties, urlParser.options);
       }
 
     } else {
 
       urlParser.database = null;
       urlParser.options = DefaultOptions.parse(urlParser.haMode, "", properties, urlParser.options);
-      DefaultOptions.optionCoherenceValidation(urlParser.options);
-
     }
+    urlParser.credentialPlugin = CredentialPluginLoader.get(urlParser.options.credentialType);
+    DefaultOptions.postOptionProcess(urlParser.options, urlParser.credentialPlugin);
 
-    LoggerFactory.init(urlParser.options.log
-        || urlParser.options.profileSql
-        || urlParser.options.slowQueryThresholdNanos != null);
+    LoggerFactory.init(
+        urlParser.options.log
+            || urlParser.options.profileSql
+            || urlParser.options.slowQueryThresholdNanos != null);
     urlParser.addresses = HostAddress.parse(hostAddressesString, urlParser.haMode);
   }
 
   private static HaMode parseHaMode(String url, int separator) {
-    //parser is sure to have at least 2 colon, since jdbc:[mysql|mariadb]: is tested.
+    // parser is sure to have at least 2 colon, since jdbc:[mysql|mariadb]: is tested.
     int firstColonPos = url.indexOf(':');
     int secondColonPos = url.indexOf(':', firstColonPos + 1);
     int thirdColonPos = url.indexOf(':', secondColonPos + 1);
@@ -282,7 +297,8 @@ public class UrlParser implements Cloneable {
     }
 
     try {
-      String haModeString = url.substring(secondColonPos + 1, thirdColonPos).toUpperCase(Locale.ROOT);
+      String haModeString =
+          url.substring(secondColonPos + 1, thirdColonPos).toUpperCase(Locale.ROOT);
       if ("FAILOVER".equals(haModeString)) {
         haModeString = "LOADBALANCE";
       }
@@ -291,7 +307,6 @@ public class UrlParser implements Cloneable {
       throw new IllegalArgumentException(
           "wrong failover parameter format in connection String " + url);
     }
-
   }
 
   private static void setDefaultHostAddressType(UrlParser urlParser) {
@@ -321,8 +336,12 @@ public class UrlParser implements Cloneable {
       if (i > 0) {
         sb.append(",");
       }
-      sb.append("address=(host=").append(hostAddress.host).append(")")
-          .append("(port=").append(hostAddress.port).append(")");
+      sb.append("address=(host=")
+          .append(hostAddress.host)
+          .append(")")
+          .append("(port=")
+          .append(hostAddress.port)
+          .append(")");
       if (hostAddress.type != null) {
         sb.append("(type=").append(hostAddress.type).append(")");
       }
@@ -345,8 +364,8 @@ public class UrlParser implements Cloneable {
    */
   public UrlParser auroraPipelineQuirks() {
 
-    //Aurora has issue with pipelining, depending on network speed.
-    //Driver must rely on information provided by user : hostname if dns, and HA mode.</p>
+    // Aurora has issue with pipelining, depending on network speed.
+    // Driver must rely on information provided by user : hostname if dns, and HA mode.</p>
     boolean disablePipeline = isAurora();
 
     if (options.useBatchMultiSend == null) {
@@ -361,11 +380,10 @@ public class UrlParser implements Cloneable {
 
   /**
    * Detection of Aurora.
-   * <p>
-   * Aurora rely on MySQL, then cannot be identified by protocol. But Aurora doesn't permit some
+   *
+   * <p>Aurora rely on MySQL, then cannot be identified by protocol. But Aurora doesn't permit some
    * behaviour normally working with MySQL : pipelining. So Driver must identified if server is
    * Aurora to disable pipeline options that are enable by default.
-   * </p>
    *
    * @return true if aurora.
    */
@@ -424,10 +442,6 @@ public class UrlParser implements Cloneable {
     return this.addresses;
   }
 
-  public void setHostAddresses(List<HostAddress> addresses) {
-    this.addresses = addresses;
-  }
-
   public Options getOptions() {
     return options;
   }
@@ -437,6 +451,10 @@ public class UrlParser implements Cloneable {
     setInitialUrl();
   }
 
+  public CredentialPlugin getCredentialPlugin() {
+    return credentialPlugin;
+  }
+
   /**
    * ToString implementation.
    *
@@ -464,12 +482,15 @@ public class UrlParser implements Cloneable {
     }
 
     UrlParser urlParser = (UrlParser) parser;
-    return (initialUrl != null ? initialUrl.equals(urlParser.getInitialUrl())
-        : urlParser.getInitialUrl() == null)
-        && (getUsername() != null ? getUsername().equals(urlParser.getUsername())
-        : urlParser.getUsername() == null)
-        && (getPassword() != null ? getPassword().equals(urlParser.getPassword())
-        : urlParser.getPassword() == null);
+    return (initialUrl != null
+            ? initialUrl.equals(urlParser.getInitialUrl())
+            : urlParser.getInitialUrl() == null)
+        && (getUsername() != null
+            ? getUsername().equals(urlParser.getUsername())
+            : urlParser.getUsername() == null)
+        && (getPassword() != null
+            ? getPassword().equals(urlParser.getPassword())
+            : urlParser.getPassword() == null);
   }
 
   @Override
@@ -511,4 +532,4 @@ public class UrlParser implements Cloneable {
     tmpUrlParser.addresses.addAll(addresses);
     return tmpUrlParser;
   }
-}
\ No newline at end of file
+}
