@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,17 +52,14 @@
 
 package org.mariadb.jdbc.internal.com.read.dao;
 
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.util.ArrayDeque;
-import java.util.Deque;
-import org.mariadb.jdbc.MariaDbStatement;
-import org.mariadb.jdbc.internal.com.read.resultset.SelectResultSet;
-import org.mariadb.jdbc.internal.com.send.parameters.ParameterHolder;
-import org.mariadb.jdbc.internal.protocol.Protocol;
-import org.mariadb.jdbc.internal.util.exceptions.ExceptionMapper;
+import org.mariadb.jdbc.*;
+import org.mariadb.jdbc.internal.com.read.resultset.*;
+import org.mariadb.jdbc.internal.com.send.parameters.*;
+import org.mariadb.jdbc.internal.protocol.*;
+import org.mariadb.jdbc.internal.util.exceptions.*;
 
+import java.sql.*;
+import java.util.*;
 
 public class Results {
 
@@ -85,8 +82,8 @@ public class Results {
   private ParameterHolder[] parameters;
 
   /**
-   * Single Text query.
-   * /! use internally, because autoincrement value is not right for multi-queries !/
+   * Single Text query. /! use internally, because autoincrement value is not right for
+   * multi-queries !/
    */
   public Results() {
     this.statement = null;
@@ -106,29 +103,34 @@ public class Results {
   /**
    * Default constructor.
    *
-   * @param statement            current statement
-   * @param fetchSize            fetch size
-   * @param batch                select result possible
-   * @param expectedSize         expected size
-   * @param binaryFormat         use binary protocol
-   * @param resultSetScrollType  one of the following <code>ResultSet</code> constants:
-   *                             <code>ResultSet.TYPE_FORWARD_ONLY</code>,
-   *                             <code>ResultSet.TYPE_SCROLL_INSENSITIVE</code>, or
-   *                             <code>ResultSet.TYPE_SCROLL_SENSITIVE</code>
+   * @param statement current statement
+   * @param fetchSize fetch size
+   * @param batch select result possible
+   * @param expectedSize expected size
+   * @param binaryFormat use binary protocol
+   * @param resultSetScrollType one of the following <code>ResultSet</code> constants: <code>
+   *     ResultSet.TYPE_FORWARD_ONLY</code>, <code>ResultSet.TYPE_SCROLL_INSENSITIVE</code>, or
+   *     <code>ResultSet.TYPE_SCROLL_SENSITIVE</code>
    * @param resultSetConcurrency a concurrency type; one of <code>ResultSet.CONCUR_READ_ONLY</code>
-   *                             or
-   *                             <code>ResultSet.CONCUR_UPDATABLE</code>
-   * @param autoGeneratedKeys    a flag indicating whether auto-generated keys should be returned;
-   *                             one of
-   *                             <code>Statement.RETURN_GENERATED_KEYS</code>
-   *                             or <code>Statement.NO_GENERATED_KEYS</code>
-   * @param autoIncrement        Connection auto-increment value
-   * @param sql                  sql command
-   * @param parameters           parameters
+   *     or <code>ResultSet.CONCUR_UPDATABLE</code>
+   * @param autoGeneratedKeys a flag indicating whether auto-generated keys should be returned; one
+   *     of <code>Statement.RETURN_GENERATED_KEYS</code> or <code>Statement.NO_GENERATED_KEYS</code>
+   * @param autoIncrement Connection auto-increment value
+   * @param sql sql command
+   * @param parameters parameters
    */
-  public Results(MariaDbStatement statement, int fetchSize, boolean batch, int expectedSize,
-                 boolean binaryFormat, int resultSetScrollType, int resultSetConcurrency, int autoGeneratedKeys,
-                 int autoIncrement, String sql, ParameterHolder[] parameters) {
+  public Results(
+      MariaDbStatement statement,
+      int fetchSize,
+      boolean batch,
+      int expectedSize,
+      boolean binaryFormat,
+      int resultSetScrollType,
+      int resultSetConcurrency,
+      int autoGeneratedKeys,
+      int autoIncrement,
+      String sql,
+      ParameterHolder[] parameters) {
     this.statement = statement;
     this.fetchSize = fetchSize;
     this.batch = batch;
@@ -147,8 +149,8 @@ public class Results {
   /**
    * Add execution statistics.
    *
-   * @param updateCount         number of updated rows
-   * @param insertId            primary key
+   * @param updateCount number of updated rows
+   * @param insertId primary key
    * @param moreResultAvailable is there additional packet
    */
   public void addStats(long updateCount, long insertId, boolean moreResultAvailable) {
@@ -191,7 +193,7 @@ public class Results {
   /**
    * Add resultSet to results.
    *
-   * @param resultSet           new resultSet.
+   * @param resultSet new resultSet.
    * @param moreResultAvailable indicate if other results (ResultSet or updateCount) are available.
    */
   public void addResultSet(SelectResultSet resultSet, boolean moreResultAvailable) {
@@ -226,6 +228,7 @@ public class Results {
 
   /**
    * Indicate that command / batch is finished, so set current resultSet if needed.
+   *
    * @return true id has cmdInformation
    */
   public boolean commandEnd() {
@@ -251,10 +254,11 @@ public class Results {
   }
 
   /**
-   * <p>Load fully current results.</p>
-   * <p><i>Lock must be set before using this method</i></p>
+   * Load fully current results.
    *
-   * @param skip     must result be available afterwhile
+   * <p><i>Lock must be set before using this method</i>
+   *
+   * @param skip must result be available afterwhile
    * @param protocol current protocol
    * @throws SQLException if any connection error occur
    */
@@ -313,20 +317,16 @@ public class Results {
     if (fetchSize == 0 || resultSet == null) {
       return true;
     }
-    return resultSet.isFullyLoaded()
-            && executionResults.isEmpty()
-            && !protocol.hasMoreResults();
+    return resultSet.isFullyLoaded() && executionResults.isEmpty() && !protocol.hasMoreResults();
   }
 
   /**
    * Position to next resultSet.
    *
-   * @param current  one of the following <code>Statement</code> constants indicating what should
-   *                 happen to current
-   *                 <code>ResultSet</code> objects obtained using the method
-   *                 <code>getResultSet</code>:
-   *                 <code>Statement.CLOSE_CURRENT_RESULT</code>, <code>Statement.KEEP_CURRENT_RESULT</code>,
-   *                 or <code>Statement.CLOSE_ALL_RESULTS</code>
+   * @param current one of the following <code>Statement</code> constants indicating what should
+   *     happen to current <code>ResultSet</code> objects obtained using the method <code>
+   *     getResultSet</code>: <code>Statement.CLOSE_CURRENT_RESULT</code>, <code>
+   *     Statement.KEEP_CURRENT_RESULT</code>, or <code>Statement.CLOSE_ALL_RESULTS</code>
    * @param protocol current protocol
    * @return true if other resultSet exists.
    * @throws SQLException if any connection error occur.
@@ -336,14 +336,14 @@ public class Results {
 
       protocol.getLock().lock();
       try {
-        //load current resultSet
+        // load current resultSet
         if (current == Statement.CLOSE_CURRENT_RESULT && resultSet != null) {
           resultSet.close();
         } else {
           resultSet.fetchRemaining();
         }
 
-        //load next data if there is
+        // load next data if there is
         if (protocol.hasMoreResults()) {
           protocol.getResult(this);
         }
@@ -353,7 +353,6 @@ public class Results {
       } finally {
         protocol.getLock().unlock();
       }
-
     }
 
     if (cmdInformation.moreResults() && !batch) {
@@ -373,9 +372,7 @@ public class Results {
       }
       resultSet = null;
       return false;
-
     }
-
   }
 
   public int getFetchSize() {
@@ -416,14 +413,15 @@ public class Results {
 
   /**
    * Send a resultSet that contain auto generated keys. 2 differences :
+   *
    * <ol>
-   * <li>Batch will list all insert ids.</li>
-   * <li>in case of multi-query is set, resultSet will be per query. </li>
+   *   <li>Batch will list all insert ids.
+   *   <li>in case of multi-query is set, resultSet will be per query.
    * </ol>
    *
-   * <p>example "INSERT INTO myTable values ('a'),('b');INSERT INTO myTable values ('c'),('d'),('e')"
-   * will have a resultSet of 2 values, and when Statement.getMoreResults() will be called, a
-   * Statement.getGeneratedKeys will return a resultset with 3 ids.</p>
+   * <p>example "INSERT INTO myTable values ('a'),('b');INSERT INTO myTable values
+   * ('c'),('d'),('e')" will have a resultSet of 2 values, and when Statement.getMoreResults() will
+   * be called, a Statement.getGeneratedKeys will return a resultset with 3 ids.
    *
    * @param protocol current protocol
    * @return a ResultSet containing generated ids.
@@ -438,7 +436,7 @@ public class Results {
       if (batch) {
         return cmdInformation.getBatchGeneratedKeys(protocol);
       }
-      return cmdInformation.getGeneratedKeys(protocol);
+      return cmdInformation.getGeneratedKeys(protocol, sql);
     }
     return SelectResultSet.createEmptyResultSet();
   }
