@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,32 +52,19 @@
 
 package org.mariadb.jdbc.internal.com.read.resultset.rowprotocol;
 
-import java.math.BigDecimal;
-import java.math.BigInteger;
-import java.nio.charset.StandardCharsets;
+import org.mariadb.jdbc.internal.*;
+import org.mariadb.jdbc.internal.com.read.resultset.*;
+import org.mariadb.jdbc.internal.util.exceptions.*;
+import org.mariadb.jdbc.util.*;
+
+import java.math.*;
+import java.nio.charset.*;
 import java.sql.Date;
-import java.sql.SQLException;
-import java.sql.Time;
-import java.sql.Timestamp;
-import java.sql.Types;
-import java.text.DateFormat;
-import java.text.ParseException;
-import java.text.SimpleDateFormat;
-import java.time.LocalDate;
-import java.time.LocalDateTime;
-import java.time.LocalTime;
-import java.time.OffsetTime;
-import java.time.ZoneId;
-import java.time.ZoneOffset;
-import java.time.ZonedDateTime;
-import java.time.format.DateTimeFormatter;
-import java.time.format.DateTimeParseException;
-import java.util.Calendar;
-import java.util.TimeZone;
-import org.mariadb.jdbc.internal.ColumnType;
-import org.mariadb.jdbc.internal.com.read.resultset.ColumnInformation;
-import org.mariadb.jdbc.internal.util.Options;
-import org.mariadb.jdbc.internal.util.exceptions.ExceptionMapper;
+import java.sql.*;
+import java.text.*;
+import java.time.*;
+import java.time.format.*;
+import java.util.*;
 
 public class TextRowProtocol extends RowProtocol {
 
@@ -85,7 +72,7 @@ public class TextRowProtocol extends RowProtocol {
    * Constructor.
    *
    * @param maxFieldSize max field size
-   * @param options      connection options
+   * @param options connection options
    */
   public TextRowProtocol(int maxFieldSize, Options options) {
     super(maxFieldSize, options);
@@ -118,19 +105,24 @@ public class TextRowProtocol extends RowProtocol {
               pos += 2 + (0xffff & (((buf[pos] & 0xff) + ((buf[pos + 1] & 0xff) << 8))));
               break;
             case 253:
-              pos += 3 + (0xffffff & ((buf[pos] & 0xff)
-                  + ((buf[pos + 1] & 0xff) << 8)
-                  + ((buf[pos + 2] & 0xff) << 16)));
+              pos +=
+                  3
+                      + (0xffffff
+                          & ((buf[pos] & 0xff)
+                              + ((buf[pos + 1] & 0xff) << 8)
+                              + ((buf[pos + 2] & 0xff) << 16)));
               break;
             case 254:
-              pos += 8 + ((buf[pos] & 0xff)
-                  + ((long) (buf[pos + 1] & 0xff) << 8)
-                  + ((long) (buf[pos + 2] & 0xff) << 16)
-                  + ((long) (buf[pos + 3] & 0xff) << 24)
-                  + ((long) (buf[pos + 4] & 0xff) << 32)
-                  + ((long) (buf[pos + 5] & 0xff) << 40)
-                  + ((long) (buf[pos + 6] & 0xff) << 48)
-                  + ((long) (buf[pos + 7] & 0xff) << 56));
+              pos +=
+                  8
+                      + ((buf[pos] & 0xff)
+                          + ((long) (buf[pos + 1] & 0xff) << 8)
+                          + ((long) (buf[pos + 2] & 0xff) << 16)
+                          + ((long) (buf[pos + 3] & 0xff) << 24)
+                          + ((long) (buf[pos + 4] & 0xff) << 32)
+                          + ((long) (buf[pos + 5] & 0xff) << 40)
+                          + ((long) (buf[pos + 6] & 0xff) << 48)
+                          + ((long) (buf[pos + 7] & 0xff) << 56));
               break;
             default:
               pos += type;
@@ -144,23 +136,26 @@ public class TextRowProtocol extends RowProtocol {
               this.lastValueNull = BIT_LAST_FIELD_NULL;
               return;
             case 252:
-              length = 0xffff & ((buf[pos++] & 0xff)
-                  + ((buf[pos++] & 0xff) << 8));
+              length = 0xffff & ((buf[pos++] & 0xff) + ((buf[pos++] & 0xff) << 8));
               break;
             case 253:
-              length = 0xffffff & ((buf[pos++] & 0xff)
-                  + ((buf[pos++] & 0xff) << 8)
-                  + ((buf[pos++] & 0xff) << 16));
+              length =
+                  0xffffff
+                      & ((buf[pos++] & 0xff)
+                          + ((buf[pos++] & 0xff) << 8)
+                          + ((buf[pos++] & 0xff) << 16));
               break;
             case 254:
-              length = (int) ((buf[pos++] & 0xff)
-                  + ((long) (buf[pos++] & 0xff) << 8)
-                  + ((long) (buf[pos++] & 0xff) << 16)
-                  + ((long) (buf[pos++] & 0xff) << 24)
-                  + ((long) (buf[pos++] & 0xff) << 32)
-                  + ((long) (buf[pos++] & 0xff) << 40)
-                  + ((long) (buf[pos++] & 0xff) << 48)
-                  + ((long) (buf[pos++] & 0xff) << 56));
+              length =
+                  (int)
+                      ((buf[pos++] & 0xff)
+                          + ((long) (buf[pos++] & 0xff) << 8)
+                          + ((long) (buf[pos++] & 0xff) << 16)
+                          + ((long) (buf[pos++] & 0xff) << 24)
+                          + ((long) (buf[pos++] & 0xff) << 32)
+                          + ((long) (buf[pos++] & 0xff) << 40)
+                          + ((long) (buf[pos++] & 0xff) << 48)
+                          + ((long) (buf[pos++] & 0xff) << 56));
               break;
             default:
               length = type;
@@ -178,8 +173,8 @@ public class TextRowProtocol extends RowProtocol {
    * Get String from raw text format.
    *
    * @param columnInfo column information
-   * @param cal        calendar
-   * @param timeZone   time zone
+   * @param cal calendar
+   * @param timeZone time zone
    * @return String value
    * @throws SQLException if column type doesn't permit conversion
    */
@@ -194,8 +189,8 @@ public class TextRowProtocol extends RowProtocol {
         return String.valueOf(parseBit());
       case DOUBLE:
       case FLOAT:
-        return zeroFillingIfNeeded(new String(buf, pos, length, StandardCharsets.UTF_8),
-            columnInfo);
+        return zeroFillingIfNeeded(
+            new String(buf, pos, length, StandardCharsets.UTF_8), columnInfo);
       case TIME:
         return getInternalTimeString(columnInfo);
       case DATE:
@@ -276,18 +271,26 @@ public class TextRowProtocol extends RowProtocol {
           Float floatValue = Float.valueOf(new String(buf, pos, length, StandardCharsets.UTF_8));
           if (floatValue.compareTo((float) Long.MAX_VALUE) >= 1) {
             throw new SQLException(
-                "Out of range value for column '" + columnInfo.getName() + "' : value "
+                "Out of range value for column '"
+                    + columnInfo.getName()
+                    + "' : value "
                     + new String(buf, pos, length, StandardCharsets.UTF_8)
-                    + " is not in Long range", "22003", 1264);
+                    + " is not in Long range",
+                "22003",
+                1264);
           }
           return floatValue.longValue();
         case DOUBLE:
           Double doubleValue = Double.valueOf(new String(buf, pos, length, StandardCharsets.UTF_8));
           if (doubleValue.compareTo((double) Long.MAX_VALUE) >= 1) {
             throw new SQLException(
-                "Out of range value for column '" + columnInfo.getName() + "' : value "
+                "Out of range value for column '"
+                    + columnInfo.getName()
+                    + "' : value "
                     + new String(buf, pos, length, StandardCharsets.UTF_8)
-                    + " is not in Long range", "22003", 1264);
+                    + " is not in Long range",
+                "22003",
+                1264);
           }
           return doubleValue.longValue();
         case BIT:
@@ -301,22 +304,27 @@ public class TextRowProtocol extends RowProtocol {
           long result = 0;
           boolean negate = false;
           int begin = pos;
-          if (length > 0 && buf[begin] == 45) { //minus sign
+          if (length > 0 && buf[begin] == 45) { // minus sign
             negate = true;
             begin++;
           }
           for (; begin < pos + length; begin++) {
             result = result * 10 + buf[begin] - 48;
           }
-          //specific for BIGINT : if value > Long.MAX_VALUE , will become negative until -1
+          // specific for BIGINT : if value > Long.MAX_VALUE , will become negative until -1
           if (result < 0) {
-            //CONJ-399 : handle specifically Long.MIN_VALUE that has absolute value +1 compare to LONG.MAX_VALUE
+            // CONJ-399 : handle specifically Long.MIN_VALUE that has absolute value +1 compare to
+            // LONG.MAX_VALUE
             if (result == Long.MIN_VALUE && negate) {
               return Long.MIN_VALUE;
             }
             throw new SQLException(
-                "Out of range value for column '" + columnInfo.getName() + "' for value "
-                    + new String(buf, pos, length, StandardCharsets.UTF_8), "22003", 1264);
+                "Out of range value for column '"
+                    + columnInfo.getName()
+                    + "' for value "
+                    + new String(buf, pos, length, StandardCharsets.UTF_8),
+                "22003",
+                1264);
           }
           return (negate ? -1 * result : result);
         default:
@@ -324,18 +332,19 @@ public class TextRowProtocol extends RowProtocol {
       }
 
     } catch (NumberFormatException nfe) {
-      //parse error.
-      //if its a decimal retry without the decimal part.
+      // parse error.
+      // if its a decimal retry without the decimal part.
       String value = new String(buf, pos, length, StandardCharsets.UTF_8);
       if (isIntegerRegex.matcher(value).find()) {
         try {
           return Long.parseLong(value.substring(0, value.indexOf(".")));
         } catch (NumberFormatException nfee) {
-          //eat exception
+          // eat exception
         }
       }
       throw new SQLException(
-          "Out of range value for column '" + columnInfo.getName() + "' : value " + value, "22003",
+          "Out of range value for column '" + columnInfo.getName() + "' : value " + value,
+          "22003",
           1264);
     }
   }
@@ -371,18 +380,22 @@ public class TextRowProtocol extends RowProtocol {
         try {
           return Float.valueOf(new String(buf, pos, length, StandardCharsets.UTF_8));
         } catch (NumberFormatException nfe) {
-          SQLException sqlException = new SQLException("Incorrect format \""
-              + new String(buf, pos, length, StandardCharsets.UTF_8)
-              + "\" for getFloat for data field with type " + columnInfo.getColumnType()
-              .getJavaTypeName(), "22003", 1264);
+          SQLException sqlException =
+              new SQLException(
+                  "Incorrect format \""
+                      + new String(buf, pos, length, StandardCharsets.UTF_8)
+                      + "\" for getFloat for data field with type "
+                      + columnInfo.getColumnType().getJavaTypeName(),
+                  "22003",
+                  1264);
           //noinspection UnnecessaryInitCause
           sqlException.initCause(nfe);
           throw sqlException;
         }
       default:
         throw new SQLException(
-            "getFloat not available for data field type " + columnInfo.getColumnType()
-                .getJavaTypeName());
+            "getFloat not available for data field type "
+                + columnInfo.getColumnType().getJavaTypeName());
     }
   }
 
@@ -391,8 +404,7 @@ public class TextRowProtocol extends RowProtocol {
    *
    * @param columnInfo column information
    * @return double value
-   * @throws SQLException if column type doesn't permit conversion or not in Double range
-   *                      (unsigned)
+   * @throws SQLException if column type doesn't permit conversion or not in Double range (unsigned)
    */
   public double getInternalDouble(ColumnInformation columnInfo) throws SQLException {
     if (lastValueWasNull()) {
@@ -417,20 +429,23 @@ public class TextRowProtocol extends RowProtocol {
         try {
           return Double.valueOf(new String(buf, pos, length, StandardCharsets.UTF_8));
         } catch (NumberFormatException nfe) {
-          SQLException sqlException = new SQLException("Incorrect format \""
-              + new String(buf, pos, length, StandardCharsets.UTF_8)
-              + "\" for getDouble for data field with type " + columnInfo.getColumnType()
-              .getJavaTypeName(), "22003", 1264);
+          SQLException sqlException =
+              new SQLException(
+                  "Incorrect format \""
+                      + new String(buf, pos, length, StandardCharsets.UTF_8)
+                      + "\" for getDouble for data field with type "
+                      + columnInfo.getColumnType().getJavaTypeName(),
+                  "22003",
+                  1264);
           //noinspection UnnecessaryInitCause
           sqlException.initCause(nfe);
           throw sqlException;
         }
       default:
         throw new SQLException(
-            "getDouble not available for data field type " + columnInfo.getColumnType()
-                .getJavaTypeName());
+            "getDouble not available for data field type "
+                + columnInfo.getColumnType().getJavaTypeName());
     }
-
   }
 
   /**
@@ -438,9 +453,8 @@ public class TextRowProtocol extends RowProtocol {
    *
    * @param columnInfo column information
    * @return BigDecimal value
-   * @throws SQLException if column type doesn't permit conversion
    */
-  public BigDecimal getInternalBigDecimal(ColumnInformation columnInfo) throws SQLException {
+  public BigDecimal getInternalBigDecimal(ColumnInformation columnInfo) {
     if (lastValueWasNull()) {
       return null;
     }
@@ -455,8 +469,8 @@ public class TextRowProtocol extends RowProtocol {
    * Get date from raw text format.
    *
    * @param columnInfo column information
-   * @param cal        calendar
-   * @param timeZone   time zone
+   * @param cal calendar
+   * @param timeZone time zone
    * @return date value
    * @throws SQLException if column type doesn't permit conversion
    */
@@ -467,8 +481,32 @@ public class TextRowProtocol extends RowProtocol {
       return null;
     }
 
-    String rawValue = new String(buf, pos, length, StandardCharsets.UTF_8);
     switch (columnInfo.getColumnType()) {
+      case DATE:
+        int[] datePart = new int[] {0, 0, 0};
+        int partIdx = 0;
+        for (int begin = pos; begin < pos + length; begin++) {
+          byte b = buf[begin];
+          if (b == '-') {
+            partIdx++;
+            continue;
+          }
+          if (b < '0' || b > '9') {
+            throw new SQLException(
+                "cannot parse data in date string '"
+                    + new String(buf, pos, length, StandardCharsets.UTF_8)
+                    + "'");
+          }
+          datePart[partIdx] = datePart[partIdx] * 10 + b - 48;
+        }
+
+        if (datePart[0] == 0 && datePart[1] == 0 && datePart[2] == 0) {
+          lastValueNull |= BIT_LAST_ZERO_DATE;
+          return null;
+        }
+
+        return new Date(datePart[0] - 1900, datePart[1] - 1, datePart[2]);
+
       case TIMESTAMP:
       case DATETIME:
         Timestamp timestamp = getInternalTimestamp(columnInfo, cal, timeZone);
@@ -480,20 +518,11 @@ public class TextRowProtocol extends RowProtocol {
       case TIME:
         throw new SQLException("Cannot read DATE using a Types.TIME field");
 
-      case DATE:
-        if ("0000-00-00".equals(rawValue)) {
-          lastValueNull |= BIT_LAST_ZERO_DATE;
-          return null;
-        }
-
-        return new Date(
-            Integer.parseInt(rawValue.substring(0, 4)) - 1900,
-            Integer.parseInt(rawValue.substring(5, 7)) - 1,
-            Integer.parseInt(rawValue.substring(8, 10))
-        );
-
       case YEAR:
-        int year = Integer.parseInt(rawValue);
+        int year = 0;
+        for (int begin = pos; begin < pos + length; begin++) {
+          year = year * 10 + buf[begin] - 48;
+        }
         if (length == 2 && columnInfo.getLength() == 2) {
           if (year <= 69) {
             year += 2000;
@@ -501,21 +530,18 @@ public class TextRowProtocol extends RowProtocol {
             year += 1900;
           }
         }
-
         return new Date(year - 1900, 0, 1);
 
       default:
-
         try {
-
           DateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
           sdf.setTimeZone(timeZone);
-          java.util.Date utilDate = sdf.parse(rawValue);
+          java.util.Date utilDate = sdf.parse(new String(buf, pos, length, StandardCharsets.UTF_8));
           return new Date(utilDate.getTime());
 
         } catch (ParseException e) {
-          throw ExceptionMapper
-              .getSqlException("Could not get object as Date : " + e.getMessage(), "S1009", e);
+          throw ExceptionMapper.getSqlException(
+              "Could not get object as Date : " + e.getMessage(), "S1009", e);
         }
     }
   }
@@ -524,8 +550,8 @@ public class TextRowProtocol extends RowProtocol {
    * Get time from raw text format.
    *
    * @param columnInfo column information
-   * @param cal        calendar
-   * @param timeZone   time zone
+   * @param cal calendar
+   * @param timeZone time zone
    * @return time value
    * @throws SQLException if column type doesn't permit conversion
    */
@@ -546,8 +572,8 @@ public class TextRowProtocol extends RowProtocol {
 
     } else {
       String raw = new String(buf, pos, length, StandardCharsets.UTF_8);
-      if (!options.useLegacyDatetimeCode && (raw.startsWith("-") || raw.split(":").length != 3
-          || raw.indexOf(":") > 3)) {
+      if (!options.useLegacyDatetimeCode
+          && (raw.startsWith("-") || raw.split(":").length != 3 || raw.indexOf(":") > 3)) {
         throw new SQLException("Time format \"" + raw + "\" incorrect, must be HH:mm:ss");
       }
       boolean negate = raw.startsWith("-");
@@ -559,7 +585,7 @@ public class TextRowProtocol extends RowProtocol {
         int hour = Integer.parseInt(rawPart[0]);
         int minutes = Integer.parseInt(rawPart[1]);
         int seconds = Integer.parseInt(rawPart[2].substring(0, 2));
-        Calendar calendar = Calendar.getInstance();
+        Calendar calendar = cal != null ? cal : Calendar.getInstance();
         if (options.useLegacyDatetimeCode) {
           calendar.setLenient(true);
         }
@@ -574,78 +600,111 @@ public class TextRowProtocol extends RowProtocol {
             raw + " cannot be parse as time. time must have \"99:99:99\" format");
       }
     }
-
   }
 
   /**
    * Get timestamp from raw text format.
    *
-   * @param columnInfo   column information
+   * @param columnInfo column information
    * @param userCalendar calendar
-   * @param timeZone     time zone
+   * @param timeZone time zone
    * @return timestamp value
    * @throws SQLException if column type doesn't permit conversion
    */
-  public Timestamp getInternalTimestamp(ColumnInformation columnInfo, Calendar userCalendar,
-      TimeZone timeZone) throws SQLException {
+  public Timestamp getInternalTimestamp(
+      ColumnInformation columnInfo, Calendar userCalendar, TimeZone timeZone) throws SQLException {
     if (lastValueWasNull()) {
       return null;
     }
 
-    String rawValue = new String(buf, pos, length, StandardCharsets.UTF_8);
-    if (rawValue.startsWith("0000-00-00 00:00:00")) {
-      lastValueNull |= BIT_LAST_ZERO_DATE;
-      return null;
-    }
-
     switch (columnInfo.getColumnType()) {
+      case TIMESTAMP:
+      case DATETIME:
+      case DATE:
+      case VARCHAR:
+      case VARSTRING:
+      case STRING:
+        int nanoBegin = -1;
+        int[] timestampsPart = new int[] {0, 0, 0, 0, 0, 0, 0};
+        int partIdx = 0;
+        for (int begin = pos; begin < pos + length; begin++) {
+          byte b = buf[begin];
+          if (b == '-' || b == ' ' || b == ':') {
+            partIdx++;
+            continue;
+          }
+          if (b == '.') {
+            partIdx++;
+            nanoBegin = begin;
+            continue;
+          }
+          if (b < '0' || b > '9') {
+            throw new SQLException(
+                "cannot parse data in timestamp string '"
+                    + new String(buf, pos, length, StandardCharsets.UTF_8)
+                    + "'");
+          }
+
+          timestampsPart[partIdx] = timestampsPart[partIdx] * 10 + b - 48;
+        }
+        if (timestampsPart[0] == 0
+            && timestampsPart[1] == 0
+            && timestampsPart[2] == 0
+            && timestampsPart[3] == 0
+            && timestampsPart[4] == 0
+            && timestampsPart[5] == 0
+            && timestampsPart[6] == 0) {
+          lastValueNull |= BIT_LAST_ZERO_DATE;
+          return null;
+        }
+
+        // fix non leading tray for nanoseconds
+        if (nanoBegin > 0) {
+          for (int begin = 0; begin < 6 - (pos + length - nanoBegin - 1); begin++) {
+            timestampsPart[6] = timestampsPart[6] * 10;
+          }
+        }
+
+        Timestamp timestamp;
+
+        Calendar calendar;
+        if (userCalendar != null) {
+          calendar = userCalendar;
+        } else if (columnInfo.getColumnType().getSqlType() == Types.TIMESTAMP) {
+          calendar = Calendar.getInstance(timeZone);
+        } else {
+          calendar = Calendar.getInstance();
+        }
+
+        synchronized (calendar) {
+          calendar.clear();
+          calendar.set(Calendar.YEAR, timestampsPart[0]);
+          calendar.set(Calendar.MONTH, timestampsPart[1] - 1);
+          calendar.set(Calendar.DAY_OF_MONTH, timestampsPart[2]);
+          calendar.set(Calendar.HOUR_OF_DAY, timestampsPart[3]);
+          calendar.set(Calendar.MINUTE, timestampsPart[4]);
+          calendar.set(Calendar.SECOND, timestampsPart[5]);
+          calendar.set(Calendar.MILLISECOND, timestampsPart[6] / 1000000);
+          timestamp = new Timestamp(calendar.getTime().getTime());
+        }
+        timestamp.setNanos(timestampsPart[6] * 1000);
+        return timestamp;
+
       case TIME:
-        //time does not go after millisecond
+        // time does not go after millisecond
+        String rawValue = new String(buf, pos, length, StandardCharsets.UTF_8);
         Timestamp tt = new Timestamp(getInternalTime(columnInfo, userCalendar, timeZone).getTime());
         tt.setNanos(extractNanos(rawValue));
         return tt;
+
       default:
-        try {
-          int hour = 0;
-          int minutes = 0;
-          int seconds = 0;
-
-          int year = Integer.parseInt(rawValue.substring(0, 4));
-          int month = Integer.parseInt(rawValue.substring(5, 7));
-          int day = Integer.parseInt(rawValue.substring(8, 10));
-          if (rawValue.length() >= 19) {
-            hour = Integer.parseInt(rawValue.substring(11, 13));
-            minutes = Integer.parseInt(rawValue.substring(14, 16));
-            seconds = Integer.parseInt(rawValue.substring(17, 19));
-          }
-          int nanoseconds = extractNanos(rawValue);
-          Timestamp timestamp;
-
-          Calendar calendar;
-          if (userCalendar != null) {
-            calendar = userCalendar;
-          } else if (columnInfo.getColumnType().getSqlType() == Types.TIMESTAMP) {
-            calendar = Calendar.getInstance(timeZone);
-          } else {
-            calendar = Calendar.getInstance();
-          }
-
-          synchronized (calendar) {
-            calendar.clear();
-            calendar.set(Calendar.YEAR, year);
-            calendar.set(Calendar.MONTH, month - 1);
-            calendar.set(Calendar.DAY_OF_MONTH, day);
-            calendar.set(Calendar.HOUR_OF_DAY, hour);
-            calendar.set(Calendar.MINUTE, minutes);
-            calendar.set(Calendar.SECOND, seconds);
-            calendar.set(Calendar.MILLISECOND, nanoseconds / 1000000);
-            timestamp = new Timestamp(calendar.getTime().getTime());
-          }
-          timestamp.setNanos(nanoseconds);
-          return timestamp;
-        } catch (NumberFormatException | StringIndexOutOfBoundsException n) {
-          throw new SQLException("Value \"" + rawValue + "\" cannot be parse as Timestamp");
-        }
+        String value = new String(buf, pos, length, StandardCharsets.UTF_8);
+        throw new SQLException(
+            "Value type \""
+                + columnInfo.getColumnType().getTypeName()
+                + "\" with value \""
+                + value
+                + "\" cannot be parse as Timestamp");
     }
   }
 
@@ -653,7 +712,7 @@ public class TextRowProtocol extends RowProtocol {
    * Get Object from raw text format.
    *
    * @param columnInfo column information
-   * @param timeZone   time zone
+   * @param timeZone time zone
    * @return Object value
    * @throws SQLException if column type doesn't permit conversion
    */
@@ -689,13 +748,14 @@ public class TextRowProtocol extends RowProtocol {
       case DOUBLE:
         return getInternalDouble(columnInfo);
       case VARCHAR:
+      case VARSTRING:
+      case STRING:
         if (columnInfo.isBinary()) {
           byte[] data = new byte[getLengthMaxFieldSize()];
           System.arraycopy(buf, pos, data, 0, getLengthMaxFieldSize());
           return data;
         }
         return getInternalString(columnInfo, null, timeZone);
-
       case TIMESTAMP:
       case DATETIME:
         return getInternalTimestamp(columnInfo, null, timeZone);
@@ -724,15 +784,8 @@ public class TextRowProtocol extends RowProtocol {
         return getInternalFloat(columnInfo);
       case TIME:
         return getInternalTime(columnInfo, null, timeZone);
-      case VARSTRING:
-      case STRING:
-        if (columnInfo.isBinary()) {
-          byte[] data = new byte[getLengthMaxFieldSize()];
-          System.arraycopy(buf, pos, data, 0, getLengthMaxFieldSize());
-          return data;
-        }
-        return getInternalString(columnInfo, null, timeZone);
       case OLDDECIMAL:
+      case JSON:
         return getInternalString(columnInfo, null, timeZone);
       case GEOMETRY:
         byte[] data = new byte[length];
@@ -756,9 +809,8 @@ public class TextRowProtocol extends RowProtocol {
    *
    * @param columnInfo column information
    * @return boolean value
-   * @throws SQLException if column type doesn't permit conversion
    */
-  public boolean getInternalBoolean(ColumnInformation columnInfo) throws SQLException {
+  public boolean getInternalBoolean(ColumnInformation columnInfo) {
     if (lastValueWasNull()) {
       return false;
     }
@@ -818,7 +870,8 @@ public class TextRowProtocol extends RowProtocol {
       return null;
     }
 
-    if (options.maximizeMysqlCompatibility && options.useLegacyDatetimeCode
+    if (options.maximizeMysqlCompatibility
+        && options.useLegacyDatetimeCode
         && rawValue.indexOf(".") > 0) {
       return rawValue.substring(0, rawValue.indexOf("."));
     }
@@ -842,13 +895,13 @@ public class TextRowProtocol extends RowProtocol {
    * Get ZonedDateTime format from raw text format.
    *
    * @param columnInfo column information
-   * @param clazz      class for logging
-   * @param timeZone   time zone
+   * @param clazz class for logging
+   * @param timeZone time zone
    * @return ZonedDateTime value
    * @throws SQLException if column type doesn't permit conversion
    */
-  public ZonedDateTime getInternalZonedDateTime(ColumnInformation columnInfo, Class clazz,
-      TimeZone timeZone) throws SQLException {
+  public ZonedDateTime getInternalZonedDateTime(
+      ColumnInformation columnInfo, Class clazz, TimeZone timeZone) throws SQLException {
     if (lastValueWasNull()) {
       return null;
     }
@@ -861,48 +914,49 @@ public class TextRowProtocol extends RowProtocol {
 
     switch (columnInfo.getColumnType().getSqlType()) {
       case Types.TIMESTAMP:
-
         if (raw.startsWith("0000-00-00 00:00:00")) {
           return null;
         }
         try {
-          LocalDateTime localDateTime = LocalDateTime
-              .parse(raw, TEXT_LOCAL_DATE_TIME.withZone(timeZone.toZoneId()));
+          LocalDateTime localDateTime =
+              LocalDateTime.parse(raw, TEXT_LOCAL_DATE_TIME.withZone(timeZone.toZoneId()));
           return ZonedDateTime.of(localDateTime, timeZone.toZoneId());
         } catch (DateTimeParseException dateParserEx) {
-          throw new SQLException(raw
-              + " cannot be parse as LocalDateTime. time must have \"yyyy-MM-dd HH:mm:ss[.S]\" format");
+          throw new SQLException(
+              raw
+                  + " cannot be parse as LocalDateTime. time must have \"yyyy-MM-dd HH:mm:ss[.S]\" format");
         }
 
       case Types.VARCHAR:
       case Types.LONGVARCHAR:
       case Types.CHAR:
-
         if (raw.startsWith("0000-00-00 00:00:00")) {
           return null;
         }
         try {
           return ZonedDateTime.parse(raw, TEXT_ZONED_DATE_TIME);
         } catch (DateTimeParseException dateParserEx) {
-          throw new SQLException(raw
-              + " cannot be parse as ZonedDateTime. time must have \"yyyy-MM-dd[T/ ]HH:mm:ss[.S]\" "
-              + "with offset and timezone format (example : '2011-12-03 10:15:30+01:00[Europe/Paris]')");
+          throw new SQLException(
+              raw
+                  + " cannot be parse as ZonedDateTime. time must have \"yyyy-MM-dd[T/ ]HH:mm:ss[.S]\" "
+                  + "with offset and timezone format (example : '2011-12-03 10:15:30+01:00[Europe/Paris]')");
         }
 
       default:
         throw new SQLException(
-            "Cannot read " + clazz.getName() + " using a " + columnInfo.getColumnType()
-                .getJavaTypeName() + " field");
-
+            "Cannot read "
+                + clazz.getName()
+                + " using a "
+                + columnInfo.getColumnType().getJavaTypeName()
+                + " field");
     }
-
   }
 
   /**
    * Get OffsetTime format from raw text format.
    *
    * @param columnInfo column information
-   * @param timeZone   time zone
+   * @param timeZone time zone
    * @return OffsetTime value
    * @throws SQLException if column type doesn't permit conversion
    */
@@ -917,32 +971,35 @@ public class TextRowProtocol extends RowProtocol {
     }
 
     ZoneId zoneId = timeZone.toZoneId().normalized();
-    if (ZoneOffset.class.isInstance(zoneId)) {
-      ZoneOffset zoneOffset = ZoneOffset.class.cast(zoneId);
+    if (zoneId instanceof ZoneOffset) {
+      ZoneOffset zoneOffset = (ZoneOffset) zoneId;
       String raw = new String(buf, pos, length, StandardCharsets.UTF_8);
       switch (columnInfo.getColumnType().getSqlType()) {
-
         case Types.TIMESTAMP:
           if (raw.startsWith("0000-00-00 00:00:00")) {
             return null;
           }
           try {
             return ZonedDateTime.parse(raw, TEXT_LOCAL_DATE_TIME.withZone(zoneOffset))
-                .toOffsetDateTime().toOffsetTime();
+                .toOffsetDateTime()
+                .toOffsetTime();
           } catch (DateTimeParseException dateParserEx) {
-            throw new SQLException(raw
-                + " cannot be parse as OffsetTime. time must have \"yyyy-MM-dd HH:mm:ss[.S]\" format");
+            throw new SQLException(
+                raw
+                    + " cannot be parse as OffsetTime. time must have \"yyyy-MM-dd HH:mm:ss[.S]\" format");
           }
 
         case Types.TIME:
           try {
-            LocalTime localTime = LocalTime
-                .parse(raw, DateTimeFormatter.ISO_LOCAL_TIME.withZone(zoneOffset));
+            LocalTime localTime =
+                LocalTime.parse(raw, DateTimeFormatter.ISO_LOCAL_TIME.withZone(zoneOffset));
             return OffsetTime.of(localTime, zoneOffset);
           } catch (DateTimeParseException dateParserEx) {
             throw new SQLException(
-                raw + " cannot be parse as OffsetTime (format is \"HH:mm:ss[.S]\" for data type \""
-                    + columnInfo.getColumnType() + "\")");
+                raw
+                    + " cannot be parse as OffsetTime (format is \"HH:mm:ss[.S]\" for data type \""
+                    + columnInfo.getColumnType()
+                    + "\")");
           }
 
         case Types.VARCHAR:
@@ -951,36 +1008,43 @@ public class TextRowProtocol extends RowProtocol {
           try {
             return OffsetTime.parse(raw, DateTimeFormatter.ISO_OFFSET_TIME);
           } catch (DateTimeParseException dateParserEx) {
-            throw new SQLException(raw
-                + " cannot be parse as OffsetTime (format is \"HH:mm:ss[.S]\" with offset for data type \""
-                + columnInfo.getColumnType() + "\")");
+            throw new SQLException(
+                raw
+                    + " cannot be parse as OffsetTime (format is \"HH:mm:ss[.S]\" with offset for data type \""
+                    + columnInfo.getColumnType()
+                    + "\")");
           }
 
         default:
-          throw new SQLException("Cannot read " + OffsetTime.class.getName() + " using a "
-              + columnInfo.getColumnType().getJavaTypeName() + " field");
+          throw new SQLException(
+              "Cannot read "
+                  + OffsetTime.class.getName()
+                  + " using a "
+                  + columnInfo.getColumnType().getJavaTypeName()
+                  + " field");
       }
     }
 
     if (options.useLegacyDatetimeCode) {
-      //system timezone is not an offset
+      // system timezone is not an offset
       throw new SQLException(
-          "Cannot return an OffsetTime for a TIME field when default timezone is '" + zoneId
+          "Cannot return an OffsetTime for a TIME field when default timezone is '"
+              + zoneId
               + "' (only possible for time-zone offset from Greenwich/UTC, such as +02:00)");
     }
 
-    //server timezone is not an offset
+    // server timezone is not an offset
     throw new SQLException(
-        "Cannot return an OffsetTime for a TIME field when server timezone '" + zoneId
+        "Cannot return an OffsetTime for a TIME field when server timezone '"
+            + zoneId
             + "' (only possible for time-zone offset from Greenwich/UTC, such as +02:00)");
-
   }
 
   /**
    * Get LocalTime format from raw text format.
    *
    * @param columnInfo column information
-   * @param timeZone   time zone
+   * @param timeZone time zone
    * @return LocalTime value
    * @throws SQLException if column type doesn't permit conversion
    */
@@ -1002,33 +1066,36 @@ public class TextRowProtocol extends RowProtocol {
       case Types.LONGVARCHAR:
       case Types.CHAR:
         try {
-          return LocalTime
-              .parse(raw, DateTimeFormatter.ISO_LOCAL_TIME.withZone(timeZone.toZoneId()));
+          return LocalTime.parse(
+              raw, DateTimeFormatter.ISO_LOCAL_TIME.withZone(timeZone.toZoneId()));
         } catch (DateTimeParseException dateParserEx) {
           throw new SQLException(
-              raw + " cannot be parse as LocalTime (format is \"HH:mm:ss[.S]\" for data type \""
-                  + columnInfo.getColumnType() + "\")");
+              raw
+                  + " cannot be parse as LocalTime (format is \"HH:mm:ss[.S]\" for data type \""
+                  + columnInfo.getColumnType()
+                  + "\")");
         }
 
       case Types.TIMESTAMP:
-        ZonedDateTime zonedDateTime = getInternalZonedDateTime(columnInfo, LocalTime.class,
-            timeZone);
-        return zonedDateTime == null ? null
+        ZonedDateTime zonedDateTime =
+            getInternalZonedDateTime(columnInfo, LocalTime.class, timeZone);
+        return zonedDateTime == null
+            ? null
             : zonedDateTime.withZoneSameInstant(ZoneId.systemDefault()).toLocalTime();
 
       default:
         throw new SQLException(
-            "Cannot read LocalTime using a " + columnInfo.getColumnType().getJavaTypeName()
+            "Cannot read LocalTime using a "
+                + columnInfo.getColumnType().getJavaTypeName()
                 + " field");
     }
-
   }
 
   /**
    * Get LocalDate format from raw text format.
    *
    * @param columnInfo column information
-   * @param timeZone   time zone
+   * @param timeZone time zone
    * @return LocalDate value
    * @throws SQLException if column type doesn't permit conversion
    */
@@ -1053,25 +1120,28 @@ public class TextRowProtocol extends RowProtocol {
           return null;
         }
         try {
-          return LocalDate
-              .parse(raw, DateTimeFormatter.ISO_LOCAL_DATE.withZone(timeZone.toZoneId()));
+          return LocalDate.parse(
+              raw, DateTimeFormatter.ISO_LOCAL_DATE.withZone(timeZone.toZoneId()));
         } catch (DateTimeParseException dateParserEx) {
           throw new SQLException(
-              raw + " cannot be parse as LocalDate (format is \"yyyy-MM-dd\" for data type \""
-                  + columnInfo.getColumnType() + "\")");
+              raw
+                  + " cannot be parse as LocalDate (format is \"yyyy-MM-dd\" for data type \""
+                  + columnInfo.getColumnType()
+                  + "\")");
         }
 
       case Types.TIMESTAMP:
-        ZonedDateTime zonedDateTime = getInternalZonedDateTime(columnInfo, LocalDate.class,
-            timeZone);
-        return zonedDateTime == null ? null
+        ZonedDateTime zonedDateTime =
+            getInternalZonedDateTime(columnInfo, LocalDate.class, timeZone);
+        return zonedDateTime == null
+            ? null
             : zonedDateTime.withZoneSameInstant(ZoneId.systemDefault()).toLocalDate();
 
       default:
         throw new SQLException(
-            "Cannot read LocalDate using a " + columnInfo.getColumnType().getJavaTypeName()
+            "Cannot read LocalDate using a "
+                + columnInfo.getColumnType().getJavaTypeName()
                 + " field");
-
     }
   }
 
@@ -1083,5 +1153,4 @@ public class TextRowProtocol extends RowProtocol {
   public boolean isBinaryEncoded() {
     return false;
   }
-
 }
