@@ -1,72 +1,66 @@
 /**
  * EdDSA-Java by str4d
- * <p>
- * To the extent possible under law, the person who associated CC0 with EdDSA-Java has waived all
+ *
+ * <p>To the extent possible under law, the person who associated CC0 with EdDSA-Java has waived all
  * copyright and related or neighboring rights to EdDSA-Java.
- * <p>
- * You should have received a copy of the CC0 legalcode along with this work. If not, see
+ *
+ * <p>You should have received a copy of the CC0 legalcode along with this work. If not, see
  * <https://creativecommons.org/publicdomain/zero/1.0/>.
  */
 package org.mariadb.jdbc.internal.com.send.authentication.ed25519.math;
 
-import java.io.Serializable;
-import java.util.Arrays;
-import org.mariadb.jdbc.internal.com.send.authentication.ed25519.Utils;
+import org.mariadb.jdbc.internal.com.send.authentication.ed25519.*;
+
+import java.io.*;
+import java.util.*;
 
 /**
  * A point $(x,y)$ on an EdDSA curve.
- * <p>
- * Reviewed/commented by Bloody Rookie (nemproject@gmx.de)
- * <p>
- * Literature:<br> [1] Daniel J. Bernstein, Niels Duif, Tanja Lange, Peter Schwabe and Bo-Yin Yang :
- * High-speed high-security signatures<br> [2] Huseyin Hisil, Kenneth Koon-Ho Wong, Gary Carter, Ed
- * Dawson: Twisted Edwards Curves Revisited<br> [3] Daniel J. Bernsteina, Tanja Lange: A complete
- * set of addition laws for incomplete Edwards curves<br> [4] Daniel J. Bernstein, Peter Birkner,
- * Marc Joye, Tanja Lange and Christiane Peters: Twisted Edwards Curves<br> [5] Christiane Pascale
- * Peters: Curves, Codes, and Cryptography (PhD thesis)<br> [6] Daniel J. Bernstein, Peter Birkner,
- * Tanja Lange and Christiane Peters: Optimizing double-base elliptic-curve single-scalar
- * multiplication<br>
+ *
+ * <p>Reviewed/commented by Bloody Rookie (nemproject@gmx.de)
+ *
+ * <p>Literature:<br>
+ * [1] Daniel J. Bernstein, Niels Duif, Tanja Lange, Peter Schwabe and Bo-Yin Yang : High-speed
+ * high-security signatures<br>
+ * [2] Huseyin Hisil, Kenneth Koon-Ho Wong, Gary Carter, Ed Dawson: Twisted Edwards Curves Revisited
+ * <br>
+ * [3] Daniel J. Bernsteina, Tanja Lange: A complete set of addition laws for incomplete Edwards
+ * curves<br>
+ * [4] Daniel J. Bernstein, Peter Birkner, Marc Joye, Tanja Lange and Christiane Peters: Twisted
+ * Edwards Curves<br>
+ * [5] Christiane Pascale Peters: Curves, Codes, and Cryptography (PhD thesis)<br>
+ * [6] Daniel J. Bernstein, Peter Birkner, Tanja Lange and Christiane Peters: Optimizing double-base
+ * elliptic-curve single-scalar multiplication<br>
  *
  * @author str4d
  */
 public class GroupElement implements Serializable {
 
   private static final long serialVersionUID = 2395879087349587L;
-  /**
-   * Variable is package private only so that tests run.
-   */
+  /** Variable is package private only so that tests run. */
   final Curve curve;
-  /**
-   * Variable is package private only so that tests run.
-   */
+  /** Variable is package private only so that tests run. */
   final Representation repr;
-  /**
-   * Variable is package private only so that tests run.
-   */
+  /** Variable is package private only so that tests run. */
   final FieldElement X;
-  /**
-   * Variable is package private only so that tests run.
-   */
+  /** Variable is package private only so that tests run. */
   final FieldElement Y;
-  /**
-   * Variable is package private only so that tests run.
-   */
+  /** Variable is package private only so that tests run. */
   final FieldElement Z;
-  /**
-   * Variable is package private only so that tests run.
-   */
+  /** Variable is package private only so that tests run. */
   final FieldElement T;
   /**
    * Precomputed table for {@link #scalarMultiply(byte[])}, filled if necessary.
-   * <p>
-   * Variable is package private only so that tests run.
+   *
+   * <p>Variable is package private only so that tests run.
    */
   org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement[][] precmp;
   /**
-   * Precomputed table for {@link #doubleScalarMultiplyVariableTime(org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement,
+   * Precomputed table for {@link
+   * #doubleScalarMultiplyVariableTime(org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement,
    * byte[], byte[])}, filled if necessary.
-   * <p>
-   * Variable is package private only so that tests run.
+   *
+   * <p>Variable is package private only so that tests run.
    */
   org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement[] dblPrecmp;
 
@@ -74,11 +68,11 @@ public class GroupElement implements Serializable {
    * Creates a group element for a curve.
    *
    * @param curve The curve.
-   * @param repr  The representation used to represent the group element.
-   * @param X     The $X$ coordinate.
-   * @param Y     The $Y$ coordinate.
-   * @param Z     The $Z$ coordinate.
-   * @param T     The $T$ coordinate.
+   * @param repr The representation used to represent the group element.
+   * @param X The $X$ coordinate.
+   * @param Y The $Y$ coordinate.
+   * @param Z The $Z$ coordinate.
+   * @param T The $T$ coordinate.
    */
   public GroupElement(
       final Curve curve,
@@ -97,20 +91,21 @@ public class GroupElement implements Serializable {
 
   /**
    * Creates a group element for a curve from a given encoded point.
-   * <p>
-   * A point $(x,y)$ is encoded by storing $y$ in bit 0 to bit 254 and the sign of $x$ in bit 255.
-   * $x$ is recovered in the following way:
-   * </p><ul>
-   * <li>$x = sign(x) * \sqrt{(y^2 - 1) / (d * y^2 + 1)} = sign(x) * \sqrt{u / v}$ with $u = y^2 -
-   * 1$ and $v = d * y^2 + 1$.
-   * <li>Setting $β = (u * v^3) * (u * v^7)^{((q - 5) / 8)}$ one has $β^2 = \pm(u / v)$.
-   * <li>If $v * β = -u$ multiply $β$ with $i=\sqrt{-1}$.
-   * <li>Set $x := β$.
-   * <li>If $sign(x) \ne$ bit 255 of $s$ then negate $x$.
+   *
+   * <p>A point $(x,y)$ is encoded by storing $y$ in bit 0 to bit 254 and the sign of $x$ in bit
+   * 255. $x$ is recovered in the following way:
+   *
+   * <ul>
+   *   <li>$x = sign(x) * \sqrt{(y^2 - 1) / (d * y^2 + 1)} = sign(x) * \sqrt{u / v}$ with $u = y^2 -
+   *       1$ and $v = d * y^2 + 1$.
+   *   <li>Setting $β = (u * v^3) * (u * v^7)^{((q - 5) / 8)}$ one has $β^2 = \pm(u / v)$.
+   *   <li>If $v * β = -u$ multiply $β$ with $i=\sqrt{-1}$.
+   *   <li>Set $x := β$.
+   *   <li>If $sign(x) \ne$ bit 255 of $s$ then negate $x$.
    * </ul>
    *
    * @param curve The curve.
-   * @param s     The encoded point.
+   * @param s The encoded point.
    */
   public GroupElement(final Curve curve, final byte[] s) {
     FieldElement x, y, yy, u, v, v3, vxx, check;
@@ -136,9 +131,9 @@ public class GroupElement implements Serializable {
     x = v3.multiply(u).multiply(x);
 
     vxx = x.square().multiply(v);
-    check = vxx.subtract(u);            // vx^2-u
+    check = vxx.subtract(u); // vx^2-u
     if (check.isNonZero()) {
-      check = vxx.add(u);             // vx^2+u
+      check = vxx.add(u); // vx^2+u
 
       if (check.isNonZero()) {
         throw new IllegalArgumentException("not a valid GroupElement");
@@ -162,28 +157,25 @@ public class GroupElement implements Serializable {
    * Creates a new group element in P2 representation.
    *
    * @param curve The curve.
-   * @param X     The $X$ coordinate.
-   * @param Y     The $Y$ coordinate.
-   * @param Z     The $Z$ coordinate.
+   * @param X The $X$ coordinate.
+   * @param Y The $Y$ coordinate.
+   * @param Z The $Z$ coordinate.
    * @return The group element in P2 representation.
    */
   public static org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement p2(
-      final Curve curve,
-      final FieldElement X,
-      final FieldElement Y,
-      final FieldElement Z) {
-    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(curve,
-        Representation.P2, X, Y, Z, null);
+      final Curve curve, final FieldElement X, final FieldElement Y, final FieldElement Z) {
+    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(
+        curve, Representation.P2, X, Y, Z, null);
   }
 
   /**
    * Creates a new group element in P3 representation.
    *
    * @param curve The curve.
-   * @param X     The $X$ coordinate.
-   * @param Y     The $Y$ coordinate.
-   * @param Z     The $Z$ coordinate.
-   * @param T     The $T$ coordinate.
+   * @param X The $X$ coordinate.
+   * @param Y The $Y$ coordinate.
+   * @param Z The $Z$ coordinate.
+   * @param T The $T$ coordinate.
    * @return The group element in P3 representation.
    */
   public static org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement p3(
@@ -192,18 +184,18 @@ public class GroupElement implements Serializable {
       final FieldElement Y,
       final FieldElement Z,
       final FieldElement T) {
-    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(curve,
-        Representation.P3, X, Y, Z, T);
+    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(
+        curve, Representation.P3, X, Y, Z, T);
   }
 
   /**
    * Creates a new group element in P1P1 representation.
    *
    * @param curve The curve.
-   * @param X     The $X$ coordinate.
-   * @param Y     The $Y$ coordinate.
-   * @param Z     The $Z$ coordinate.
-   * @param T     The $T$ coordinate.
+   * @param X The $X$ coordinate.
+   * @param Y The $Y$ coordinate.
+   * @param Z The $Z$ coordinate.
+   * @param T The $T$ coordinate.
    * @return The group element in P1P1 representation.
    */
   public static org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement p1p1(
@@ -212,36 +204,33 @@ public class GroupElement implements Serializable {
       final FieldElement Y,
       final FieldElement Z,
       final FieldElement T) {
-    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(curve,
-        Representation.P1P1, X, Y, Z, T);
+    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(
+        curve, Representation.P1P1, X, Y, Z, T);
   }
 
   /**
    * Creates a new group element in PRECOMP representation.
    *
    * @param curve The curve.
-   * @param ypx   The $y + x$ value.
-   * @param ymx   The $y - x$ value.
-   * @param xy2d  The $2 * d * x * y$ value.
+   * @param ypx The $y + x$ value.
+   * @param ymx The $y - x$ value.
+   * @param xy2d The $2 * d * x * y$ value.
    * @return The group element in PRECOMP representation.
    */
   public static org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement precomp(
-      final Curve curve,
-      final FieldElement ypx,
-      final FieldElement ymx,
-      final FieldElement xy2d) {
-    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(curve,
-        Representation.PRECOMP, ypx, ymx, xy2d, null);
+      final Curve curve, final FieldElement ypx, final FieldElement ymx, final FieldElement xy2d) {
+    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(
+        curve, Representation.PRECOMP, ypx, ymx, xy2d, null);
   }
 
   /**
    * Creates a new group element in CACHED representation.
    *
    * @param curve The curve.
-   * @param YpX   The $Y + X$ value.
-   * @param YmX   The $Y - X$ value.
-   * @param Z     The $Z$ coordinate.
-   * @param T2d   The $2 * d * T$ value.
+   * @param YpX The $Y + X$ value.
+   * @param YmX The $Y - X$ value.
+   * @param Z The $Z$ coordinate.
+   * @param T2d The $2 * d * T$ value.
    * @return The group element in CACHED representation.
    */
   public static org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement cached(
@@ -250,14 +239,14 @@ public class GroupElement implements Serializable {
       final FieldElement YmX,
       final FieldElement Z,
       final FieldElement T2d) {
-    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(curve,
-        Representation.CACHED, YpX, YmX, Z, T2d);
+    return new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement(
+        curve, Representation.CACHED, YpX, YmX, Z, T2d);
   }
 
   /**
    * Convert a to radix 16.
-   * <p>
-   * Method is package private only so that tests run.
+   *
+   * <p>Method is package private only so that tests run.
    *
    * @param a $= a[0]+256*a[1]+...+256^{31} a[31]$
    * @return 64 bytes, each between -8 and 7
@@ -287,11 +276,11 @@ public class GroupElement implements Serializable {
   /**
    * Calculates a sliding-windows base 2 representation for a given value $a$. To learn more about
    * it see [6] page 8.
-   * <p>
-   * Output: $r$ which satisfies $a = r0 * 2^0 + r1 * 2^1 + \dots + r255 * 2^{255}$ with $ri$ in
+   *
+   * <p>Output: $r$ which satisfies $a = r0 * 2^0 + r1 * 2^1 + \dots + r255 * 2^{255}$ with $ri$ in
    * $\{-15, -13, -11, -9, -7, -5, -3, -1, 0, 1, 3, 5, 7, 9, 11, 13, 15\}$
-   * <p>
-   * Method is package private only so that tests run.
+   *
+   * <p>Method is package private only so that tests run.
    *
    * @param a $= a[0]+256*a[1]+\dots+256^{31} a[31]$.
    * @return The byte array $r$ in the above described form.
@@ -441,13 +430,16 @@ public class GroupElement implements Serializable {
   /**
    * Convert a GroupElement from one Representation to another. TODO-CR: Add additional conversion?
    * $r = p$
+   *
+   * <p>Supported conversions:
+   *
    * <p>
-   * Supported conversions:
-   * <p><ul>
-   * <li>P3 $\rightarrow$ P2
-   * <li>P3 $\rightarrow$ CACHED (1 multiply, 1 add, 1 subtract)
-   * <li>P1P1 $\rightarrow$ P2 (3 multiply)
-   * <li>P1P1 $\rightarrow$ P3 (4 multiply)
+   *
+   * <ul>
+   *   <li>P3 $\rightarrow$ P2
+   *   <li>P3 $\rightarrow$ CACHED (1 multiply, 1 add, 1 subtract)
+   *   <li>P1P1 $\rightarrow$ P2 (3 multiply)
+   *   <li>P1P1 $\rightarrow$ P3 (4 multiply)
    *
    * @param repr The representation to convert to.
    * @return A new group element in the given representation.
@@ -469,7 +461,11 @@ public class GroupElement implements Serializable {
           case P3:
             return p3(this.curve, this.X, this.Y, this.Z, this.T);
           case CACHED:
-            return cached(this.curve, this.Y.add(this.X), this.Y.subtract(this.X), this.Z,
+            return cached(
+                this.curve,
+                this.Y.add(this.X),
+                this.Y.subtract(this.X),
+                this.Z,
                 this.T.multiply(this.curve.get2D()));
           default:
             throw new IllegalArgumentException();
@@ -477,11 +473,15 @@ public class GroupElement implements Serializable {
       case P1P1:
         switch (repr) {
           case P2:
-            return p2(this.curve, this.X.multiply(this.T), Y.multiply(this.Z),
-                this.Z.multiply(this.T));
+            return p2(
+                this.curve, this.X.multiply(this.T), Y.multiply(this.Z), this.Z.multiply(this.T));
           case P3:
-            return p3(this.curve, this.X.multiply(this.T), Y.multiply(this.Z),
-                this.Z.multiply(this.T), this.X.multiply(this.Y));
+            return p3(
+                this.curve,
+                this.X.multiply(this.T),
+                Y.multiply(this.Z),
+                this.Z.multiply(this.T),
+                this.X.multiply(this.Y));
           case P1P1:
             return p1p1(this.curve, this.X, this.Y, this.Z, this.T);
           default:
@@ -508,8 +508,8 @@ public class GroupElement implements Serializable {
 
   /**
    * Precomputes several tables.
-   * <p>
-   * The precomputed tables are used for {@link #scalarMultiply(byte[])} and {@link
+   *
+   * <p>The precomputed tables are used for {@link #scalarMultiply(byte[])} and {@link
    * #doubleScalarMultiplyVariableTime(org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement,
    * byte[], byte[])}.
    *
@@ -520,7 +520,8 @@ public class GroupElement implements Serializable {
 
     if (precomputeSingle && this.precmp == null) {
       // Precomputation for single scalar multiplication.
-      this.precmp = new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement[32][8];
+      this.precmp =
+          new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement[32][8];
       // TODO-CR BR: check that this == base point when the method is called.
       Bi = this;
       for (int i = 0; i < 32; i++) {
@@ -529,8 +530,9 @@ public class GroupElement implements Serializable {
           final FieldElement recip = Bij.Z.invert();
           final FieldElement x = Bij.X.multiply(recip);
           final FieldElement y = Bij.Y.multiply(recip);
-          this.precmp[i][j] = precomp(this.curve, y.add(x), y.subtract(x),
-              x.multiply(y).multiply(this.curve.get2D()));
+          this.precmp[i][j] =
+              precomp(
+                  this.curve, y.add(x), y.subtract(x), x.multiply(y).multiply(this.curve.get2D()));
           Bij = Bij.add(Bi.toCached()).toP3();
         }
         // Only every second summand is precomputed (16^2 = 256)
@@ -545,14 +547,15 @@ public class GroupElement implements Serializable {
     if (this.dblPrecmp != null) {
       return;
     }
-    this.dblPrecmp = new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement[8];
+    this.dblPrecmp =
+        new org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement[8];
     Bi = this;
     for (int i = 0; i < 8; i++) {
       final FieldElement recip = Bi.Z.invert();
       final FieldElement x = Bi.X.multiply(recip);
       final FieldElement y = Bi.Y.multiply(recip);
-      this.dblPrecmp[i] = precomp(this.curve, y.add(x), y.subtract(x),
-          x.multiply(y).multiply(this.curve.get2D()));
+      this.dblPrecmp[i] =
+          precomp(this.curve, y.add(x), y.subtract(x), x.multiply(y).multiply(this.curve.get2D()));
       // Bi = edwards(B,edwards(B,Bi))
       Bi = this.add(this.add(Bi.toCached()).toP3().toCached()).toP3();
     }
@@ -561,30 +564,34 @@ public class GroupElement implements Serializable {
   /**
    * Doubles a given group element $p$ in $P^2$ or $P^3$ representation and returns the result in $P
    * \times P$ representation. $r = 2 * p$ where $p = (X : Y : Z)$ or $p = (X : Y : Z : T)$
-   * <p>
-   * $r$ in $P \times P$ representation:
-   * <p>
-   * $r = ((X' : Z'), (Y' : T'))$ where
-   * </p><ul>
-   * <li>$X' = (X + Y)^2 - (Y^2 + X^2)$
-   * <li>$Y' = Y^2 + X^2$
-   * <li>$Z' = y^2 - X^2$
-   * <li>$T' = 2 * Z^2 - (y^2 - X^2)$
-   * </ul><p>
-   * $r$ converted from $P \times P$ to $P^2$ representation:
-   * <p>
-   * $r = (X'' : Y'' : Z'')$ where
-   * </p><ul>
-   * <li>$X'' = X' * Z' = ((X + Y)^2 - Y^2 - X^2) * (2 * Z^2 - (y^2 - X^2))$
-   * <li>$Y'' = Y' * T' = (Y^2 + X^2) * (2 * Z^2 - (y^2 - X^2))$
-   * <li>$Z'' = Z' * T' = (y^2 - X^2) * (2 * Z^2 - (y^2 - X^2))$
-   * </ul><p>
-   * Formula for the $P^2$ representation is in agreement with the formula given in [4] page 12
+   *
+   * <p>$r$ in $P \times P$ representation:
+   *
+   * <p>$r = ((X' : Z'), (Y' : T'))$ where
+   *
+   * <ul>
+   *   <li>$X' = (X + Y)^2 - (Y^2 + X^2)$
+   *   <li>$Y' = Y^2 + X^2$
+   *   <li>$Z' = y^2 - X^2$
+   *   <li>$T' = 2 * Z^2 - (y^2 - X^2)$
+   * </ul>
+   *
+   * <p>$r$ converted from $P \times P$ to $P^2$ representation:
+   *
+   * <p>$r = (X'' : Y'' : Z'')$ where
+   *
+   * <ul>
+   *   <li>$X'' = X' * Z' = ((X + Y)^2 - Y^2 - X^2) * (2 * Z^2 - (y^2 - X^2))$
+   *   <li>$Y'' = Y' * T' = (Y^2 + X^2) * (2 * Z^2 - (y^2 - X^2))$
+   *   <li>$Z'' = Z' * T' = (y^2 - X^2) * (2 * Z^2 - (y^2 - X^2))$
+   * </ul>
+   *
+   * <p>Formula for the $P^2$ representation is in agreement with the formula given in [4] page 12
    * (with $a = -1$) up to a common factor -1 which does not matter:
-   * <p>
-   * $$ B = (X + Y)^2; C = X^2; D = Y^2; E = -C = -X^2; F := E + D = Y^2 - X^2; H = Z^2; J = F − 2 *
-   * H; \\ X3 = (B − C − D) · J = X' * (-T'); \\ Y3 = F · (E − D) = Z' * (-Y'); \\ Z3 = F · J = Z' *
-   * (-T'). $$
+   *
+   * <p>$$ B = (X + Y)^2; C = X^2; D = Y^2; E = -C = -X^2; F := E + D = Y^2 - X^2; H = Z^2; J = F −
+   * 2 * H; \\ X3 = (B − C − D) · J = X' * (-T'); \\ Y3 = F · (E − D) = Z' * (-Y'); \\ Z3 = F · J =
+   * Z' * (-T'). $$
    *
    * @return The P1P1 representation
    */
@@ -609,45 +616,58 @@ public class GroupElement implements Serializable {
   /**
    * GroupElement addition using the twisted Edwards addition law with extended coordinates
    * (Hisil2008).
+   *
+   * <p>this must be in $P^3$ representation and $q$ in PRECOMP representation. $r = p + q$ where $p
+   * = this = (X1 : Y1 : Z1 : T1), q = (q.X, q.Y, q.Z) = (Y2/Z2 + X2/Z2, Y2/Z2 - X2/Z2, 2 * d *
+   * X2/Z2 * Y2/Z2)$
+   *
+   * <p>$r$ in $P \times P$ representation:
+   *
+   * <p>$r = ((X' : Z'), (Y' : T'))$ where
+   *
    * <p>
-   * this must be in $P^3$ representation and $q$ in PRECOMP representation. $r = p + q$ where $p =
-   * this = (X1 : Y1 : Z1 : T1), q = (q.X, q.Y, q.Z) = (Y2/Z2 + X2/Z2, Y2/Z2 - X2/Z2, 2 * d * X2/Z2
-   * * Y2/Z2)$
+   *
+   * <ul>
+   *   <li>$X' = (Y1 + X1) * q.X - (Y1 - X1) * q.Y = ((Y1 + X1) * (Y2 + X2) - (Y1 - X1) * (Y2 - X2))
+   *       * 1/Z2$
+   *   <li>$Y' = (Y1 + X1) * q.X + (Y1 - X1) * q.Y = ((Y1 + X1) * (Y2 + X2) + (Y1 - X1) * (Y2 - X2))
+   *       * 1/Z2$
+   *   <li>$Z' = 2 * Z1 + T1 * q.Z = 2 * Z1 + T1 * 2 * d * X2 * Y2 * 1/Z2^2 = (2 * Z1 * Z2 + 2 * d *
+   *       T1 * T2) * 1/Z2$
+   *   <li>$T' = 2 * Z1 - T1 * q.Z = 2 * Z1 - T1 * 2 * d * X2 * Y2 * 1/Z2^2 = (2 * Z1 * Z2 - 2 * d *
+   *       T1 * T2) * 1/Z2$
+   * </ul>
+   *
+   * <p>Setting $A = (Y1 - X1) * (Y2 - X2), B = (Y1 + X1) * (Y2 + X2), C = 2 * d * T1 * T2, D = 2 *
+   * Z1 * Z2$ we get
+   *
    * <p>
-   * $r$ in $P \times P$ representation:
+   *
+   * <ul>
+   *   <li>$X' = (B - A) * 1/Z2$
+   *   <li>$Y' = (B + A) * 1/Z2$
+   *   <li>$Z' = (D + C) * 1/Z2$
+   *   <li>$T' = (D - C) * 1/Z2$
+   * </ul>
+   *
+   * <p>$r$ converted from $P \times P$ to $P^2$ representation:
+   *
+   * <p>$r = (X'' : Y'' : Z'' : T'')$ where
+   *
    * <p>
-   * $r = ((X' : Z'), (Y' : T'))$ where
-   * <p><ul>
-   * <li>$X' = (Y1 + X1) * q.X - (Y1 - X1) * q.Y = ((Y1 + X1) * (Y2 + X2) - (Y1 - X1) * (Y2 - X2))
-   * * 1/Z2$
-   * <li>$Y' = (Y1 + X1) * q.X + (Y1 - X1) * q.Y = ((Y1 + X1) * (Y2 + X2) + (Y1 - X1) * (Y2 - X2))
-   * * 1/Z2$
-   * <li>$Z' = 2 * Z1 + T1 * q.Z = 2 * Z1 + T1 * 2 * d * X2 * Y2 * 1/Z2^2 = (2 * Z1 * Z2 + 2 * d *
-   * T1 * T2) * 1/Z2$
-   * <li>$T' = 2 * Z1 - T1 * q.Z = 2 * Z1 - T1 * 2 * d * X2 * Y2 * 1/Z2^2 = (2 * Z1 * Z2 - 2 * d *
-   * T1 * T2) * 1/Z2$
-   * </ul><p>
-   * Setting $A = (Y1 - X1) * (Y2 - X2), B = (Y1 + X1) * (Y2 + X2), C = 2 * d * T1 * T2, D = 2 * Z1
-   * * Z2$ we get
-   * <p><ul>
-   * <li>$X' = (B - A) * 1/Z2$
-   * <li>$Y' = (B + A) * 1/Z2$
-   * <li>$Z' = (D + C) * 1/Z2$
-   * <li>$T' = (D - C) * 1/Z2$
-   * </ul><p>
-   * $r$ converted from $P \times P$ to $P^2$ representation:
-   * <p>
-   * $r = (X'' : Y'' : Z'' : T'')$ where
-   * <p><ul>
-   * <li>$X'' = X' * Z' = (B - A) * (D + C) * 1/Z2^2$
-   * <li>$Y'' = Y' * T' = (B + A) * (D - C) * 1/Z2^2$
-   * <li>$Z'' = Z' * T' = (D + C) * (D - C) * 1/Z2^2$
-   * <li>$T'' = X' * Y' = (B - A) * (B + A) * 1/Z2^2$
-   * </ul><p>
-   * TODO-CR BR: Formula for the $P^2$ representation is not in agreement with the formula given in
-   * [2] page 6<br> TODO-CR BR: (the common factor $1/Z2^2$ does not matter):<br> $$ E = B - A, F =
-   * D - C, G = D + C, H = B + A \\ X3 = E * F = (B - A) * (D - C); \\ Y3 = G * H = (D + C) * (B +
-   * A); \\ Z3 = F * G = (D - C) * (D + C); \\ T3 = E * H = (B - A) * (B + A); $$
+   *
+   * <ul>
+   *   <li>$X'' = X' * Z' = (B - A) * (D + C) * 1/Z2^2$
+   *   <li>$Y'' = Y' * T' = (B + A) * (D - C) * 1/Z2^2$
+   *   <li>$Z'' = Z' * T' = (D + C) * (D - C) * 1/Z2^2$
+   *   <li>$T'' = X' * Y' = (B - A) * (B + A) * 1/Z2^2$
+   * </ul>
+   *
+   * <p>TODO-CR BR: Formula for the $P^2$ representation is not in agreement with the formula given
+   * in [2] page 6<br>
+   * TODO-CR BR: (the common factor $1/Z2^2$ does not matter):<br>
+   * $$ E = B - A, F = D - C, G = D + C, H = B + A \\ X3 = E * F = (B - A) * (D - C); \\ Y3 = G * H
+   * = (D + C) * (B + A); \\ Z3 = F * G = (D - C) * (D + C); \\ T3 = E * H = (B - A) * (B + A); $$
    *
    * @param q the PRECOMP representation of the GroupElement to add.
    * @return the P1P1 representation of the result.
@@ -674,12 +694,12 @@ public class GroupElement implements Serializable {
   /**
    * GroupElement subtraction using the twisted Edwards addition law with extended coordinates
    * (Hisil2008).
-   * <p>
-   * this must be in $P^3$ representation and $q$ in PRECOMP representation. $r = p - q$ where $p =
-   * this = (X1 : Y1 : Z1 : T1), q = (q.X, q.Y, q.Z) = (Y2/Z2 + X2/Z2, Y2/Z2 - X2/Z2, 2 * d * X2/Z2
-   * * Y2/Z2)$
-   * <p>
-   * Negating $q$ means negating the value of $X2$ and $T2$ (the latter is irrelevant here). The
+   *
+   * <p>this must be in $P^3$ representation and $q$ in PRECOMP representation. $r = p - q$ where $p
+   * = this = (X1 : Y1 : Z1 : T1), q = (q.X, q.Y, q.Z) = (Y2/Z2 + X2/Z2, Y2/Z2 - X2/Z2, 2 * d *
+   * X2/Z2 * Y2/Z2)$
+   *
+   * <p>Negating $q$ means negating the value of $X2$ and $T2$ (the latter is irrelevant here). The
    * formula is in accordance to {@link #madd the above addition}.
    *
    * @param q the PRECOMP representation of the GroupElement to subtract.
@@ -707,26 +727,30 @@ public class GroupElement implements Serializable {
   /**
    * GroupElement addition using the twisted Edwards addition law with extended coordinates
    * (Hisil2008).
-   * <p>
-   * this must be in $P^3$ representation and $q$ in CACHED representation. $r = p + q$ where $p =
-   * this = (X1 : Y1 : Z1 : T1), q = (q.X, q.Y, q.Z, q.T) = (Y2 + X2, Y2 - X2, Z2, 2 * d * T2)$
-   * <p>
-   * $r$ in $P \times P$ representation:
-   * </p><ul>
-   * <li>$X' = (Y1 + X1) * (Y2 + X2) - (Y1 - X1) * (Y2 - X2)$
-   * <li>$Y' = (Y1 + X1) * (Y2 + X2) + (Y1 - X1) * (Y2 - X2)$
-   * <li>$Z' = 2 * Z1 * Z2 + 2 * d * T1 * T2$
-   * <li>$T' = 2 * Z1 * T2 - 2 * d * T1 * T2$
-   * </ul><p>
-   * Setting $A = (Y1 - X1) * (Y2 - X2), B = (Y1 + X1) * (Y2 + X2), C = 2 * d * T1 * T2, D = 2 * Z1
-   * * Z2$ we get
-   * </p><ul>
-   * <li>$X' = (B - A)$
-   * <li>$Y' = (B + A)$
-   * <li>$Z' = (D + C)$
-   * <li>$T' = (D - C)$
-   * </ul><p>
-   * Same result as in {@link #madd} (up to a common factor which does not matter).
+   *
+   * <p>this must be in $P^3$ representation and $q$ in CACHED representation. $r = p + q$ where $p
+   * = this = (X1 : Y1 : Z1 : T1), q = (q.X, q.Y, q.Z, q.T) = (Y2 + X2, Y2 - X2, Z2, 2 * d * T2)$
+   *
+   * <p>$r$ in $P \times P$ representation:
+   *
+   * <ul>
+   *   <li>$X' = (Y1 + X1) * (Y2 + X2) - (Y1 - X1) * (Y2 - X2)$
+   *   <li>$Y' = (Y1 + X1) * (Y2 + X2) + (Y1 - X1) * (Y2 - X2)$
+   *   <li>$Z' = 2 * Z1 * Z2 + 2 * d * T1 * T2$
+   *   <li>$T' = 2 * Z1 * T2 - 2 * d * T1 * T2$
+   * </ul>
+   *
+   * <p>Setting $A = (Y1 - X1) * (Y2 - X2), B = (Y1 + X1) * (Y2 + X2), C = 2 * d * T1 * T2, D = 2 *
+   * Z1 * Z2$ we get
+   *
+   * <ul>
+   *   <li>$X' = (B - A)$
+   *   <li>$Y' = (B + A)$
+   *   <li>$Z' = (D + C)$
+   *   <li>$T' = (D - C)$
+   * </ul>
+   *
+   * <p>Same result as in {@link #madd} (up to a common factor which does not matter).
    *
    * @param q the CACHED representation of the GroupElement to add.
    * @return the P1P1 representation of the result.
@@ -754,10 +778,10 @@ public class GroupElement implements Serializable {
   /**
    * GroupElement subtraction using the twisted Edwards addition law with extended coordinates
    * (Hisil2008).
-   * <p>
-   * $r = p - q$
-   * <p>
-   * Negating $q$ means negating the value of the coordinate $X2$ and $T2$. The formula is in
+   *
+   * <p>$r = p - q$
+   *
+   * <p>Negating $q$ means negating the value of the coordinate $X2$ and $T2$. The formula is in
    * accordance to {@link #add the above addition}.
    *
    * @param q the PRECOMP representation of the GroupElement to subtract.
@@ -785,8 +809,8 @@ public class GroupElement implements Serializable {
 
   /**
    * Negates this group element by subtracting it from the neutral group element.
-   * <p>
-   * TODO-CR BR: why not simply negate the coordinates $X$ and $T$?
+   *
+   * <p>TODO-CR BR: why not simply negate the coordinates $X$ and $T$?
    *
    * @return The negative of this group element.
    */
@@ -807,10 +831,12 @@ public class GroupElement implements Serializable {
     if (obj == this) {
       return true;
     }
-    if (!(obj instanceof org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement)) {
+    if (!(obj
+        instanceof org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement)) {
       return false;
     }
-    org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement ge = (org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement) obj;
+    org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement ge =
+        (org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement) obj;
     if (!this.repr.equals(ge.repr)) {
       try {
         ge = ge.toRep(this.repr);
@@ -856,53 +882,57 @@ public class GroupElement implements Serializable {
 
   /**
    * Constant-time conditional move.
-   * <p>
-   * Replaces this with $u$ if $b == 1$.<br> Replaces this with this if $b == 0$.
-   * <p>
-   * Method is package private only so that tests run.
+   *
+   * <p>Replaces this with $u$ if $b == 1$.<br>
+   * Replaces this with this if $b == 0$.
+   *
+   * <p>Method is package private only so that tests run.
    *
    * @param u The group element to return if $b == 1$.
    * @param b in $\{0, 1\}$
    * @return $u$ if $b == 1$; this if $b == 0$. Results undefined if $b$ is not in $\{0, 1\}$.
    */
   org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement cmov(
-          final org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement u, final int b) {
+      final org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement u,
+      final int b) {
     return precomp(curve, X.cmov(u.X, b), Y.cmov(u.Y, b), Z.cmov(u.Z, b));
   }
 
   /**
    * Look up $16^i r_i B$ in the precomputed table.
-   * <p>
-   * No secret array indices, no secret branching. Constant time.
-   * <p>
-   * Must have previously precomputed.
-   * <p>
-   * Method is package private only so that tests run.
+   *
+   * <p>No secret array indices, no secret branching. Constant time.
+   *
+   * <p>Must have previously precomputed.
+   *
+   * <p>Method is package private only so that tests run.
    *
    * @param pos $= i/2$ for $i$ in $\{0, 2, 4,..., 62\}$
-   * @param b   $= r_i$
+   * @param b $= r_i$
    * @return the GroupElement
    */
-  org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement select(final int pos, final int b) {
+  org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement select(
+      final int pos, final int b) {
     // Is r_i negative?
     final int bnegative = Utils.negative(b);
     // |r_i|
     final int babs = b - (((-bnegative) & b) << 1);
 
     // 16^i |r_i| B
-    final org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement t = this.curve
-        .getZero(Representation.PRECOMP)
-        .cmov(this.precmp[pos][0], Utils.equal(babs, 1))
-        .cmov(this.precmp[pos][1], Utils.equal(babs, 2))
-        .cmov(this.precmp[pos][2], Utils.equal(babs, 3))
-        .cmov(this.precmp[pos][3], Utils.equal(babs, 4))
-        .cmov(this.precmp[pos][4], Utils.equal(babs, 5))
-        .cmov(this.precmp[pos][5], Utils.equal(babs, 6))
-        .cmov(this.precmp[pos][6], Utils.equal(babs, 7))
-        .cmov(this.precmp[pos][7], Utils.equal(babs, 8));
+    final org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement t =
+        this.curve
+            .getZero(Representation.PRECOMP)
+            .cmov(this.precmp[pos][0], Utils.equal(babs, 1))
+            .cmov(this.precmp[pos][1], Utils.equal(babs, 2))
+            .cmov(this.precmp[pos][2], Utils.equal(babs, 3))
+            .cmov(this.precmp[pos][3], Utils.equal(babs, 4))
+            .cmov(this.precmp[pos][4], Utils.equal(babs, 5))
+            .cmov(this.precmp[pos][5], Utils.equal(babs, 6))
+            .cmov(this.precmp[pos][6], Utils.equal(babs, 7))
+            .cmov(this.precmp[pos][7], Utils.equal(babs, 8));
     // -16^i |r_i| B
-    final org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement tminus = precomp(curve, t.Y,
-        t.X, t.Z.negate());
+    final org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement tminus =
+        precomp(curve, t.Y, t.X, t.Z.negate());
     // 16^i r_i B
     return t.cmov(tminus, bnegative);
   }
@@ -911,8 +941,8 @@ public class GroupElement implements Serializable {
    * $h = a * B$ where $a = a[0]+256*a[1]+\dots+256^{31} a[31]$ and $B$ is this point. If its lookup
    * table has not been precomputed, it will be at the start of the method (and cached for later
    * calls). Constant time.
-   * <p>
-   * Preconditions: (TODO: Check this applies here) $a[31] \le 127$
+   *
+   * <p>Preconditions: (TODO: Check this applies here) $a[31] \le 127$
    *
    * @param a $= a[0]+256*a[1]+\dots+256^{31} a[31]$
    * @return the GroupElement
@@ -924,13 +954,13 @@ public class GroupElement implements Serializable {
 
     final byte[] e = toRadix16(a);
 
-    org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement h = this.curve
-        .getZero(Representation.P3);
+    org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement h =
+        this.curve.getZero(Representation.P3);
     synchronized (this) {
       // TODO: Get opinion from a crypto professional.
       // This should in practice never be necessary, the only point that
       // this should get called on is EdDSA's B.
-      //precompute();
+      // precompute();
       for (i = 1; i < 64; i += 2) {
         t = select(i / 2, e[i]);
         h = h.madd(t).toP3();
@@ -950,23 +980,25 @@ public class GroupElement implements Serializable {
   /**
    * $r = a * A + b * B$ where $a = a[0]+256*a[1]+\dots+256^{31} a[31]$, $b =
    * b[0]+256*b[1]+\dots+256^{31} b[31]$ and $B$ is this point.
-   * <p>
-   * $A$ must have been previously precomputed.
+   *
+   * <p>$A$ must have been previously precomputed.
    *
    * @param A in P3 representation.
    * @param a $= a[0]+256*a[1]+\dots+256^{31} a[31]$
    * @param b $= b[0]+256*b[1]+\dots+256^{31} b[31]$
    * @return the GroupElement
    */
-  public org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement doubleScalarMultiplyVariableTime(
-          final org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement A, final byte[] a,
+  public org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement
+      doubleScalarMultiplyVariableTime(
+          final org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement A,
+          final byte[] a,
           final byte[] b) {
     // TODO-CR BR: A check that this is the base point is needed.
     final byte[] aslide = slide(a);
     final byte[] bslide = slide(b);
 
-    org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement r = this.curve
-        .getZero(Representation.P2);
+    org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement r =
+        this.curve.getZero(Representation.P2);
 
     int i;
     for (i = 255; i >= 0; --i) {
@@ -980,7 +1012,7 @@ public class GroupElement implements Serializable {
       // TODO: Get opinion from a crypto professional.
       // This should in practice never be necessary, the only point that
       // this should get called on is EdDSA's B.
-      //precompute();
+      // precompute();
       for (; i >= 0; --i) {
         org.mariadb.jdbc.internal.com.send.authentication.ed25519.math.GroupElement t = r.dbl();
 
@@ -1042,34 +1074,25 @@ public class GroupElement implements Serializable {
 
   /**
    * Available representations for a group element.
+   *
    * <ul>
-   * <li>P2: Projective representation $(X:Y:Z)$ satisfying $x=X/Z, y=Y/Z$.
-   * <li>P3: Extended projective representation $(X:Y:Z:T)$ satisfying $x=X/Z, y=Y/Z, XY=ZT$.
-   * <li>P1P1: Completed representation $((X:Z), (Y:T))$ satisfying $x=X/Z, y=Y/T$.
-   * <li>PRECOMP: Precomputed representation $(y+x, y-x, 2dxy)$.
-   * <li>CACHED: Cached representation $(Y+X, Y-X, Z, 2dT)$
+   *   <li>P2: Projective representation $(X:Y:Z)$ satisfying $x=X/Z, y=Y/Z$.
+   *   <li>P3: Extended projective representation $(X:Y:Z:T)$ satisfying $x=X/Z, y=Y/Z, XY=ZT$.
+   *   <li>P1P1: Completed representation $((X:Z), (Y:T))$ satisfying $x=X/Z, y=Y/T$.
+   *   <li>PRECOMP: Precomputed representation $(y+x, y-x, 2dxy)$.
+   *   <li>CACHED: Cached representation $(Y+X, Y-X, Z, 2dT)$
    * </ul>
    */
   public enum Representation {
-    /**
-     * Projective ($P^2$): $(X:Y:Z)$ satisfying $x=X/Z, y=Y/Z$
-     */
+    /** Projective ($P^2$): $(X:Y:Z)$ satisfying $x=X/Z, y=Y/Z$ */
     P2,
-    /**
-     * Extended ($P^3$): $(X:Y:Z:T)$ satisfying $x=X/Z, y=Y/Z, XY=ZT$
-     */
+    /** Extended ($P^3$): $(X:Y:Z:T)$ satisfying $x=X/Z, y=Y/Z, XY=ZT$ */
     P3,
-    /**
-     * Completed ($P \times P$): $((X:Z),(Y:T))$ satisfying $x=X/Z, y=Y/T$
-     */
+    /** Completed ($P \times P$): $((X:Z),(Y:T))$ satisfying $x=X/Z, y=Y/T$ */
     P1P1,
-    /**
-     * Precomputed (Duif): $(y+x,y-x,2dxy)$
-     */
+    /** Precomputed (Duif): $(y+x,y-x,2dxy)$ */
     PRECOMP,
-    /**
-     * Cached: $(Y+X,Y-X,Z,2dT)$
-     */
+    /** Cached: $(Y+X,Y-X,Z,2dT)$ */
     CACHED
   }
 }
