@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,47 +52,25 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import com.sun.jna.*;
+import org.junit.*;
+import org.junit.rules.*;
+import org.junit.runner.*;
+import org.mariadb.jdbc.failover.*;
+import org.mariadb.jdbc.internal.failover.*;
+import org.mariadb.jdbc.internal.protocol.*;
+import org.mariadb.jdbc.util.*;
 
-import com.sun.jna.Platform;
-import java.io.IOException;
-import java.lang.Thread.State;
-import java.lang.reflect.Method;
-import java.net.InetAddress;
-import java.net.UnknownHostException;
-import java.sql.Connection;
-import java.sql.DatabaseMetaData;
-import java.sql.DriverManager;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.SQLNonTransientConnectionException;
-import java.sql.Statement;
-import java.text.DecimalFormat;
-import java.text.NumberFormat;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.Map;
-import java.util.Properties;
-import java.util.Random;
-import java.util.Set;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-import org.junit.AfterClass;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Rule;
-import org.junit.rules.TestRule;
-import org.junit.rules.TestWatcher;
-import org.junit.runner.Description;
-import org.mariadb.jdbc.failover.TcpProxy;
-import org.mariadb.jdbc.internal.failover.AbstractMastersListener;
-import org.mariadb.jdbc.internal.protocol.Protocol;
-import org.mariadb.jdbc.internal.util.Options;
+import java.io.*;
+import java.lang.Thread.*;
+import java.lang.reflect.*;
+import java.net.*;
+import java.sql.*;
+import java.text.*;
+import java.util.*;
+import java.util.regex.*;
+
+import static org.junit.Assert.*;
 
 /**
  * Base util class. For testing mvn test -DdbUrl=jdbc:mariadb://localhost:3306/testj?user=root
@@ -107,7 +85,7 @@ public class BaseTest {
   private static final Set<String> tempViewList = new HashSet<>();
   private static final Set<String> tempProcedureList = new HashSet<>();
   private static final Set<String> tempFunctionList = new HashSet<>();
-  private static final NumberFormat numberFormat = DecimalFormat.getInstance();
+  private static final NumberFormat numberFormat = DecimalFormat.getInstance(Locale.ROOT);
   protected static String connU;
   protected static String connUri;
   protected static String connDnsUri;
@@ -123,64 +101,81 @@ public class BaseTest {
   protected static boolean doPrecisionTest = true;
   private static TcpProxy proxy = null;
   private static UrlParser urlParser;
+
   @Rule
-  public TestRule watcher = new TestWatcher() {
-    private long ttime;
+  public TestRule watcher =
+      new TestWatcher() {
+        private long ttime;
 
-    protected void starting(Description description) {
-      if (testSingleHost) {
-        System.out.println(
-            "start test : " + description.getClassName() + "." + description.getMethodName());
-        ttime = System.nanoTime();
-      }
-    }
-
-    //execute another query to ensure connection is stable
-    protected void finished(Description description) {
-      if (testSingleHost) {
-        Random random = new Random();
-        int randInt = random.nextInt();
-        try (PreparedStatement preparedStatement = sharedConnection
-            .prepareStatement("SELECT " + randInt)) {
-          ResultSet rs = preparedStatement.executeQuery();
-          assertTrue(rs.next());
-          assertEquals(randInt, rs.getInt(1));
-        } catch (SQLNonTransientConnectionException connFail) {
-          connFail.printStackTrace();
-          try {
-              beforeClassBaseTest();
-            } catch (SQLException e) {
-              System.out.println("ERROR reconnecting");
-              e.printStackTrace();
-            }
-        } catch (Exception e) {
-          e.printStackTrace();
-          fail("Prepare after test fail for " + description.getClassName() + "." + description
-              .getMethodName());
+        protected void starting(Description description) {
+          if (testSingleHost) {
+            System.out.println(
+                "start test : " + description.getClassName() + "." + description.getMethodName());
+            ttime = System.nanoTime();
+          }
         }
-      }
-    }
 
-    protected void succeeded(Description description) {
-      if (testSingleHost) {
-        System.out.println(
-            "finished test success : " + description.getClassName() + "." + description
-                .getMethodName()
-                + " after " + numberFormat.format(((double) System.nanoTime() - ttime) / 1000000)
-                + " ms");
-      }
-    }
+        // execute another query to ensure connection is stable
+        protected void finished(Description description) {
+          if (testSingleHost) {
+            Random random = new Random();
+            int randInt = random.nextInt();
+            try (PreparedStatement preparedStatement =
+                sharedConnection.prepareStatement("SELECT " + randInt)) {
+              ResultSet rs = preparedStatement.executeQuery();
+              assertTrue(rs.next());
+              assertEquals(randInt, rs.getInt(1));
+            } catch (SQLNonTransientConnectionException connFail) {
+              connFail.printStackTrace();
+              try {
+                beforeClassBaseTest();
+              } catch (SQLException e) {
+                System.out.println("ERROR reconnecting");
+                e.printStackTrace();
+              }
+              fail(
+                  "Prepare after test fail for "
+                      + description.getClassName()
+                      + "."
+                      + description.getMethodName());
 
-    protected void failed(Throwable throwable, Description description) {
-      if (testSingleHost) {
-        System.out.println(
-            "finished test failed : " + description.getClassName() + "." + description
-                .getMethodName()
-                + " after " + numberFormat.format(((double) System.nanoTime() - ttime) / 1000000)
-                + " ms");
-      }
-    }
-  };
+            } catch (Exception e) {
+              e.printStackTrace();
+              fail(
+                  "Prepare after test fail for "
+                      + description.getClassName()
+                      + "."
+                      + description.getMethodName());
+            }
+          }
+        }
+
+        protected void succeeded(Description description) {
+          if (testSingleHost) {
+            System.out.println(
+                "finished test success : "
+                    + description.getClassName()
+                    + "."
+                    + description.getMethodName()
+                    + " after "
+                    + numberFormat.format(((double) System.nanoTime() - ttime) / 1000000)
+                    + " ms");
+          }
+        }
+
+        protected void failed(Throwable throwable, Description description) {
+          if (testSingleHost) {
+            System.out.println(
+                "finished test failed : "
+                    + description.getClassName()
+                    + "."
+                    + description.getMethodName()
+                    + " after "
+                    + numberFormat.format(((double) System.nanoTime() - ttime) / 1000000)
+                    + " ms");
+          }
+        }
+      };
 
   /**
    * Initialization.
@@ -213,8 +208,8 @@ public class BaseTest {
       String additionalParameters;
       if ((dbIndex < paramIndex && dbIndex < 0) || (dbIndex > paramIndex && paramIndex > -1)) {
         additionalParameters = urlSecondPart.substring(paramIndex);
-      } else if ((dbIndex < paramIndex && dbIndex > -1) || (dbIndex > paramIndex
-          && paramIndex < 0)) {
+      } else if ((dbIndex < paramIndex && dbIndex > -1)
+          || (dbIndex > paramIndex && paramIndex < 0)) {
         additionalParameters = urlSecondPart.substring(dbIndex);
       } else {
         additionalParameters = null;
@@ -244,17 +239,31 @@ public class BaseTest {
 
       String dbVersion = sharedConnection.getMetaData().getDatabaseProductVersion();
       doPrecisionTest =
-          isMariadbServer() || !dbVersion.startsWith("5.5"); //MySQL 5.5 doesn't support precision
+          isMariadbServer() || !dbVersion.startsWith("5.5"); // MySQL 5.5 doesn't support precision
     }
   }
 
   private static void setUri() {
-    connU = "jdbc:mariadb://" + ((hostname == null) ? "localhost" : hostname) + ":" + port + "/"
-        + ((database == null) ? "" : database);
-    connUri = connU + "?" + parameters
-        + (password != null && !"".equals(password) ? "&password=" + password : "");
-    connDnsUri = "jdbc:mariadb://mariadb.example.com:" + port + "/" + database + "?" + parameters
-        + (password != null && !"".equals(password) ? "&password=" + password : "");
+    connU =
+        "jdbc:mariadb://"
+            + ((hostname == null) ? "localhost" : hostname)
+            + ":"
+            + port
+            + "/"
+            + ((database == null) ? "" : database);
+    connUri =
+        connU
+            + "?"
+            + parameters
+            + (password != null && !"".equals(password) ? "&password=" + password : "");
+    connDnsUri =
+        "jdbc:mariadb://mariadb.example.com:"
+            + port
+            + "/"
+            + database
+            + "?"
+            + parameters
+            + (password != null && !"".equals(password) ? "&password=" + password : "");
   }
 
   /**
@@ -271,7 +280,7 @@ public class BaseTest {
           try {
             stmt.execute("DROP VIEW IF EXISTS " + viewName);
           } catch (SQLException e) {
-            //eat exception
+            // eat exception
           }
         }
       }
@@ -281,7 +290,7 @@ public class BaseTest {
           try {
             stmt.execute("DROP TABLE IF EXISTS " + tableName);
           } catch (SQLException e) {
-            //eat exception
+            // eat exception
           }
         }
       }
@@ -291,7 +300,7 @@ public class BaseTest {
           try {
             stmt.execute("DROP procedure IF EXISTS " + procedureName);
           } catch (SQLException e) {
-            //eat exception
+            // eat exception
           }
         }
       }
@@ -301,7 +310,7 @@ public class BaseTest {
           try {
             stmt.execute("DROP FUNCTION IF EXISTS " + functionName);
           } catch (SQLException e) {
-            //eat exception
+            // eat exception
           }
         }
       }
@@ -312,13 +321,20 @@ public class BaseTest {
         e.printStackTrace();
       }
     }
-    Iterator<Thread> it = Thread.getAllStackTraces().keySet().iterator();
-    Thread thread;
-
-    while (it.hasNext()) {
-      thread = it.next();
-      if (thread.getName().contains("MariaDb-bulk-")) {
-        assertEquals(State.WAITING, thread.getState());
+    if (!Platform.isWindows()) {
+      Iterator<Thread> it = Thread.getAllStackTraces().keySet().iterator();
+      Thread thread;
+      while (it.hasNext()) {
+        thread = it.next();
+        if (thread.getName().contains("MariaDb-bulk-")) {
+          if (thread.getState() != State.WAITING) {
+            // print stack trace to console.
+            for (StackTraceElement ste : thread.getStackTrace()) {
+              System.out.println(ste);
+            }
+          }
+          assertEquals(State.WAITING, thread.getState());
+        }
       }
     }
   }
@@ -331,7 +347,7 @@ public class BaseTest {
   /**
    * Create a table that will be detroyed a the end of tests.
    *
-   * @param tableName    table name
+   * @param tableName table name
    * @param tableColumns table columns
    * @throws SQLException exception
    */
@@ -342,9 +358,9 @@ public class BaseTest {
   /**
    * Create a table that will be detroyed a the end of tests.
    *
-   * @param tableName    table name
+   * @param tableName table name
    * @param tableColumns table columns
-   * @param engine       engine type
+   * @param engine engine type
    * @throws SQLException exception
    */
   public static void createTable(String tableName, String tableColumns, String engine)
@@ -353,8 +369,12 @@ public class BaseTest {
       Statement stmt = sharedConnection.createStatement();
       stmt.execute("drop table if exists " + tableName);
       stmt.execute(
-          "create table " + tableName + " (" + tableColumns + ") " + ((engine != null) ? engine
-              : ""));
+          "create table "
+              + tableName
+              + " ("
+              + tableColumns
+              + ") "
+              + ((engine != null) ? engine : ""));
       if (!tempFunctionList.contains(tableName)) {
         tempTableList.add(tableName);
       }
@@ -364,7 +384,7 @@ public class BaseTest {
   /**
    * Create a view that will be detroyed a the end of tests.
    *
-   * @param viewName     table name
+   * @param viewName table name
    * @param tableColumns table columns
    * @throws SQLException exception
    */
@@ -441,6 +461,18 @@ public class BaseTest {
     }
   }
 
+  /**
+   * Check if version if at minimum the version asked.
+   *
+   * @param major database major version
+   * @param minor database minor version
+   * @param patch database patch version
+   * @throws SQLException exception
+   */
+  public static boolean minVersion(int major, int minor, int patch) {
+    return ((MariaDbConnection) sharedConnection).versionGreaterOrEqual(major, minor, patch);
+  }
+
   /**
    * Indicate if there is a anonymous user.
    *
@@ -450,8 +482,8 @@ public class BaseTest {
   public boolean anonymousUser() throws SQLException {
     if (testSingleHost) {
       Statement stmt = sharedConnection.createStatement();
-      ResultSet rs = stmt
-          .executeQuery("SELECT * FROM mysql.user u where u.Host='localhost' and u.User=''");
+      ResultSet rs =
+          stmt.executeQuery("SELECT * FROM mysql.user u where u.Host='localhost' and u.User=''");
       return rs.next();
     }
     return false;
@@ -473,14 +505,16 @@ public class BaseTest {
     try {
       hostAddress = tmpUrlParser.getHostAddresses().get(0);
       proxy = new TcpProxy(hostAddress.host, hostAddress.port);
-      sockethosts += "address=(host=localhost)(port=" + proxy.getLocalPort() + ")"
-          + ((hostAddress.type != null) ? "(type=" + hostAddress.type + ")" : "");
+      sockethosts +=
+          "address=(host=localhost)(port="
+              + proxy.getLocalPort()
+              + ")"
+              + ((hostAddress.type != null) ? "(type=" + hostAddress.type + ")" : "");
     } catch (IOException e) {
       e.printStackTrace();
     }
 
     return openConnection("jdbc:mariadb://" + sockethosts + "/" + connUri.split("/")[3], info);
-
   }
 
   /**
@@ -492,9 +526,7 @@ public class BaseTest {
     proxy.restart(millissecond);
   }
 
-  /**
-   * Stop proxy.
-   */
+  /** Stop proxy. */
   public void stopProxy() {
     proxy.stop();
   }
@@ -507,22 +539,18 @@ public class BaseTest {
     proxy.removeDelay();
   }
 
-  /**
-   * Restart proxy.
-   */
+  /** Restart proxy. */
   public void restartProxy() {
     proxy.restart();
   }
 
-  /**
-   * Clean proxies.
-   */
+  /** Clean proxies. */
   public void closeProxy() {
     try {
       proxy.stop();
       proxy = null;
     } catch (Exception e) {
-      //Eat exception
+      // Eat exception
     }
   }
 
@@ -579,10 +607,13 @@ public class BaseTest {
   }
 
   protected Connection setBlankConnection(String parameters) throws SQLException {
-    return openConnection(connU
-        + "?user=" + username
-        + (password != null && !"".equals(password) ? "&password=" + password : "")
-        + parameters, null);
+    return openConnection(
+        connU
+            + "?user="
+            + username
+            + (password != null && !"".equals(password) ? "&password=" + password : "")
+            + parameters,
+        null);
   }
 
   protected Connection setConnection() throws SQLException {
@@ -630,18 +661,21 @@ public class BaseTest {
   }
 
   protected Connection setDnsConnection(String parameters) throws SQLException {
-    String connU = "jdbc:mariadb://mariadb.example.com:" + port + "/"
-        + ((database == null) ? "" : database);
-    String connUri = connU + "?user=" + username
-        + (password != null && !"".equals(password) ? "&password=" + password : "")
-        + (parameters != null ? "&" + parameters : "");
+    String connU =
+        "jdbc:mariadb://mariadb.example.com:" + port + "/" + ((database == null) ? "" : database);
+    String connUri =
+        connU
+            + "?user="
+            + username
+            + (password != null && !"".equals(password) ? "&password=" + password : "")
+            + (parameters != null ? "&" + parameters : "");
     return openConnection(connUri + parameters, null);
   }
 
   /**
    * Permit to reconstruct a connection.
    *
-   * @param uri  base uri
+   * @param uri base uri
    * @param info additionnal properties
    * @return A connection
    * @throws SQLException is any error occur
@@ -670,7 +704,7 @@ public class BaseTest {
         return rs.getInt(2) > 0;
       }
     } catch (SQLException sqle) {
-      //skip
+      // skip
     }
     return false;
   }
@@ -712,7 +746,7 @@ public class BaseTest {
   /**
    * Check if max_allowed_packet value is equal or greater then 20m.
    *
-   * @param testName       test method name
+   * @param testName test method name
    * @param displayMessage message to display in case of error.
    * @return true if max_allowed_packet value is equal or greater then 20m.
    * @throws SQLException if connection fail
@@ -750,7 +784,7 @@ public class BaseTest {
   /**
    * Check if max_allowed_packet value is equal or greater then 40m.
    *
-   * @param testName   test method name
+   * @param testName test method name
    * @param displayMsg message to display in case of error.
    * @return true if max_allowed_packet value is equal or greater then 40m.
    * @throws SQLException if connection fail
@@ -784,15 +818,22 @@ public class BaseTest {
     boolean superPrivilege = false;
     try (Statement st = sharedConnection.createStatement()) {
       // first test for specific user and host combination
-      try (ResultSet rs = st.executeQuery(
-          "SELECT Super_Priv FROM mysql.user WHERE user = '" + username + "' AND host = '"
-              + hostname + "'")) {
+      try (ResultSet rs =
+          st.executeQuery(
+              "SELECT Super_Priv FROM mysql.user WHERE user = '"
+                  + username
+                  + "' AND host = '"
+                  + hostname
+                  + "'")) {
         if (rs.next()) {
           superPrivilege = (rs.getString(1).equals("Y"));
         } else {
           // then check for user on whatever (%) host
-          try (ResultSet rs2 = st.executeQuery(
-              "SELECT Super_Priv FROM mysql.user WHERE user = '" + username + "' AND host = '%'")) {
+          try (ResultSet rs2 =
+              st.executeQuery(
+                  "SELECT Super_Priv FROM mysql.user WHERE user = '"
+                      + username
+                      + "' AND host = '%'")) {
             if (rs2.next()) {
               superPrivilege = (rs2.getString(1).equals("Y"));
             }
@@ -802,8 +843,12 @@ public class BaseTest {
     }
 
     if (!superPrivilege) {
-      System.out.println("test '" + testName + "' skipped because user '" + username
-          + "' doesn't have SUPER privileges");
+      System.out.println(
+          "test '"
+              + testName
+              + "' skipped because user '"
+              + username
+              + "' doesn't have SUPER privileges");
     }
 
     return superPrivilege;
@@ -819,8 +864,8 @@ public class BaseTest {
     boolean isLocal = false;
 
     try {
-      if (InetAddress.getByName(hostname).isAnyLocalAddress() || InetAddress.getByName(hostname)
-          .isLoopbackAddress()) {
+      if (InetAddress.getByName(hostname).isAnyLocalAddress()
+          || InetAddress.getByName(hostname).isLoopbackAddress()) {
         isLocal = true;
       }
     } catch (UnknownHostException e) {
@@ -862,21 +907,7 @@ public class BaseTest {
     DatabaseMetaData md = sharedConnection.getMetaData();
     int dbMajor = md.getDatabaseMajorVersion();
     int dbMinor = md.getDatabaseMinorVersion();
-    return (dbMajor > major
-        || (dbMajor == major && dbMinor >= minor));
-
-  }
-
-  /**
-   * Check if version if at minimum the version asked.
-   *
-   * @param major database major version
-   * @param minor database minor version
-   * @param patch database patch version
-   * @throws SQLException exception
-   */
-  public static boolean minVersion(int major, int minor, int patch) {
-    return ((MariaDbConnection) sharedConnection).versionGreaterOrEqual(major, minor, patch);
+    return (dbMajor > major || (dbMajor == major && dbMinor >= minor));
   }
 
   /**
@@ -891,7 +922,6 @@ public class BaseTest {
     int dbMajor = md.getDatabaseMajorVersion();
     int dbMinor = md.getDatabaseMinorVersion();
     return (dbMajor < major || (dbMajor == major && dbMinor < minor));
-
   }
 
   /**
@@ -905,7 +935,6 @@ public class BaseTest {
 
     String dbVersion = sharedConnection.getMetaData().getDatabaseProductVersion();
     Assume.assumeFalse(dbVersion.startsWith(major + "." + minor));
-
   }
 
   /**
@@ -923,7 +952,6 @@ public class BaseTest {
 
   public void requireMinimumVersion(int major, int minor) throws SQLException {
     Assume.assumeTrue(minVersion(major, minor));
-
   }
 
   /**
@@ -943,7 +971,7 @@ public class BaseTest {
     int majorVersion = 0;
     int minorVersion = 0;
 
-    //standard version
+    // standard version
     if (versionArray.length > 2) {
 
       majorVersion = Integer.parseInt(versionArray[0]);
@@ -958,18 +986,16 @@ public class BaseTest {
       if (versionArray.length > 1) {
         minorVersion = Integer.parseInt(versionArray[1]);
       }
-
     }
 
-    Assume.assumeTrue(majorVersion > major
-        || (majorVersion == major && minorVersion >= minor));
+    Assume.assumeTrue(majorVersion > major || (majorVersion == major && minorVersion >= minor));
   }
 
   /**
    * Change session time zone.
    *
    * @param connection connection
-   * @param timeZone   timezone to set
+   * @param timeZone timezone to set
    * @throws SQLException exception
    */
   public void setSessionTimeZone(Connection connection, String timeZone) throws SQLException {
@@ -986,8 +1012,8 @@ public class BaseTest {
    * @throws SQLException if error occur
    */
   public int getRowCount(String tableName) throws SQLException {
-    ResultSet rs = sharedConnection.createStatement()
-        .executeQuery("SELECT COUNT(*) FROM " + tableName);
+    ResultSet rs =
+        sharedConnection.createStatement().executeQuery("SELECT COUNT(*) FROM " + tableName);
     if (rs.next()) {
       return rs.getInt(1);
     }
@@ -1060,7 +1086,7 @@ public class BaseTest {
         }
       }
     } catch (SQLException sqle) {
-      //eat
+      // eat
     }
     return true;
   }
@@ -1077,18 +1103,19 @@ public class BaseTest {
   /**
    * Get current autoincrement value, since Galera values are automatically set.
    *
-   * @param autoIncInit       default increment
+   * @param autoIncInit default increment
    * @param autoIncOffsetInit default increment offset
    * @throws SQLException if any error occur
-   * @see <a href="https://mariadb.org/auto-increments-in-galera/">https://mariadb.org/auto-increments-in-galera/</a>
+   * @see <a
+   *     href="https://mariadb.org/auto-increments-in-galera/">https://mariadb.org/auto-increments-in-galera/</a>
    */
   public int[] setAutoInc(int autoIncInit, int autoIncOffsetInit) throws SQLException {
 
     int autoInc = autoIncInit;
     int autoIncOffset = autoIncOffsetInit;
     if (isGalera()) {
-      ResultSet rs = sharedConnection.createStatement()
-          .executeQuery("show variables like '%auto_increment%'");
+      ResultSet rs =
+          sharedConnection.createStatement().executeQuery("show variables like '%auto_increment%'");
       while (rs.next()) {
         if ("auto_increment_increment".equals(rs.getString(1))) {
           autoInc = rs.getInt(2);
@@ -1098,11 +1125,10 @@ public class BaseTest {
         }
       }
       if (autoInc == 1) {
-        //galera with one node only, then offset is not used
+        // galera with one node only, then offset is not used
         autoIncOffset = 0;
       }
     }
-    return new int[]{autoInc, autoIncOffset};
+    return new int[] {autoInc, autoIncOffset};
   }
-
 }
