@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,29 +52,16 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.sql.BatchUpdateException;
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.SQLTimeoutException;
-import java.sql.Statement;
-import java.util.Arrays;
-import java.util.Properties;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Test;
+import java.sql.*;
+import java.util.*;
+import java.util.concurrent.*;
+
+import static org.junit.Assert.*;
 
 public class CancelTest extends BaseTest {
 
-
   @Before
   public void cancelSupported() throws SQLException {
     requireMinimumVersion(5, 0);
@@ -88,18 +75,17 @@ public class CancelTest extends BaseTest {
 
       Statement stmt = tmpConnection.createStatement();
       ExecutorService exec = Executors.newFixedThreadPool(1);
-      //check blacklist shared
+      // check blacklist shared
       exec.execute(new CancelThread(stmt));
       stmt.execute(
           "select * from information_schema.columns as c1,  information_schema.tables, information_schema.tables as t2");
 
-      //wait for thread endings
+      // wait for thread endings
       exec.shutdown();
       Assert.fail();
     } catch (SQLException e) {
-      //normal exception
+      // normal exception
     }
-
   }
 
   @Test(timeout = 20000, expected = SQLTimeoutException.class)
@@ -107,7 +93,7 @@ public class CancelTest extends BaseTest {
     Assume.assumeFalse(sharedIsAurora());
     try (Connection tmpConnection = openNewConnection(connUri, new Properties())) {
       Statement stmt = tmpConnection.createStatement();
-      stmt.setQueryTimeout(1); //query take more than 20 seconds (local DB)
+      stmt.setQueryTimeout(1); // query take more than 20 seconds (local DB)
       stmt.execute(
           "select * from information_schema.columns as c1,  information_schema.tables, information_schema.tables as t2");
     }
@@ -117,9 +103,10 @@ public class CancelTest extends BaseTest {
   public void timeoutPrepareSleep() throws Exception {
     Assume.assumeFalse(sharedIsAurora());
     try (Connection tmpConnection = openNewConnection(connUri, new Properties())) {
-      try (PreparedStatement stmt = tmpConnection.prepareStatement(
-          "select * from information_schema.columns as c1,  information_schema.tables, information_schema.tables as t2")) {
-        stmt.setQueryTimeout(1); //query take more than 20 seconds (local DB)
+      try (PreparedStatement stmt =
+          tmpConnection.prepareStatement(
+              "select * from information_schema.columns as c1,  information_schema.tables, information_schema.tables as t2")) {
+        stmt.setQueryTimeout(1); // query take more than 20 seconds (local DB)
         stmt.execute();
       }
     }
@@ -162,8 +149,8 @@ public class CancelTest extends BaseTest {
       char[] arr = new char[1000];
       Arrays.fill(arr, 'a');
       String str = String.valueOf(arr);
-      try (PreparedStatement stmt = tmpConnection
-          .prepareStatement("INSERT INTO timeoutBatch VALUES (?)")) {
+      try (PreparedStatement stmt =
+          tmpConnection.prepareStatement("INSERT INTO timeoutBatch VALUES (?)")) {
         stmt.setQueryTimeout(1);
         for (int i = 0; i < 20000; i++) {
           stmt.setString(1, str);
