@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,26 +52,18 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.sql.Connection;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import org.junit.Assume;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import java.sql.*;
+
+import static org.junit.Assert.*;
 
 public class DataSourceTest extends BaseTest {
 
   protected static final String defConnectToIP = null;
   protected static String connectToIP;
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @BeforeClass
   public static void beforeClassDataSourceTest() {
     connectToIP = System.getProperty("testConnectToIP", defConnectToIP);
@@ -79,8 +71,8 @@ public class DataSourceTest extends BaseTest {
 
   @Test
   public void testDataSource() throws SQLException {
-    MariaDbDataSource ds = new MariaDbDataSource(hostname == null ? "localhost" : hostname, port,
-        database);
+    MariaDbDataSource ds =
+        new MariaDbDataSource(hostname == null ? "localhost" : hostname, port, database);
 
     try (Connection connection = ds.getConnection(username, password)) {
       assertEquals(connection.isValid(0), true);
@@ -89,8 +81,8 @@ public class DataSourceTest extends BaseTest {
 
   @Test
   public void testDataSource2() throws SQLException {
-    MariaDbDataSource ds = new MariaDbDataSource(hostname == null ? "localhost" : hostname, port,
-        database);
+    MariaDbDataSource ds =
+        new MariaDbDataSource(hostname == null ? "localhost" : hostname, port, database);
     try (Connection connection = ds.getConnection(username, password)) {
       assertEquals(connection.isValid(0), true);
     }
@@ -134,7 +126,6 @@ public class DataSourceTest extends BaseTest {
     assertEquals(ds.getUrlParser().getOptions().connectTimeout, 2_000);
   }
 
-
   @Test
   public void testDataSourceTimeout4() throws SQLException {
     MariaDbDataSource ds = new MariaDbDataSource();
@@ -153,8 +144,8 @@ public class DataSourceTest extends BaseTest {
   @Test
   public void setDatabaseNameTest() throws SQLException {
     Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
-    MariaDbDataSource ds = new MariaDbDataSource(hostname == null ? "localhost" : hostname, port,
-        database);
+    MariaDbDataSource ds =
+        new MariaDbDataSource(hostname == null ? "localhost" : hostname, port, database);
     try (Connection connection = ds.getConnection(username, password)) {
       connection.createStatement().execute("CREATE DATABASE IF NOT EXISTS test2");
       ds.setDatabaseName("test2");
@@ -175,8 +166,8 @@ public class DataSourceTest extends BaseTest {
   @Test
   public void setServerNameTest() throws SQLException {
     Assume.assumeTrue(connectToIP != null);
-    MariaDbDataSource ds = new MariaDbDataSource(hostname == null ? "localhost" : hostname, port,
-        database);
+    MariaDbDataSource ds =
+        new MariaDbDataSource(hostname == null ? "localhost" : hostname, port, database);
     try (Connection connection = ds.getConnection(username, password)) {
       ds.setServerName(connectToIP);
 
@@ -195,34 +186,35 @@ public class DataSourceTest extends BaseTest {
   @Test(timeout = 50000) // unless port 3307 can be used
   public void setPortTest() throws SQLException {
     Assume.assumeFalse("true".equals(System.getenv("AURORA")));
-    MariaDbDataSource ds = new MariaDbDataSource(hostname == null ? "localhost" : hostname, port,
-        database);
+    MariaDbDataSource ds =
+        new MariaDbDataSource(hostname == null ? "localhost" : hostname, port, database);
     try (Connection connection2 = ds.getConnection(username, password)) {
-      //delete blacklist, because can failover on 3306 is filled
+      // delete blacklist, because can failover on 3306 is filled
       assureBlackList(connection2);
     }
 
     ds.setPort(3407);
 
-    //must throw SQLException
+    // must throw SQLException
     try {
       ds.getConnection(username, password);
       fail();
     } catch (SQLException e) {
-      //normal error
+      // normal error
     }
   }
 
   /**
-   * Conj-123:Session variables lost and exception if set via MariaDbDataSource.setProperties/setURL.
+   * Conj-123:Session variables lost and exception if set via
+   * MariaDbDataSource.setProperties/setURL.
    *
    * @throws SQLException exception
    */
   @Test
   @SuppressWarnings("deprecation")
   public void setPropertiesTest() throws SQLException {
-    MariaDbDataSource ds = new MariaDbDataSource(hostname == null ? "localhost" : hostname, port,
-        database);
+    MariaDbDataSource ds =
+        new MariaDbDataSource(hostname == null ? "localhost" : hostname, port, database);
     ds.setProperties("sessionVariables=sql_mode='PIPES_AS_CONCAT'");
     try (Connection connection = ds.getConnection(username, password)) {
       ResultSet rs = connection.createStatement().executeQuery("SELECT @@sql_mode");
@@ -238,16 +230,14 @@ public class DataSourceTest extends BaseTest {
         fail();
       }
     }
-
   }
 
   @Test
   public void setLoginTimeOut() {
-    MariaDbDataSource ds = new MariaDbDataSource(hostname == null ? "localhost" : hostname, port,
-        database);
+    MariaDbDataSource ds =
+        new MariaDbDataSource(hostname == null ? "localhost" : hostname, port, database);
     assertEquals(30, ds.getLoginTimeout());
     ds.setLoginTimeout(10);
     assertEquals(10, ds.getLoginTimeout());
   }
-
 }
