@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,39 +52,15 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.io.ByteArrayInputStream;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.ObjectInputStream;
-import java.io.Reader;
-import java.io.StringReader;
-import java.math.BigDecimal;
-import java.math.BigInteger;
-import java.net.URL;
-import java.nio.charset.Charset;
-import java.nio.charset.StandardCharsets;
-import java.sql.Connection;
-import java.sql.DatabaseMetaData;
-import java.sql.Date;
-import java.sql.DriverManager;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.sql.Time;
-import java.sql.Timestamp;
-import java.sql.Types;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import java.io.*;
+import java.math.*;
+import java.net.*;
+import java.nio.charset.*;
+import java.sql.*;
+
+import static org.junit.Assert.*;
 
 public class DatatypeTest extends BaseTest {
 
@@ -99,33 +75,36 @@ public class DatatypeTest extends BaseTest {
   public static void initClass() throws SQLException {
     createTable("Driverstreamtest", "id int not null primary key, strm text");
     createTable("Driverstreamtest2", "id int primary key not null, strm text");
-    createTable("objecttest", "int_test int primary key not null, string_test varchar(30), "
-        + "timestamp_test timestamp, serial_test blob");
-    createTable("bintest",
+    createTable(
+        "objecttest",
+        "int_test int primary key not null, string_test varchar(30), "
+            + "timestamp_test timestamp, serial_test blob");
+    createTable(
+        "bintest",
         "id int not null primary key auto_increment, bin1 varbinary(300), bin2 varbinary(300)");
-    createTable("bigdectest", "id int not null primary key auto_increment, bd decimal",
-        "engine=innodb");
+    createTable(
+        "bigdectest", "id int not null primary key auto_increment, bd decimal", "engine=innodb");
     createTable("bytetest", "id int not null primary key auto_increment, a int", "engine=innodb");
     createTable("shorttest", "id int not null primary key auto_increment,a int", "engine=innodb");
-    createTable("doubletest", "id int not null primary key auto_increment,a double",
-        "engine=innodb");
+    createTable(
+        "doubletest", "id int not null primary key auto_increment,a double", "engine=innodb");
     createTable("bittest", "id int not null primary key auto_increment, b int");
     createTable("emptytest", "id int");
-    createTable("test_setobjectconv",
+    createTable(
+        "test_setobjectconv",
         "id int not null primary key auto_increment, v1 varchar(40), v2 varchar(40)");
     createTable("blabla", "valsue varchar(20)");
     createTable("TestBigIntType", "t1 bigint(20), t2 bigint(20), t3 bigint(20), t4 bigint(20)");
-    createTable("time_period",
+    createTable(
+        "time_period",
         "ID int unsigned NOT NULL, START time NOT NULL, END time NOT NULL, PRIMARY KEY (ID)");
     createTable("bitBoolTest", "d1 BOOLEAN, d2 BIT");
-
-
   }
 
   /**
    * Get a simple Statement or a PrepareStatement.
    *
-   * @param query    query
+   * @param query query
    * @param prepared flag must be a prepare statement
    * @return a statement
    * @throws SQLException exception
@@ -137,8 +116,8 @@ public class DatatypeTest extends BaseTest {
   /**
    * Get a simple Statement or a PrepareStatement.
    *
-   * @param query      query
-   * @param prepared   flag must be a prepare statement
+   * @param query query
+   * @param prepared flag must be a prepare statement
    * @param connection the connection to use
    * @return a statement
    * @throws SQLException exception
@@ -167,19 +146,26 @@ public class DatatypeTest extends BaseTest {
       if (!clazz.equals(obj.getClass())) {
         System.out.println("test");
       }
-      assertEquals("Unexpected class for column " + column, clazz,
-          resultSet.getObject(column).getClass());
+      assertEquals(
+          "Unexpected class for column " + column, clazz, resultSet.getObject(column).getClass());
     }
-    assertEquals("Unexpected class name for column " + column, clazz.getName(),
+    assertEquals(
+        "Unexpected class name for column " + column,
+        clazz.getName(),
         resultSet.getMetaData().getColumnClassName(index));
-    assertEquals("Unexpected MySQL type for column " + column, mysqlType,
+    assertEquals(
+        "Unexpected MySQL type for column " + column,
+        mysqlType,
         resultSet.getMetaData().getColumnTypeName(index));
-    assertEquals("Unexpected java sql type for column " + column, javaSqlType,
+    assertEquals(
+        "Unexpected java sql type for column " + column,
+        javaSqlType,
         resultSet.getMetaData().getColumnType(index));
   }
 
   private void createDataTypeTables() throws SQLException {
-    createTable("datatypetest",
+    createTable(
+        "datatypetest",
         "bit1 BIT(1) default 0,"
             + "bit2 BIT(2) default 1,"
             + "tinyint1 TINYINT(1) default 0,"
@@ -200,8 +186,9 @@ public class DatatypeTest extends BaseTest {
             + "datetime0 DATETIME default '2001-01-01 00:00:00',"
             + "timestamp0 TIMESTAMP default  '2001-01-01 00:00:00',"
             + "time0 TIME default '22:11:00',"
-            + ((minVersion(5, 6) && strictBeforeVersion(10, 0)) ? "year2 YEAR(4) default 99,"
-            : "year2 YEAR(2) default 99,")
+            + ((minVersion(5, 6) && strictBeforeVersion(10, 0))
+                ? "year2 YEAR(4) default 99,"
+                : "year2 YEAR(2) default 99,")
             + "year4 YEAR(4) default 2011,"
             + "char0 CHAR(1) default '0',"
             + "char_binary CHAR (1) binary default '0',"
@@ -224,8 +211,8 @@ public class DatatypeTest extends BaseTest {
   /**
    * Testing different date parameters.
    *
-   * @param connection     current connection
-   * @param tinyInt1isBit  tiny bit must be consider as boolean
+   * @param connection current connection
+   * @param tinyInt1isBit tiny bit must be consider as boolean
    * @param yearIsDateType year must be consider as Date or int
    * @throws Exception exception
    */
@@ -234,9 +221,11 @@ public class DatatypeTest extends BaseTest {
 
     createDataTypeTables();
 
-    connection.createStatement()
-        .execute("insert into datatypetest (tinyblob0,mediumblob0,blob0,longblob0,"
-            + "tinytext0,mediumtext0,text0, longtext0) values(0x1,0x1,0x1,0x1, 'a', 'a', 'a', 'a')");
+    connection
+        .createStatement()
+        .execute(
+            "insert into datatypetest (tinyblob0,mediumblob0,blob0,longblob0,"
+                + "tinytext0,mediumtext0,text0, longtext0) values(0x1,0x1,0x1,0x1, 'a', 'a', 'a', 'a')");
 
     resultSet = connection.createStatement().executeQuery("select * from datatypetest");
     resultSet.next();
@@ -246,11 +235,16 @@ public class DatatypeTest extends BaseTest {
     checkClass("bit1", Boolean.class, "BIT", Types.BIT);
     checkClass("bit2", byteArrayClass, "BIT", Types.VARBINARY);
 
-    checkClass("tinyint1",
-        tinyInt1isBit ? Boolean.class : Integer.class, "TINYINT",
+    checkClass(
+        "tinyint1",
+        tinyInt1isBit ? Boolean.class : Integer.class,
+        "TINYINT",
         tinyInt1isBit ? Types.BIT : Types.TINYINT);
     checkClass("tinyint2", Integer.class, "TINYINT", Types.TINYINT);
-    checkClass("bool0", tinyInt1isBit ? Boolean.class : Integer.class, "TINYINT",
+    checkClass(
+        "bool0",
+        tinyInt1isBit ? Boolean.class : Integer.class,
+        "TINYINT",
         tinyInt1isBit ? Types.BIT : Types.TINYINT);
     checkClass("smallint0", Integer.class, "SMALLINT", Types.SMALLINT);
     checkClass("smallint_unsigned", Integer.class, "SMALLINT UNSIGNED", Types.SMALLINT);
@@ -268,13 +262,17 @@ public class DatatypeTest extends BaseTest {
     checkClass("timestamp0", Timestamp.class, "TIMESTAMP", Types.TIMESTAMP);
 
     if (minVersion(5, 6) && strictBeforeVersion(10, 0)) {
-      //MySQL deprecated YEAR(2) since 5.6
-      checkClass("year2",
-          yearIsDateType ? Date.class : Short.class, "YEAR",
+      // MySQL deprecated YEAR(2) since 5.6
+      checkClass(
+          "year2",
+          yearIsDateType ? Date.class : Short.class,
+          "YEAR",
           yearIsDateType ? Types.DATE : Types.SMALLINT);
     }
-    checkClass("year4",
-        yearIsDateType ? Date.class : Short.class, "YEAR",
+    checkClass(
+        "year4",
+        yearIsDateType ? Date.class : Short.class,
+        "YEAR",
         yearIsDateType ? Types.DATE : Types.SMALLINT);
     checkClass("char0", String.class, "CHAR", Types.CHAR);
     checkClass("char_binary", String.class, "CHAR", Types.CHAR);
@@ -296,7 +294,6 @@ public class DatatypeTest extends BaseTest {
     resultSet = connection.createStatement().executeQuery("select NULL as foo");
     resultSet.next();
     checkClass("foo", String.class, "NULL", Types.NULL);
-
   }
 
   @Test
@@ -328,15 +325,15 @@ public class DatatypeTest extends BaseTest {
   @SuppressWarnings("deprecation")
   @Test
   public void testCharacterStreams() throws SQLException, IOException {
-    PreparedStatement stmt = sharedConnection.prepareStatement(
-        "insert into Driverstreamtest (id, strm) values (?,?)");
+    PreparedStatement stmt =
+        sharedConnection.prepareStatement("insert into Driverstreamtest (id, strm) values (?,?)");
     stmt.setInt(1, 2);
     String toInsert = "abcdefgh\njklmn\"";
     Reader reader = new StringReader(toInsert);
     stmt.setCharacterStream(2, reader);
     stmt.execute();
-    ResultSet rs = sharedConnection.createStatement()
-        .executeQuery("select * from Driverstreamtest");
+    ResultSet rs =
+        sharedConnection.createStatement().executeQuery("select * from Driverstreamtest");
     assertTrue(rs.next());
     Reader rdr = rs.getCharacterStream("strm");
     StringBuilder sb = new StringBuilder();
@@ -371,8 +368,8 @@ public class DatatypeTest extends BaseTest {
 
   @Test
   public void testCharacterStreamWithLength() throws SQLException, IOException {
-    PreparedStatement stmt = sharedConnection.prepareStatement(
-        "insert into Driverstreamtest2 (id, strm) values (?,?)");
+    PreparedStatement stmt =
+        sharedConnection.prepareStatement("insert into Driverstreamtest2 (id, strm) values (?,?)");
     stmt.setInt(1, 2);
     String toInsert = "abcdefgh\njklmn\"";
     Reader reader = new StringReader(toInsert);
@@ -393,7 +390,6 @@ public class DatatypeTest extends BaseTest {
     }
     assertEquals(sb.toString(), toInsert.substring(0, 5));
     assertEquals(rs.getString("strm"), toInsert.substring(0, 5));
-
   }
 
   @Test
@@ -434,14 +430,11 @@ public class DatatypeTest extends BaseTest {
     ps.execute();
   }
 
-  /**
-   * CONJ-299 - PreparedStatement.setObject(Type.BIT, "1") should register as true.
-   */
-
+  /** CONJ-299 - PreparedStatement.setObject(Type.BIT, "1") should register as true. */
   @Test
   public void setBitBoolObjectTest() throws SQLException {
-    PreparedStatement ps = sharedConnection
-        .prepareStatement("insert into bitBoolTest values (?,?)");
+    PreparedStatement ps =
+        sharedConnection.prepareStatement("insert into bitBoolTest values (?,?)");
     ps.setObject(1, 0);
     ps.setObject(2, 0);
     ps.addBatch();
@@ -472,8 +465,8 @@ public class DatatypeTest extends BaseTest {
 
     ps.executeBatch();
 
-    try (ResultSet rs = sharedConnection.createStatement()
-        .executeQuery("select * from bitBoolTest")) {
+    try (ResultSet rs =
+        sharedConnection.createStatement().executeQuery("select * from bitBoolTest")) {
       assertValue(rs, false);
       assertValue(rs, true);
       assertValue(rs, false);
@@ -498,8 +491,8 @@ public class DatatypeTest extends BaseTest {
 
   @Test
   public void setObjectTest() throws SQLException, IOException, ClassNotFoundException {
-    PreparedStatement ps = sharedConnection
-        .prepareStatement("insert into objecttest values (?,?,?,?)");
+    PreparedStatement ps =
+        sharedConnection.prepareStatement("insert into objecttest values (?,?,?,?)");
     ps.setObject(1, 5);
     ps.setObject(2, "aaa");
     ps.setObject(3, Timestamp.valueOf("2009-01-17 15:41:01"));
@@ -553,15 +546,14 @@ public class DatatypeTest extends BaseTest {
 
     assertEquals(sc.getVal(), "testing");
     assertEquals(sc.getVal2(), 8);
-
   }
 
   @Test
   public void setObjectBitInt() throws SQLException {
 
-    PreparedStatement preparedStatement = sharedConnection
-        .prepareStatement("INSERT INTO TestBigIntType "
-            + "(t1, t2, t3, t4) VALUES (?, ?, ?, ?)");
+    PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement(
+            "INSERT INTO TestBigIntType " + "(t1, t2, t3, t4) VALUES (?, ?, ?, ?)");
 
     final long valueLong = System.currentTimeMillis();
     final String maxValue = String.valueOf(Long.MAX_VALUE);
@@ -579,7 +571,6 @@ public class DatatypeTest extends BaseTest {
     try (ResultSet rs = getResultSet("select * from TestBigIntType", true)) {
       validateResultBigIntType(valueLong, maxValue, rs);
     }
-
   }
 
   private void validateResultBigIntType(long valueLong, String maxValue, ResultSet resultSet)
@@ -605,8 +596,8 @@ public class DatatypeTest extends BaseTest {
       allBytes[i] = (byte) (i & 0xff);
     }
     ByteArrayInputStream bais = new ByteArrayInputStream(allBytes);
-    PreparedStatement ps = sharedConnection
-        .prepareStatement("insert into bintest (bin1,bin2) values (?,?)");
+    PreparedStatement ps =
+        sharedConnection.prepareStatement("insert into bintest (bin1,bin2) values (?,?)");
     ps.setBytes(1, allBytes);
     ps.setBinaryStream(2, bais);
     ps.execute();
@@ -683,8 +674,8 @@ public class DatatypeTest extends BaseTest {
       createTable("bintest3", "bin1 longblob", "engine=innodb");
       Statement stmt = connection.createStatement();
 
-      try (PreparedStatement ps = connection
-          .prepareStatement("insert into bintest3 (bin1) values (?)")) {
+      try (PreparedStatement ps =
+          connection.prepareStatement("insert into bintest3 (bin1) values (?)")) {
         ps.setBinaryStream(1, is);
         ps.execute();
       }
@@ -696,7 +687,6 @@ public class DatatypeTest extends BaseTest {
       for (int i = 0; i < 1000000; i++) {
         assertEquals(buf[i], buf2[i]);
       }
-
     }
   }
 
@@ -706,14 +696,14 @@ public class DatatypeTest extends BaseTest {
       for (int i = 0; i < 1000000; i++) {
         assertEquals((byte) i, buf2[i]);
       }
-      assertEquals(rs.getString(1), new String(buf, Charset.forName("UTF-8")));
+      assertEquals(rs.getString(1), new String(buf, StandardCharsets.UTF_8));
 
       if (rs.next()) {
         buf2 = rs.getBytes(1);
         for (int i = 0; i < 1000000; i++) {
           assertEquals((byte) i, buf2[i]);
         }
-        assertEquals(rs.getString(1), new String(buf, Charset.forName("UTF-8")));
+        assertEquals(rs.getString(1), new String(buf, StandardCharsets.UTF_8));
         if (rs.next()) {
           fail();
         }
@@ -729,8 +719,8 @@ public class DatatypeTest extends BaseTest {
   public void bigDecimalTest() throws SQLException {
     requireMinimumVersion(5, 0);
     BigDecimal bd = BigDecimal.TEN;
-    PreparedStatement ps = sharedConnection
-        .prepareStatement("insert into bigdectest (bd) values (?)");
+    PreparedStatement ps =
+        sharedConnection.prepareStatement("insert into bigdectest (bd) values (?)");
     ps.setBigDecimal(1, bd);
     ps.execute();
 
@@ -740,7 +730,6 @@ public class DatatypeTest extends BaseTest {
     try (ResultSet rs = getResultSet("select bd from bigdectest", true)) {
       bigDecimalTestResult(rs, bd);
     }
-
   }
 
   private void bigDecimalTestResult(ResultSet rs, BigDecimal bd) throws SQLException {
@@ -757,7 +746,6 @@ public class DatatypeTest extends BaseTest {
     } else {
       fail("Must have resultset");
     }
-
   }
 
   @Test
@@ -789,8 +777,8 @@ public class DatatypeTest extends BaseTest {
 
   @Test
   public void shortTest() throws SQLException {
-    PreparedStatement ps = sharedConnection
-        .prepareStatement("insert into shorttest (a) values (?)");
+    PreparedStatement ps =
+        sharedConnection.prepareStatement("insert into shorttest (a) values (?)");
     ps.setShort(1, Short.MAX_VALUE);
     ps.execute();
     try (ResultSet rs = getResultSet("select a from shorttest", false)) {
@@ -816,8 +804,8 @@ public class DatatypeTest extends BaseTest {
 
   @Test
   public void doubleTest() throws SQLException {
-    PreparedStatement ps = sharedConnection
-        .prepareStatement("insert into doubletest (a) values (?)");
+    PreparedStatement ps =
+        sharedConnection.prepareStatement("insert into doubletest (a) values (?)");
     double sendDoubleValue = 1.5;
     ps.setDouble(1, sendDoubleValue);
     ps.execute();
@@ -882,13 +870,13 @@ public class DatatypeTest extends BaseTest {
         rs.getURL(1);
         fail("must have thrown error");
       } catch (SQLException e) {
-        //expected
+        // expected
       }
       try {
         rs.getURL("url");
         fail("must have thrown error");
       } catch (SQLException e) {
-        //expected
+        // expected
       }
     } else {
       fail("must have result !");
@@ -919,8 +907,8 @@ public class DatatypeTest extends BaseTest {
 
   @Test
   public void testSetObject() throws SQLException {
-    PreparedStatement ps = sharedConnection
-        .prepareStatement("insert into test_setobjectconv values (null, ?, ?)");
+    PreparedStatement ps =
+        sharedConnection.prepareStatement("insert into test_setobjectconv values (null, ?, ?)");
     ps.setObject(1, "2009-01-01 00:00:00", Types.TIMESTAMP);
     ps.setObject(2, "33", Types.DOUBLE);
     ps.execute();
@@ -928,8 +916,8 @@ public class DatatypeTest extends BaseTest {
 
   @Test
   public void testBit() throws SQLException {
-    PreparedStatement stmt = sharedConnection
-        .prepareStatement("insert into bittest values(null, ?)");
+    PreparedStatement stmt =
+        sharedConnection.prepareStatement("insert into bittest values(null, ?)");
     stmt.setBoolean(1, true);
     stmt.execute();
     stmt.setBoolean(1, false);
@@ -961,7 +949,8 @@ public class DatatypeTest extends BaseTest {
   @Test
   @SuppressWarnings("deprecation")
   public void testNullTimePreparedStatement() throws Exception {
-    sharedConnection.createStatement()
+    sharedConnection
+        .createStatement()
         .execute("insert into time_period(id, start, end) values(1, '00:00:00', '08:00:00');");
     final String sql = "SELECT id, start, end FROM time_period WHERE id=?";
     PreparedStatement preparedStatement = sharedConnection.prepareStatement(sql);
@@ -981,16 +970,16 @@ public class DatatypeTest extends BaseTest {
     createTable("longMinValueSpecificity", "ii BIGINT");
     try (Statement statement = sharedConnection.createStatement()) {
 
-      try (PreparedStatement preparedStatement = sharedConnection.prepareStatement(
-          "INSERT INTO longMinValueSpecificity values (?)")) {
+      try (PreparedStatement preparedStatement =
+          sharedConnection.prepareStatement("INSERT INTO longMinValueSpecificity values (?)")) {
         preparedStatement.setLong(1, Long.MAX_VALUE);
         preparedStatement.executeQuery();
         preparedStatement.setLong(1, Long.MIN_VALUE);
         preparedStatement.executeQuery();
       }
 
-      try (PreparedStatement preparedStatement = sharedConnection.prepareStatement(
-          "SELECT * from longMinValueSpecificity")) {
+      try (PreparedStatement preparedStatement =
+          sharedConnection.prepareStatement("SELECT * from longMinValueSpecificity")) {
         ResultSet resultSet = preparedStatement.executeQuery();
         assertTrue(resultSet.next());
         assertEquals(Long.MAX_VALUE, resultSet.getLong(1));
@@ -1010,25 +999,33 @@ public class DatatypeTest extends BaseTest {
   public void testBinarySetter() throws Throwable {
     createTable("LatinTable", "t1 varchar(30)", "DEFAULT CHARSET=latin1");
 
-    try (Connection connection = DriverManager.getConnection(connU + "?user=" + username
-        + ((password != null && !password.isEmpty()) ? "&password=" + password : "")
-        + "&useServerPrepStmts=true")) {
+    try (Connection connection =
+        DriverManager.getConnection(
+            connU
+                + "?user="
+                + username
+                + ((password != null && !password.isEmpty()) ? "&password=" + password : "")
+                + "&useServerPrepStmts=true")) {
       checkCharactersInsert(connection);
     }
 
     Statement stmt = sharedConnection.createStatement();
     assertFalse(stmt.execute("truncate LatinTable"));
 
-    try (Connection connection = DriverManager.getConnection(connU + "?user=" + username
-        + (password != null && !"".equals(password) ? "&password=" + password : "")
-        + "&useServerPrepStmts=false")) {
+    try (Connection connection =
+        DriverManager.getConnection(
+            connU
+                + "?user="
+                + username
+                + (password != null && !"".equals(password) ? "&password=" + password : "")
+                + "&useServerPrepStmts=false")) {
       checkCharactersInsert(connection);
     }
   }
 
   private void checkCharactersInsert(Connection connection) throws Throwable {
-    try (PreparedStatement preparedStatement = connection
-        .prepareStatement("INSERT INTO LatinTable(t1)  values (?)")) {
+    try (PreparedStatement preparedStatement =
+        connection.prepareStatement("INSERT INTO LatinTable(t1)  values (?)")) {
       String str = "你好(hello in Chinese)";
       try {
         preparedStatement.setString(1, str);
@@ -1066,14 +1063,15 @@ public class DatatypeTest extends BaseTest {
 
     validResultSetBitValue(stmt.executeQuery("SELECT * FROM testShortBit"));
 
-    try (PreparedStatement preparedStatement = sharedConnection
-        .prepareStatement("SELECT * FROM testShortBit")) {
+    try (PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement("SELECT * FROM testShortBit")) {
       validResultSetBitValue(preparedStatement.executeQuery());
     }
   }
 
   /**
-   * CONJ-650 : NegativeArraySizeException while executing getObject(columnName, byte[].class) with null value
+   * CONJ-650 : NegativeArraySizeException while executing getObject(columnName, byte[].class) with
+   * null value
    *
    * @throws SQLException if any exception occur.
    */
@@ -1081,14 +1079,12 @@ public class DatatypeTest extends BaseTest {
   public void testNullGetObject() throws SQLException {
     createTable("testTextNullValue", "id int, val text");
     Statement stmt = sharedConnection.createStatement();
-    stmt.execute(
-        "INSERT INTO testTextNullValue VALUES (1, 'abc'), (2, null)");
+    stmt.execute("INSERT INTO testTextNullValue VALUES (1, 'abc'), (2, null)");
     ResultSet rs = stmt.executeQuery("SELECT * FROM testTextNullValue");
     assertTrue(rs.next());
     assertArrayEquals(rs.getObject(2, byte[].class), "abc".getBytes());
     assertTrue(rs.next());
     assertNull(rs.getObject(2, byte[].class));
-
   }
 
   private void validResultSetBitValue(ResultSet rs) throws SQLException {
@@ -1116,7 +1112,6 @@ public class DatatypeTest extends BaseTest {
     assertTrue(rs.next());
     checkAllDataType(rs, 1, 1);
     checkAllDataType(rs, 2, 2147483648L);
-
   }
 
   private void checkAllDataType(ResultSet rs, int index, long expectedValue) throws SQLException {
@@ -1160,6 +1155,5 @@ public class DatatypeTest extends BaseTest {
     assertEquals((double) expectedValue, rs.getDouble(index), 0.01);
     assertEquals(new BigDecimal(expectedValue), rs.getBigDecimal(index));
     assertEquals(String.valueOf(expectedValue), rs.getString(index));
-
   }
 }
