@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,30 +52,20 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.sql.Connection;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.util.UUID;
-import javax.sql.XAConnection;
-import javax.transaction.xa.XAException;
-import javax.transaction.xa.XAResource;
-import javax.transaction.xa.Xid;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import javax.sql.*;
+import javax.transaction.xa.*;
+import java.sql.*;
+import java.util.*;
+
+import static org.junit.Assert.*;
 
 public class DistributedTransactionTest extends BaseTest {
 
   private final MariaDbDataSource dataSource;
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   public DistributedTransactionTest() throws SQLException {
     dataSource = new MariaDbDataSource();
     dataSource.setServerName(hostname);
@@ -96,13 +86,13 @@ public class DistributedTransactionTest extends BaseTest {
   }
 
   private Xid newXid() {
-    return new MariaDbXid(1, UUID.randomUUID().toString().getBytes(),
-        UUID.randomUUID().toString().getBytes());
+    return new MariaDbXid(
+        1, UUID.randomUUID().toString().getBytes(), UUID.randomUUID().toString().getBytes());
   }
 
   private Xid newXid(Xid branchFrom) {
-    return new MariaDbXid(1, branchFrom.getGlobalTransactionId(),
-        UUID.randomUUID().toString().getBytes());
+    return new MariaDbXid(
+        1, branchFrom.getGlobalTransactionId(), UUID.randomUUID().toString().getBytes());
   }
 
   /**
@@ -184,14 +174,13 @@ public class DistributedTransactionTest extends BaseTest {
     }
   }
 
-
   @Test
   public void testCommit() throws Exception {
     int connectionNumber = test2PhaseCommit(true);
 
     // check the completion
-    try (ResultSet rs = sharedConnection.createStatement()
-        .executeQuery("SELECT * from xatable order by i")) {
+    try (ResultSet rs =
+        sharedConnection.createStatement().executeQuery("SELECT * from xatable order by i")) {
       for (int i = 0; i < connectionNumber; i++) {
         assertTrue(rs.next());
         assertEquals(rs.getInt(1), i);
@@ -203,8 +192,8 @@ public class DistributedTransactionTest extends BaseTest {
   public void testRollback() throws Exception {
     test2PhaseCommit(false);
     // check the completion
-    try (ResultSet rs = sharedConnection.createStatement()
-        .executeQuery("SELECT * from xatable order by i")) {
+    try (ResultSet rs =
+        sharedConnection.createStatement().executeQuery("SELECT * from xatable order by i")) {
       assertFalse(rs.next());
     }
   }
@@ -292,4 +281,4 @@ public class DistributedTransactionTest extends BaseTest {
       }
     }
   }
-}
\ No newline at end of file
+}
