@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,34 +52,16 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.io.PrintWriter;
-import java.io.StringWriter;
-import java.lang.Thread.State;
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.util.Iterator;
-import java.util.Properties;
-import java.util.concurrent.BrokenBarrierException;
-import java.util.concurrent.CyclicBarrier;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
-import java.util.concurrent.ScheduledThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.concurrent.atomic.AtomicInteger;
-import java.util.concurrent.atomic.AtomicReference;
-import org.junit.Assume;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import java.io.*;
+import java.lang.Thread.*;
+import java.sql.*;
+import java.util.*;
+import java.util.concurrent.*;
+import java.util.concurrent.atomic.*;
+
+import static org.junit.Assert.*;
 
 public class ExecuteBatchTest extends BaseTest {
 
@@ -101,7 +83,8 @@ public class ExecuteBatchTest extends BaseTest {
    */
   @BeforeClass()
   public static void initClass() throws SQLException {
-    createTable("ExecuteBatchTest",
+    createTable(
+        "ExecuteBatchTest",
         "id int not null primary key auto_increment, test varchar(100) , test2 int");
     createTable("ExecuteBatchUseBatchMultiSend", "test varchar(100)");
   }
@@ -114,41 +97,43 @@ public class ExecuteBatchTest extends BaseTest {
   @Test
   public void interruptExecuteBatch() throws Exception {
     Assume.assumeTrue(
-        sharedOptions().useBatchMultiSend && !(sharedOptions().useBulkStmts && isMariadbServer()
-            && minVersion(10, 2)));
+        sharedOptions().useBatchMultiSend
+            && !(sharedOptions().useBulkStmts && isMariadbServer() && minVersion(10, 2)));
     ExecutorService service = Executors.newFixedThreadPool(1);
 
     final CyclicBarrier barrier = new CyclicBarrier(2);
     final AtomicBoolean wasInterrupted = new AtomicBoolean(false);
     final AtomicReference<Exception> exceptionRef = new AtomicReference<>();
 
-    service.submit(() -> {
-      try {
-        PreparedStatement preparedStatement = sharedConnection.prepareStatement(
-            "INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
+    service.submit(
+        () -> {
+          try {
+            PreparedStatement preparedStatement =
+                sharedConnection.prepareStatement(
+                    "INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
 
-        // Send a large enough batch that will take long enough to allow us to interrupt it
-        for (int i = 0; i < 1_000_000; i++) {
-          preparedStatement.setString(1, String.valueOf(System.nanoTime()));
-          preparedStatement.setInt(2, i);
-          preparedStatement.addBatch();
-        }
+            // Send a large enough batch that will take long enough to allow us to interrupt it
+            for (int i = 0; i < 1_000_000; i++) {
+              preparedStatement.setString(1, String.valueOf(System.nanoTime()));
+              preparedStatement.setInt(2, i);
+              preparedStatement.addBatch();
+            }
 
-        barrier.await();
+            barrier.await();
 
-        preparedStatement.executeBatch();
-      } catch (InterruptedException ex) {
-        exceptionRef.set(ex);
-        Thread.currentThread().interrupt();
-      } catch (BrokenBarrierException ex) {
-        exceptionRef.set(ex);
-      } catch (SQLException ex) {
-        exceptionRef.set(ex);
-        wasInterrupted.set(Thread.currentThread().isInterrupted());
-      } catch (Exception ex) {
-        exceptionRef.set(ex);
-      }
-    });
+            preparedStatement.executeBatch();
+          } catch (InterruptedException ex) {
+            exceptionRef.set(ex);
+            Thread.currentThread().interrupt();
+          } catch (BrokenBarrierException ex) {
+            exceptionRef.set(ex);
+          } catch (SQLException ex) {
+            exceptionRef.set(ex);
+            wasInterrupted.set(Thread.currentThread().isInterrupted());
+          } catch (Exception ex) {
+            exceptionRef.set(ex);
+          }
+        });
 
     barrier.await();
 
@@ -158,13 +143,12 @@ public class ExecuteBatchTest extends BaseTest {
     // Interrupt the thread
     service.shutdownNow();
 
-    assertTrue(
-        service.awaitTermination(1, TimeUnit.MINUTES)
-    );
+    assertTrue(service.awaitTermination(1, TimeUnit.MINUTES));
 
     assertNotNull(exceptionRef.get());
 
-    //ensure that even interrupted, connection status is when sending in bulk (all corresponding bulk send are read)
+    // ensure that even interrupted, connection status is when sending in bulk (all corresponding
+    // bulk send are read)
     ResultSet rs = sharedConnection.createStatement().executeQuery("SELECT 123456");
     assertTrue(rs.next());
     assertEquals(123456, rs.getInt(1));
@@ -174,27 +158,28 @@ public class ExecuteBatchTest extends BaseTest {
 
     assertTrue(
         "Exception should be a SQLException: \n" + writer.toString(),
-        exceptionRef.get() instanceof SQLException
-    );
+        exceptionRef.get() instanceof SQLException);
 
     assertTrue(wasInterrupted.get());
-
   }
 
   @Test
-  public void serverBulk8mTest() throws SQLException {
-    Assume.assumeTrue(checkMaxAllowedPacketMore8m("serverBulk8mTest"));
+  public void serverBulk1mTest() throws SQLException {
+    Assume.assumeTrue(checkMaxAllowedPacketMore8m("serverBulk1mTest"));
     Assume.assumeTrue(runLongTest);
     Assume.assumeFalse(sharedIsAurora());
+    Assume.assumeTrue(isMariadbServer());
 
     sharedConnection.createStatement().execute("TRUNCATE TABLE ExecuteBatchTest");
 
-    try (Connection connection = setConnection(
-        "&useComMulti=false&useBatchMultiSend=true&profileSql=" + profileSql)) {
-      PreparedStatement preparedStatement = connection
-          .prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
-      //packet size : 7 200 068 kb
-      addBatchData(preparedStatement, 60000, connection);
+    try (Connection connection =
+        setConnection(
+            "&useBulkStmts=true&useComMulti=false&useBatchMultiSend=true&profileSql="
+                + profileSql)) {
+      PreparedStatement preparedStatement =
+          connection.prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
+      // packet size : 7 200 068 kb
+      addBatchData(preparedStatement, 10000, connection, false, false || !minVersion(10, 2));
     }
   }
 
@@ -203,82 +188,101 @@ public class ExecuteBatchTest extends BaseTest {
     Assume.assumeTrue(checkMaxAllowedPacketMore20m("serverBulk20mTest"));
     Assume.assumeTrue(runLongTest);
     Assume.assumeFalse(sharedIsAurora());
+    Assume.assumeTrue(isMariadbServer());
 
     sharedConnection.createStatement().execute("TRUNCATE TABLE ExecuteBatchTest");
 
-    try (Connection connection = setConnection(
-        "&useComMulti=false&useBatchMultiSend=true&profileSql=" + profileSql)) {
-      PreparedStatement preparedStatement = connection
-          .prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
-      //packet size : 7 200 068 kb
-      addBatchData(preparedStatement, 160000, connection);
+    try (Connection connection =
+        setConnection(
+            "&useBulkStmts=true&useComMulti=false&useBatchMultiSend=true&profileSql="
+                + profileSql)) {
+      PreparedStatement preparedStatement =
+          connection.prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
+      // packet size : 7 200 068 kb
+      addBatchData(preparedStatement, 160000, connection, false, false || !minVersion(10, 2));
     }
   }
 
   @Test
-  public void serverStd8mTest() throws SQLException {
-    Assume.assumeTrue(checkMaxAllowedPacketMore8m("serverStd8mTest"));
+  public void serverStd1mTest() throws SQLException {
+    Assume.assumeTrue(checkMaxAllowedPacketMore8m("serverStd1mTest"));
     Assume.assumeTrue(runLongTest);
     sharedConnection.createStatement().execute("TRUNCATE TABLE ExecuteBatchTest");
 
-    try (Connection connection = setConnection(
-        "&useComMulti=false&useBatchMultiSend=false&profileSql=" + profileSql)) {
-      PreparedStatement preparedStatement = connection
-          .prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
-      addBatchData(preparedStatement, 60000, connection);
+    try (Connection connection =
+        setConnection("&useComMulti=false&useBatchMultiSend=false&profileSql=" + profileSql)) {
+      PreparedStatement preparedStatement =
+          connection.prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
+      addBatchData(preparedStatement, 10000, connection, false, !sharedIsRewrite());
     }
   }
 
   @Test
   public void clientBulkTest() throws SQLException {
-    Assume.assumeTrue(checkMaxAllowedPacketMore8m("serverStd8mTest"));
+    Assume.assumeTrue(checkMaxAllowedPacketMore8m("clientBulkTest"));
     Assume.assumeTrue(runLongTest);
     Assume.assumeFalse(sharedIsAurora());
+    Assume.assumeTrue(isMariadbServer());
 
     sharedConnection.createStatement().execute("TRUNCATE TABLE ExecuteBatchTest");
 
-    try (Connection connection = setConnection(
-        "&useComMulti=false&useBatchMultiSend=true&useServerPrepStmts=false&profileSql="
-            + profileSql)) {
-      PreparedStatement preparedStatement = connection
-          .prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
-      addBatchData(preparedStatement, 60000, connection);
+    try (Connection connection =
+        setConnection(
+            "&useBulkStmts=true&useComMulti=false&useBatchMultiSend=true&useServerPrepStmts"
+                + "=false&profileSql="
+                + profileSql)) {
+      PreparedStatement preparedStatement =
+          connection.prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
+      addBatchData(preparedStatement, 10000, connection, false, false || !minVersion(10, 2));
     }
   }
 
   @Test
-  public void clientRewriteValuesNotPossible8mTest() throws SQLException {
-    Assume.assumeTrue(checkMaxAllowedPacketMore8m("clientRewriteValuesNotPossibleTest"));
+  public void clientMultipleTest() throws SQLException {
+    Assume.assumeTrue(checkMaxAllowedPacketMore8m("clientMultipleTest"));
     Assume.assumeTrue(runLongTest);
+    Assume.assumeFalse(sharedIsAurora());
+    Assume.assumeTrue(isMariadbServer());
+
     sharedConnection.createStatement().execute("TRUNCATE TABLE ExecuteBatchTest");
-    try (Connection connection = setConnection(
-        "&rewriteBatchedStatements=true&profileSql=" + profileSql)) {
-      PreparedStatement preparedStatement = connection.prepareStatement(
-          "INSERT INTO ExecuteBatchTest(test, test2) values (?, ?) ON DUPLICATE KEY UPDATE id=?");
-      addBatchData(preparedStatement, 60000, connection, true, true);
+
+    try (Connection connection =
+        setConnection(
+            "&useBulkStmts=false&useComMulti=false&useBatchMultiSend=true&useServerPrepStmts"
+                + "=false&profileSql="
+                + profileSql)) {
+      PreparedStatement preparedStatement =
+          connection.prepareStatement("INSERT INTO ExecuteBatchTest(test, test2) values (?, ?)");
+      addBatchData(preparedStatement, 10000, connection, false, !sharedIsRewrite());
     }
   }
 
   @Test
-  public void clientRewriteValuesNotPossible20mTest() throws SQLException {
-    Assume.assumeTrue(checkMaxAllowedPacketMore8m("clientRewriteValuesNotPossibleTest"));
+  public void clientRewriteValuesNotPossible1mTest() throws SQLException {
+    Assume.assumeTrue(checkMaxAllowedPacketMore8m("clientRewriteValuesNotPossible1mTest"));
     Assume.assumeTrue(runLongTest);
     sharedConnection.createStatement().execute("TRUNCATE TABLE ExecuteBatchTest");
-    try (Connection connection = setConnection(
-        "&rewriteBatchedStatements=true&profileSql=" + profileSql)) {
-      PreparedStatement preparedStatement = connection.prepareStatement(
-          "INSERT INTO ExecuteBatchTest(test, test2) values (?, ?) ON DUPLICATE KEY UPDATE id=?");
-      addBatchData(preparedStatement, 160000, connection, true, true);
+    try (Connection connection =
+        setConnection("&rewriteBatchedStatements=true&profileSql=" + profileSql)) {
+      PreparedStatement preparedStatement =
+          connection.prepareStatement(
+              "INSERT INTO ExecuteBatchTest(test, test2) values (?, ?) ON DUPLICATE KEY UPDATE id=?");
+      addBatchData(preparedStatement, 10000, connection, true, true);
     }
   }
 
-  private void addBatchData(PreparedStatement preparedStatement, int batchNumber,
-      Connection connection) throws SQLException {
+  private void addBatchData(
+      PreparedStatement preparedStatement, int batchNumber, Connection connection)
+      throws SQLException {
     addBatchData(preparedStatement, batchNumber, connection, false, false);
   }
 
-  private void addBatchData(PreparedStatement preparedStatement, int batchNumber,
-      Connection connection, boolean additionnalParameter, boolean sendUnique)
+  private void addBatchData(
+      PreparedStatement preparedStatement,
+      int batchNumber,
+      Connection connection,
+      boolean additionnalParameter,
+      boolean sendUnique)
       throws SQLException {
     for (int i = 0; i < batchNumber; i++) {
       preparedStatement.setString(1, oneHundredLengthString);
@@ -290,25 +294,23 @@ public class ExecuteBatchTest extends BaseTest {
     }
     int[] resultInsert = preparedStatement.executeBatch();
 
-    //test result Size
+    // test result Size
     assertEquals(batchNumber, resultInsert.length);
     for (int i = 0; i < batchNumber; i++) {
-      if ((!sendUnique && sharedIsRewrite())
-              || (sharedOptions().useBulkStmts
-              && isMariadbServer()
-              && minVersion(10, 2))) {
+      if (!sendUnique || (sharedOptions().useBulkStmts && isMariadbServer() && minVersion(10, 2))) {
         assertEquals(Statement.SUCCESS_NO_INFO, resultInsert[i]);
       } else {
         assertEquals(1, resultInsert[i]);
       }
     }
 
-    //check that connection is OK and results are well inserted
-    ResultSet resultSet = connection.createStatement()
-        .executeQuery("SELECT * FROM ExecuteBatchTest");
+    // check that connection is OK and results are well inserted
+    ResultSet resultSet =
+        connection.createStatement().executeQuery("SELECT * FROM ExecuteBatchTest");
     for (int i = 0; i < batchNumber; i++) {
       assertTrue(resultSet.next());
-      if (!sharedOptions().useBulkStmts) {
+      if (sendUnique
+          && (!sharedOptions().useBulkStmts || !isMariadbServer() || !minVersion(10, 2))) {
         assertEquals(i + 1, resultSet.getInt(1));
       }
       assertEquals(oneHundredLengthString, resultSet.getString(2));
@@ -331,9 +333,7 @@ public class ExecuteBatchTest extends BaseTest {
         assertEquals(10, updateCounts.length);
         for (int updateCount : updateCounts) {
           if ((sharedIsRewrite()
-              || (sharedOptions().useBulkStmts
-              && isMariadbServer()
-              && minVersion(10, 2)))) {
+              || (sharedOptions().useBulkStmts && isMariadbServer() && minVersion(10, 2)))) {
             assertEquals(Statement.SUCCESS_NO_INFO, updateCount);
           } else {
             assertEquals(1, updateCount);
@@ -366,28 +366,32 @@ public class ExecuteBatchTest extends BaseTest {
     AtomicInteger counter = new AtomicInteger();
     ExecutorService exec = Executors.newFixedThreadPool(limit + 50);
     for (int i = 0; i < limit; i++) {
-      exec.execute(() -> {
-        try (Connection connection = setConnection()) {
-          connection.setAutoCommit(false);
-          Statement stmt = connection.createStatement();
-          int connectionCounter = counter.getAndIncrement();
-          for (int j = 0; j < 1024; j++) {
-            stmt.addBatch(
-                "INSERT INTO multipleSimultaneousBatch_" + connectionCounter + "(a) VALUES (" + j
-                    + ")");
-          }
-          stmt.executeBatch();
-          connection.commit();
-        } catch (Throwable e) {
-          e.printStackTrace();
-        }
-      });
+      exec.execute(
+          () -> {
+            try (Connection connection = setConnection()) {
+              connection.setAutoCommit(false);
+              Statement stmt = connection.createStatement();
+              int connectionCounter = counter.getAndIncrement();
+              for (int j = 0; j < 1024; j++) {
+                stmt.addBatch(
+                    "INSERT INTO multipleSimultaneousBatch_"
+                        + connectionCounter
+                        + "(a) VALUES ("
+                        + j
+                        + ")");
+              }
+              stmt.executeBatch();
+              connection.commit();
+            } catch (Throwable e) {
+              e.printStackTrace();
+            }
+          });
     }
 
     exec.shutdown();
     exec.awaitTermination(150, TimeUnit.SECONDS);
 
-    //check results
+    // check results
     Statement stmt = sharedConnection.createStatement();
     for (int i = 0; i < limit; i++) {
       ResultSet rs = stmt.executeQuery("SELECT count(*) from multipleSimultaneousBatch_" + i);
@@ -396,7 +400,6 @@ public class ExecuteBatchTest extends BaseTest {
     }
   }
 
-
   @Test
   public void useBatchMultiSendWithError() throws Exception {
     Assume.assumeFalse(sharedIsAurora());
@@ -415,8 +418,9 @@ public class ExecuteBatchTest extends BaseTest {
     properties.setProperty("useBatchMultiSend", "true");
     try (Connection connection = createProxyConnection(properties)) {
       Statement stmt = connection.createStatement();
-      stmt.execute("CREATE TEMPORARY TABLE useBatchMultiSendWithError (id INT NOT NULL,"
-          + "UNIQUE INDEX `index1` (id))");
+      stmt.execute(
+          "CREATE TEMPORARY TABLE useBatchMultiSendWithError (id INT NOT NULL,"
+              + "UNIQUE INDEX `index1` (id))");
       String sql = "insert into useBatchMultiSendWithError (id) values (?)";
       try (PreparedStatement pstmt = connection.prepareStatement(sql)) {
         for (int i = 0; i < 200000; i++) {
@@ -425,9 +429,12 @@ public class ExecuteBatchTest extends BaseTest {
         }
 
         final ScheduledThreadPoolExecutor executor = new ScheduledThreadPoolExecutor(1);
-        executor.schedule(() -> {
-          stopProxy();
-        }, 10, TimeUnit.MILLISECONDS);
+        executor.schedule(
+            () -> {
+              stopProxy();
+            },
+            10,
+            TimeUnit.MILLISECONDS);
 
         try {
           pstmt.executeBatch();
@@ -445,9 +452,7 @@ public class ExecuteBatchTest extends BaseTest {
           }
           restartProxy();
         }
-
       }
     }
   }
-
 }
