@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,18 +52,12 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import org.junit.*;
 
-import java.io.IOException;
-import java.io.InputStream;
-import java.sql.Connection;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Test;
+import java.io.*;
+import java.sql.*;
+
+import static org.junit.Assert.*;
 
 public class GiganticLoadDataInfileTest extends BaseTest {
 
@@ -74,7 +68,8 @@ public class GiganticLoadDataInfileTest extends BaseTest {
    */
   @BeforeClass()
   public static void initClass() throws SQLException {
-    createTable("gigantic_load_data_infile",
+    createTable(
+        "gigantic_load_data_infile",
         "id int not null primary key auto_increment, name char(20)",
         "ENGINE=myisam");
   }
@@ -88,7 +83,8 @@ public class GiganticLoadDataInfileTest extends BaseTest {
         MariaDbStatement mariaDbStatement = statement.unwrap(MariaDbStatement.class);
         mariaDbStatement.setLocalInfileInputStream(in);
 
-        String sql = "LOAD DATA LOCAL INFILE 'dummyFileName'"
+        String sql =
+            "LOAD DATA LOCAL INFILE 'dummyFileName'"
                 + " INTO TABLE gigantic_load_data_infile "
                 + " FIELDS TERMINATED BY '\\t' ENCLOSED BY ''"
                 + " ESCAPED BY '\\\\' LINES TERMINATED BY '\\n'";
@@ -101,9 +97,7 @@ public class GiganticLoadDataInfileTest extends BaseTest {
     }
   }
 
-  /**
-   * Custom memory conserving generator of a LOAD DATA INFILE that generates a stream.
-   */
+  /** Custom memory conserving generator of a LOAD DATA INFILE that generates a stream. */
   private static class VeryLongAutoGeneratedInputStream extends InputStream {
 
     private final int numberOfRows;
@@ -132,5 +126,4 @@ public class GiganticLoadDataInfileTest extends BaseTest {
       return buffer[currentPosInBuffer++];
     }
   }
-
 }
