@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,27 +52,12 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.io.BufferedInputStream;
-import java.io.BufferedWriter;
-import java.io.ByteArrayInputStream;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileWriter;
-import java.io.IOException;
-import java.io.InputStream;
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import org.junit.Assume;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import java.io.*;
+import java.sql.*;
+
+import static org.junit.Assert.*;
 
 public class LocalInfileInputStreamTest extends BaseTest {
 
@@ -86,26 +71,26 @@ public class LocalInfileInputStreamTest extends BaseTest {
     createTable("LocalInfileInputStreamTest", "id int, test varchar(100)");
     createTable("ttlocal", "id int, test varchar(100)");
     createTable("ldinfile", "a varchar(10)");
-    createTable("`infile`", "`a` varchar(50) DEFAULT NULL, `b` varchar(50) DEFAULT NULL",
+    createTable(
+        "`infile`",
+        "`a` varchar(50) DEFAULT NULL, `b` varchar(50) DEFAULT NULL",
         "ENGINE=InnoDB DEFAULT CHARSET=latin1");
   }
 
   @Test
   public void testLocalInfileInputStream() throws SQLException {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     try (Connection connection = setConnection("&allowLocalInfile=true")) {
       try (Statement st = connection.createStatement()) {
         // Build a tab-separated record file
-        String builder = "1\thello\n"
-                + "2\tworld\n";
+        String builder = "1\thello\n" + "2\tworld\n";
 
         InputStream inputStream = new ByteArrayInputStream(builder.getBytes());
         ((MariaDbStatement) st).setLocalInfileInputStream(inputStream);
 
         st.executeUpdate(
-                "LOAD DATA LOCAL INFILE 'dummy.tsv' INTO TABLE LocalInfileInputStreamTest (id, test)");
+            "LOAD DATA LOCAL INFILE 'dummy.tsv' INTO TABLE LocalInfileInputStreamTest (id, test)");
 
         ResultSet rs = st.executeQuery("SELECT COUNT(*) FROM LocalInfileInputStreamTest");
         assertTrue(rs.next());
@@ -124,8 +109,7 @@ public class LocalInfileInputStreamTest extends BaseTest {
   @Test
   public void testLocalInfileValidInterceptor() throws Exception {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     File temp = File.createTempFile("validateInfile", ".txt");
     StringBuilder builder = new StringBuilder();
     builder.append("1,hello\n");
@@ -141,8 +125,7 @@ public class LocalInfileInputStreamTest extends BaseTest {
   @Test
   public void testLocalInfileUnValidInterceptor() throws Exception {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     File temp = File.createTempFile("localInfile", ".txt");
     StringBuilder builder = new StringBuilder();
     builder.append("1,hello\n");
@@ -156,11 +139,12 @@ public class LocalInfileInputStreamTest extends BaseTest {
         fail("Must have been intercepted");
       } catch (SQLException sqle) {
         assertTrue(
-                sqle.getMessage().contains("LOAD DATA LOCAL INFILE request to send local file named")
-                        && sqle.getMessage().contains(
+            sqle.getMessage().contains("LOAD DATA LOCAL INFILE request to send local file named")
+                && sqle.getMessage()
+                    .contains(
                         "not validated by interceptor \"org.mariadb.jdbc.LocalInfileInterceptorImpl\""));
       }
-      //check that connection state is correct
+      // check that connection state is correct
       Statement st = connection.createStatement();
       ResultSet rs = st.executeQuery("SELECT 1");
       assertTrue(rs.next());
@@ -168,10 +152,11 @@ public class LocalInfileInputStreamTest extends BaseTest {
     }
   }
 
-
   private void testLocalInfile(Connection connection, String file) throws SQLException {
     try (Statement st = connection.createStatement()) {
-      st.executeUpdate("LOAD DATA LOCAL INFILE '" + file
+      st.executeUpdate(
+          "LOAD DATA LOCAL INFILE '"
+              + file
               + "' INTO TABLE ttlocal "
               + "  FIELDS TERMINATED BY ',' OPTIONALLY ENCLOSED BY '\"'"
               + "  (id, test)");
@@ -191,14 +176,15 @@ public class LocalInfileInputStreamTest extends BaseTest {
   @Test
   public void loadDataInfileEmpty() throws SQLException, IOException {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     // Create temp file.
     File temp = File.createTempFile("validateInfile", ".tmp");
     try (Connection connection = setConnection("&allowLocalInfile=true")) {
       Statement st = connection.createStatement();
-      st.execute("LOAD DATA LOCAL INFILE '" + temp.getAbsolutePath().replace('\\', '/')
-          + "' INTO TABLE ldinfile");
+      st.execute(
+          "LOAD DATA LOCAL INFILE '"
+              + temp.getAbsolutePath().replace('\\', '/')
+              + "' INTO TABLE ldinfile");
       try (ResultSet rs = st.executeQuery("SELECT * FROM ldinfile")) {
         assertFalse(rs.next());
       }
@@ -210,18 +196,17 @@ public class LocalInfileInputStreamTest extends BaseTest {
   @Test
   public void testPrepareLocalInfileWithoutInputStream() throws SQLException {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     try (Connection connection = setConnection("&allowLocalInfile=true")) {
       try {
-        PreparedStatement st = connection
-                .prepareStatement("LOAD DATA LOCAL INFILE 'validateInfile.tsv' "
-                        + "INTO TABLE ldinfile");
+        PreparedStatement st =
+            connection.prepareStatement(
+                "LOAD DATA LOCAL INFILE 'validateInfile.tsv' " + "INTO TABLE ldinfile");
         st.execute();
         fail();
       } catch (SQLException e) {
         assertTrue(e.getMessage().contains("Could not send file"));
-        //check that connection is alright
+        // check that connection is alright
         try {
           assertFalse(connection.isClosed());
           Statement st = connection.createStatement();
@@ -246,7 +231,7 @@ public class LocalInfileInputStreamTest extends BaseTest {
   private File createTmpData(long recordNumber) throws Exception {
     File file = File.createTempFile("./infile" + recordNumber, ".tmp");
 
-    //write it
+    // write it
     try (BufferedWriter writer = new BufferedWriter(new FileWriter(file))) {
       // Every row is 8 bytes to make counting easier
       for (long i = 0; i < recordNumber; i++) {
@@ -268,14 +253,16 @@ public class LocalInfileInputStreamTest extends BaseTest {
         try (InputStream is = new BufferedInputStream(new FileInputStream(file))) {
           MariaDbStatement stmt = statement.unwrap(MariaDbStatement.class);
           stmt.setLocalInfileInputStream(is);
-          int insertNumber = stmt.executeUpdate("LOAD DATA LOCAL INFILE 'ignoredFileName' "
-                  + "INTO TABLE `infile` "
-                  + "COLUMNS TERMINATED BY ',' ENCLOSED BY '\\\"' ESCAPED BY '\\\\' "
-                  + "LINES TERMINATED BY '\\n' (`a`, `b`)");
+          int insertNumber =
+              stmt.executeUpdate(
+                  "LOAD DATA LOCAL INFILE 'ignoredFileName' "
+                      + "INTO TABLE `infile` "
+                      + "COLUMNS TERMINATED BY ',' ENCLOSED BY '\\\"' ESCAPED BY '\\\\' "
+                      + "LINES TERMINATED BY '\\n' (`a`, `b`)");
           assertEquals(insertNumber, recordNumber);
         }
         file.delete();
-        statement.setFetchSize(1000); //to avoid using too much memory for tests
+        statement.setFetchSize(1000); // to avoid using too much memory for tests
         try (ResultSet rs = statement.executeQuery("SELECT * FROM `infile`")) {
           for (int i = 0; i < recordNumber; i++) {
             assertTrue("record " + i + " doesn't exist", rs.next());
@@ -296,16 +283,14 @@ public class LocalInfileInputStreamTest extends BaseTest {
   @Test
   public void testSmallBigLocalInfileInputStream() throws Exception {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     checkBigLocalInfile(256);
   }
 
   @Test
   public void test2xBigLocalInfileInputStream() throws Exception {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     Assume.assumeTrue(checkMaxAllowedPacketMore40m("test2xBigLocalInfileInputStream"));
     checkBigLocalInfile(16777216 * 2);
   }
@@ -313,8 +298,7 @@ public class LocalInfileInputStreamTest extends BaseTest {
   @Test
   public void testMoreThanMaxAllowedPacketLocalInfileInputStream() throws Exception {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
     Assume.assumeFalse(sharedIsAurora());
     Statement stmt = sharedConnection.createStatement();
@@ -324,5 +308,4 @@ public class LocalInfileInputStreamTest extends BaseTest {
     Assume.assumeTrue(maxAllowedPacket < 100_000_000);
     checkBigLocalInfile(maxAllowedPacket + 1024);
   }
-
 }
