@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,22 +52,14 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
+import org.mariadb.jdbc.internal.util.constant.*;
+import org.mariadb.jdbc.util.*;
 
-import java.sql.Connection;
-import java.sql.DriverManager;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.util.ArrayList;
-import java.util.Properties;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.mariadb.jdbc.internal.util.DefaultOptions;
-import org.mariadb.jdbc.internal.util.constant.HaMode;
+import java.sql.*;
+import java.util.*;
+
+import static org.junit.Assert.*;
 
 public class ParserTest extends BaseTest {
 
@@ -86,8 +78,9 @@ public class ParserTest extends BaseTest {
   public void poolVerification() throws Exception {
     ArrayList<HostAddress> hostAddresses = new ArrayList<>();
     hostAddresses.add(new HostAddress(hostname, port));
-    UrlParser urlParser = new UrlParser(database, hostAddresses,
-        DefaultOptions.defaultValues(HaMode.NONE), HaMode.NONE);
+    UrlParser urlParser =
+        new UrlParser(
+            database, hostAddresses, DefaultOptions.defaultValues(HaMode.NONE), HaMode.NONE);
     urlParser.setUsername("USER");
     urlParser.setPassword("PWD");
     urlParser.parseUrl("jdbc:mariadb://localhost:3306/db");
@@ -118,7 +111,6 @@ public class ParserTest extends BaseTest {
         UrlParser.parse("jdbc:mariadb:sequential://host1,host2/", emptyProps).isMultiMaster());
     assertTrue(
         UrlParser.parse("jdbc:mariadb:loadbalance://host1,host2/", emptyProps).isMultiMaster());
-
   }
 
   @Test
@@ -143,7 +135,8 @@ public class ParserTest extends BaseTest {
       sql = "INSERT INTO table2 VALUES (1),(2),(3),(4),(5),(6)";
       statement.execute(sql);
       // uppercase OJ
-      sql = "SELECT table1.id1, table2.id2 FROM { OJ table1 LEFT OUTER JOIN table2 ON table1.id1 = table2.id2 }";
+      sql =
+          "SELECT table1.id1, table2.id2 FROM { OJ table1 LEFT OUTER JOIN table2 ON table1.id1 = table2.id2 }";
       ResultSet rs = statement.executeQuery(sql);
       for (int count = 1; count <= 6; count++) {
         assertTrue(rs.next());
@@ -151,7 +144,8 @@ public class ParserTest extends BaseTest {
         assertEquals(count, rs.getInt(2));
       }
       // mixed oJ
-      sql = "SELECT table1.id1, table2.id2 FROM { oJ table1 LEFT OUTER JOIN table2 ON table1.id1 = table2.id2 }";
+      sql =
+          "SELECT table1.id1, table2.id2 FROM { oJ table1 LEFT OUTER JOIN table2 ON table1.id1 = table2.id2 }";
       rs = statement.executeQuery(sql);
       for (int count = 1; count <= 6; count++) {
         assertTrue(rs.next());
@@ -166,12 +160,14 @@ public class ParserTest extends BaseTest {
   @Test
   public void auroraClusterVerification() {
     try {
-      DriverManager.getConnection("jdbc:mariadb:aurora://"
-          + "1.somehex.us-east-1.rds.amazonaws.com,"
-          + "2.someOtherHex.us-east-1.rds.amazonaws.com/testj");
+      DriverManager.getConnection(
+          "jdbc:mariadb:aurora://"
+              + "1.somehex.us-east-1.rds.amazonaws.com,"
+              + "2.someOtherHex.us-east-1.rds.amazonaws.com/testj");
       fail("must have fail since not same cluster");
     } catch (Exception e) {
-      assertEquals("Connection string must contain only one aurora cluster. "
+      assertEquals(
+          "Connection string must contain only one aurora cluster. "
               + "'2.someOtherHex.us-east-1.rds.amazonaws.com' doesn't correspond to DNS prefix "
               + "'somehex.us-east-1.rds.amazonaws.com'",
           e.getMessage());
