@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,16 +52,12 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.nio.charset.Charset;
-import java.sql.Connection;
-import java.sql.DriverManager;
-import java.sql.SQLException;
-import java.sql.SQLInvalidAuthorizationSpecException;
-import java.sql.Statement;
-import org.junit.Assume;
-import org.junit.Test;
+import java.nio.charset.*;
+import java.sql.*;
+
+import static org.junit.Assert.*;
 
 public class PasswordEncodingTest extends BaseTest {
 
@@ -69,38 +65,46 @@ public class PasswordEncodingTest extends BaseTest {
 
   @Test
   public void testPwdCharset() throws Exception {
-    //aurora user has no right to create other user
+    // aurora user has no right to create other user
     Assume.assumeFalse("true".equals(System.getenv("AURORA")));
     Assume.assumeFalse(anonymousUser());
 
-    String[] charsets = new String[]{"UTF-8",
-        "windows-1252",
-        "Big5"};
-    String[] charsetsMysql = new String[]{"utf8",
-        "latin1",
-        "big5"};
+    String[] charsets = new String[] {"UTF-8", "windows-1252", "Big5"};
+    String[] charsetsMysql = new String[] {"utf8", "latin1", "big5"};
     try {
       for (int i = 0; i < charsets.length; i++) {
         createUser(charsets[i], charsetsMysql[i]);
       }
 
       for (String currentCharsetName : charsets) {
-        try (Connection connection = DriverManager
-            .getConnection("jdbc:mariadb://" + ((hostname != null) ? hostname : "localhost")
-                + ":" + port + "/" + database + "?user=test" + currentCharsetName + "&password="
-                + exoticPwd)) {
-          //windows-1252 and windows-1250 will work have the same conversion for this password
+        try (Connection connection =
+            DriverManager.getConnection(
+                "jdbc:mariadb://"
+                    + ((hostname != null) ? hostname : "localhost")
+                    + ":"
+                    + port
+                    + "/"
+                    + database
+                    + "?user=test"
+                    + currentCharsetName
+                    + "&password="
+                    + exoticPwd)) {
+          // windows-1252 and windows-1250 will work have the same conversion for this password
           if (!currentCharsetName.equals(Charset.defaultCharset().name())
-              && (!"windows-1252".equals(currentCharsetName) || !Charset.defaultCharset().name()
-              .startsWith("windows-125"))) {
-            fail("must have failed for currentCharsetName=" + currentCharsetName
-                + " using java default charset "
-                + Charset.defaultCharset().name());
+              && (!"windows-1252".equals(currentCharsetName)
+                  || !Charset.defaultCharset().name().startsWith("windows-125"))) {
+            fail(
+                "must have failed for currentCharsetName="
+                    + currentCharsetName
+                    + " using java default charset "
+                    + Charset.defaultCharset().name());
           }
         } catch (SQLInvalidAuthorizationSpecException sqle) {
           if (currentCharsetName.equals(Charset.defaultCharset().name())) {
-            fail("must have not have failed for charsetName=" + currentCharsetName
-                + " which is java default");
+            fail(
+                "must have not have failed for charsetName="
+                    + currentCharsetName
+                    + " which is java default");
           }
         }
       }
@@ -114,12 +118,10 @@ public class PasswordEncodingTest extends BaseTest {
         try {
           stmt.execute("DROP USER 'test" + charsetName + "'@'%'");
         } catch (SQLException e) {
-          //nothing
+          // nothing
         }
       }
     }
-
-
   }
 
   private void createUser(String charsetName, String serverCharset) throws Exception {
@@ -129,8 +131,8 @@ public class PasswordEncodingTest extends BaseTest {
       stmt.execute("set @@character_set_client='" + serverCharset + "'");
 
       boolean useOldNotation = true;
-      if ((isMariadbServer() && minVersion(10, 2, 0)) || (!isMariadbServer() && minVersion(8, 0,
-          0))) {
+      if ((isMariadbServer() && minVersion(10, 2, 0))
+          || (!isMariadbServer() && minVersion(8, 0, 0))) {
         useOldNotation = false;
       }
       if (useOldNotation) {
@@ -144,7 +146,6 @@ public class PasswordEncodingTest extends BaseTest {
             "CREATE USER 'test" + charsetName + "'@'%' identified by '" + exoticPwd + "'",
             Charset.forName(charsetName));
         stmt.execute("GRANT ALL on *.* to 'test" + charsetName + "'@'%'");
-
       }
       stmt.execute("FLUSH PRIVILEGES");
     }
@@ -153,22 +154,37 @@ public class PasswordEncodingTest extends BaseTest {
   private void checkConnection(String charsetName, String[] charsets) throws Exception {
 
     for (String currentCharsetName : charsets) {
-      try (Connection connection = DriverManager
-          .getConnection("jdbc:mariadb://" + ((hostname != null) ? hostname : "localhost")
-              + ":" + port + "/" + database + "?user=test" + charsetName + "&password="
-              + exoticPwd + "&passwordCharacterEncoding=" + currentCharsetName)) {
+      try (Connection connection =
+          DriverManager.getConnection(
+              "jdbc:mariadb://"
+                  + ((hostname != null) ? hostname : "localhost")
+                  + ":"
+                  + port
+                  + "/"
+                  + database
+                  + "?user=test"
+                  + charsetName
+                  + "&password="
+                  + exoticPwd
+                  + "&passwordCharacterEncoding="
+                  + currentCharsetName)) {
         if (!currentCharsetName.equals(charsetName)) {
-          fail("must have failed for charsetName=" + charsetName
-              + " using passwordCharacterEncoding=" + currentCharsetName);
+          fail(
+              "must have failed for charsetName="
+                  + charsetName
+                  + " using passwordCharacterEncoding="
+                  + currentCharsetName);
         }
 
       } catch (SQLInvalidAuthorizationSpecException sqle) {
         if (currentCharsetName.equals(charsetName)) {
-          fail("must not have failed for charsetName=" + charsetName
-              + " using passwordCharacterEncoding=" + currentCharsetName);
+          fail(
+              "must not have failed for charsetName="
+                  + charsetName
+                  + " using passwordCharacterEncoding="
+                  + currentCharsetName);
         }
       }
     }
   }
-
 }
