@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,23 +52,12 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.io.UnsupportedEncodingException;
-import java.math.BigInteger;
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.SQLSyntaxErrorException;
-import java.sql.Statement;
-import java.sql.Types;
-import org.junit.Assume;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import java.math.*;
+import java.sql.*;
+
+import static org.junit.Assert.*;
 
 public class PreparedStatementTest extends BaseTest {
 
@@ -84,9 +73,12 @@ public class PreparedStatementTest extends BaseTest {
   public static void initClass() throws SQLException {
     createTable("table1", "id1 int auto_increment primary key");
     createTable("table2", "id2 int auto_increment primary key");
-    createTable("`testBigintTable`", "`id` bigint(20) unsigned NOT NULL, PRIMARY KEY (`id`)",
+    createTable(
+        "`testBigintTable`",
+        "`id` bigint(20) unsigned NOT NULL, PRIMARY KEY (`id`)",
         "ENGINE=InnoDB DEFAULT CHARSET=utf8");
-    createTable("`backTicksPreparedStatements`",
+    createTable(
+        "`backTicksPreparedStatements`",
         "`id` int(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,"
             + "`SLIndex#orBV#` text,"
             + "`isM&M'sTasty?` bit(1) DEFAULT NULL,"
@@ -95,8 +87,8 @@ public class PreparedStatementTest extends BaseTest {
         "ENGINE=InnoDB DEFAULT CHARSET=utf8");
     createTable("test_insert_select", "`field1` varchar(20)");
     createTable("test_decimal_insert", "`field1` decimal(10, 7)");
-    createTable("PreparedStatementTest1",
-        "id int not null primary key auto_increment, test longblob");
+    createTable(
+        "PreparedStatementTest1", "id int not null primary key auto_increment, test longblob");
     createTable("PreparedStatementTest2", "my_col varchar(20)");
     createTable("PreparedStatementTest3", "my_col varchar(20)");
   }
@@ -106,7 +98,6 @@ public class PreparedStatementTest extends BaseTest {
     PreparedStatement preparedStatement = sharedConnection.prepareStatement("SELECT ?");
     preparedStatement.close();
     preparedStatement.close();
-
   }
 
   /**
@@ -117,17 +108,17 @@ public class PreparedStatementTest extends BaseTest {
   @Test
   public void cannotPrepareExecuteFallback() throws Exception {
     sharedConnection.createStatement().execute("TRUNCATE test_insert_select");
-    PreparedStatement stmt = sharedConnection.prepareStatement(
-        "insert into test_insert_select ( field1) (select  TMP.field1 from (select ? `field1` from dual) TMP)",
-        Statement.RETURN_GENERATED_KEYS);
+    PreparedStatement stmt =
+        sharedConnection.prepareStatement(
+            "insert into test_insert_select ( field1) (select  TMP.field1 from (select ? `field1` from dual) TMP)",
+            Statement.RETURN_GENERATED_KEYS);
     stmt.setString(1, "test");
     stmt.execute();
-    ResultSet rs = sharedConnection.createStatement()
-        .executeQuery("select count(*) from test_insert_select");
+    ResultSet rs =
+        sharedConnection.createStatement().executeQuery("select count(*) from test_insert_select");
     assertTrue(rs.next());
   }
 
-
   /**
    * Conj-238 : query not preparable. check batch fallback.
    *
@@ -136,15 +127,16 @@ public class PreparedStatementTest extends BaseTest {
   @Test
   public void cannotPrepareBatchFallback() throws Exception {
     sharedConnection.createStatement().execute("TRUNCATE test_insert_select");
-    PreparedStatement stmt = sharedConnection.prepareStatement(
-        "insert into test_insert_select ( field1) (select  TMP.field1 from (select ? `field1` from dual) TMP)",
-        Statement.RETURN_GENERATED_KEYS);
+    PreparedStatement stmt =
+        sharedConnection.prepareStatement(
+            "insert into test_insert_select ( field1) (select  TMP.field1 from (select ? `field1` from dual) TMP)",
+            Statement.RETURN_GENERATED_KEYS);
     stmt.setString(1, "test");
     stmt.addBatch();
     stmt.executeBatch();
 
-    ResultSet rs = sharedConnection.createStatement()
-        .executeQuery("select count(*) from test_insert_select");
+    ResultSet rs =
+        sharedConnection.createStatement().executeQuery("select count(*) from test_insert_select");
     assertTrue(rs.next());
   }
 
@@ -155,15 +147,18 @@ public class PreparedStatementTest extends BaseTest {
    */
   @Test
   public void cannotPrepareMetadata() throws Exception {
-    Assume.assumeTrue(isMariadbServer() && !minVersion(10, 2)); //corrected in 10.2
-    PreparedStatement stmt = sharedConnection.prepareStatement(
-        "insert into test_insert_select ( field1) (select  TMP.field1 from (select ? `field1` from dual) TMP)");
+    Assume.assumeTrue(isMariadbServer() && !minVersion(10, 2)); // corrected in 10.2
+    PreparedStatement stmt =
+        sharedConnection.prepareStatement(
+            "insert into test_insert_select ( field1) (select  TMP.field1 from (select ? `field1` from dual) TMP)");
     try {
       stmt.getMetaData();
     } catch (SQLException e) {
-      assertTrue(e.getMessage().contains(
-          "If column exists but type cannot be identified (example 'select ? `field1` from dual'). "
-              + "Use CAST function to solve this problem (example 'select CAST(? as integer) `field1` from dual')"));
+      assertTrue(
+          e.getMessage()
+              .contains(
+                  "If column exists but type cannot be identified (example 'select ? `field1` from dual'). "
+                      + "Use CAST function to solve this problem (example 'select CAST(? as integer) `field1` from dual')"));
     }
   }
 
@@ -189,10 +184,10 @@ public class PreparedStatementTest extends BaseTest {
   }
 
   @Test
-  public void testNoSuchTableBatchUpdate() throws SQLException, UnsupportedEncodingException {
+  public void testNoSuchTableBatchUpdate() throws SQLException {
     sharedConnection.createStatement().execute("drop table if exists vendor_code_test");
-    PreparedStatement preparedStatement = sharedConnection
-        .prepareStatement("INSERT INTO vendor_code_test VALUES(?)");
+    PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement("INSERT INTO vendor_code_test VALUES(?)");
     preparedStatement.setString(1, "dummyValue");
     preparedStatement.addBatch();
 
@@ -214,8 +209,8 @@ public class PreparedStatementTest extends BaseTest {
   public void testBigInt() throws SQLException {
     Statement st = sharedConnection.createStatement();
     st.execute("INSERT INTO `testBigintTable` (`id`) VALUES (0)");
-    PreparedStatement stmt = sharedConnection
-        .prepareStatement("UPDATE `testBigintTable` SET `id` = ?");
+    PreparedStatement stmt =
+        sharedConnection.prepareStatement("UPDATE `testBigintTable` SET `id` = ?");
     BigInteger bigT = BigInteger.valueOf(System.currentTimeMillis());
     stmt.setObject(1, bigT);
     stmt.executeUpdate();
@@ -233,8 +228,8 @@ public class PreparedStatementTest extends BaseTest {
    */
   @Test
   public void testDoubleToDecimal() throws SQLException {
-    PreparedStatement stmt = sharedConnection
-        .prepareStatement("INSERT INTO test_decimal_insert (field1) VALUES (?)");
+    PreparedStatement stmt =
+        sharedConnection.prepareStatement("INSERT INTO test_decimal_insert (field1) VALUES (?)");
     Double value = 0.3456789;
     stmt.setObject(1, value, Types.DECIMAL, 7);
     stmt.executeUpdate();
@@ -248,18 +243,22 @@ public class PreparedStatementTest extends BaseTest {
   @Test
   public void testPreparedStatementsWithQuotes() throws SQLException {
 
-    String query = "INSERT INTO backTicksPreparedStatements (`SLIndex#orBV#`,`Seems:LikeParam?`,"
-        + "`Webinar10-TM/ProjComp`,`isM&M'sTasty?`)"
-        + " VALUES (?,?,?,?)";
+    String query =
+        "INSERT INTO backTicksPreparedStatements (`SLIndex#orBV#`,`Seems:LikeParam?`,"
+            + "`Webinar10-TM/ProjComp`,`isM&M'sTasty?`)"
+            + " VALUES (?,?,?,?)";
     PreparedStatement ps = sharedConnection.prepareStatement(query);
     ps.setString(1, "slIndex");
     ps.setBoolean(2, false);
     ps.setString(3, "webinar10");
     ps.setBoolean(4, true);
     ps.execute();
-    ResultSet rs = sharedConnection.createStatement()
-        .executeQuery("SELECT `SLIndex#orBV#`,`Seems:LikeParam?`,"
-            + "`Webinar10-TM/ProjComp`,`isM&M'sTasty?` FROM backTicksPreparedStatements");
+    ResultSet rs =
+        sharedConnection
+            .createStatement()
+            .executeQuery(
+                "SELECT `SLIndex#orBV#`,`Seems:LikeParam?`,"
+                    + "`Webinar10-TM/ProjComp`,`isM&M'sTasty?` FROM backTicksPreparedStatements");
     assertTrue(rs.next());
     assertEquals("slIndex", rs.getString(1));
     assertEquals(false, rs.getBoolean(2));
@@ -275,15 +274,14 @@ public class PreparedStatementTest extends BaseTest {
    */
   @Test
   public void testExecuteBatch() throws SQLException {
-    PreparedStatement preparedStatement = sharedConnection
-        .prepareStatement("INSERT INTO table1 VALUE ?");
+    PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement("INSERT INTO table1 VALUE ?");
     try {
       int[] result = preparedStatement.executeBatch();
       assertEquals(0, result.length);
     } catch (SQLException sqle) {
       fail("Must not throw error");
     }
-
   }
 
   /**
@@ -293,7 +291,9 @@ public class PreparedStatementTest extends BaseTest {
    */
   @Test
   public void testFallbackPrepare() throws SQLException {
-    createTable("testFallbackPrepare", "`test` varchar(500) COLLATE utf8mb4_unicode_ci NOT NULL",
+    createTable(
+        "testFallbackPrepare",
+        "`test` varchar(500) COLLATE utf8mb4_unicode_ci NOT NULL",
         "ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci");
     try (Connection connection = setConnection()) {
       Statement stmt = connection.createStatement();
@@ -301,8 +301,9 @@ public class PreparedStatementTest extends BaseTest {
       stmt.execute(
           "SELECT * FROM `testFallbackPrepare` WHERE `test` LIKE 'jj' COLLATE utf8mb4_unicode_ci");
 
-      try (PreparedStatement preparedStatement = connection.prepareStatement(
-          "SELECT * FROM `testFallbackPrepare` WHERE `test` LIKE ? COLLATE utf8mb4_unicode_ci")) {
+      try (PreparedStatement preparedStatement =
+          connection.prepareStatement(
+              "SELECT * FROM `testFallbackPrepare` WHERE `test` LIKE ? COLLATE utf8mb4_unicode_ci")) {
         preparedStatement.setString(1, "jj");
         preparedStatement.execute();
       } catch (SQLException sqle) {
@@ -318,13 +319,13 @@ public class PreparedStatementTest extends BaseTest {
    */
   @Test
   public void testCallExecuteErrorBatch() throws SQLException {
-    PreparedStatement pstmt = sharedConnection
-        .prepareStatement("SELECT 1;INSERT INTO INCORRECT_QUERY");
+    PreparedStatement pstmt =
+        sharedConnection.prepareStatement("SELECT 1;INSERT INTO INCORRECT_QUERY");
     try {
       pstmt.execute();
       fail("Must have thrown error");
     } catch (SQLSyntaxErrorException sqlSyntax) {
-      //normal exception
+      // normal exception
     } catch (SQLException sqle) {
       fail("must have thrown an SQLSyntaxErrorException");
     }
@@ -341,7 +342,7 @@ public class PreparedStatementTest extends BaseTest {
   }
 
   private void testRewriteMultiPacket(boolean notRewritable) throws SQLException {
-    //aurora server fail something
+    // aurora server fail something
     Assume.assumeFalse(sharedIsAurora());
 
     Statement statement = sharedConnection.createStatement();
@@ -349,10 +350,11 @@ public class PreparedStatementTest extends BaseTest {
     ResultSet rs = statement.executeQuery("select @@max_allowed_packet");
     assertTrue(rs.next());
     int maxAllowedPacket = rs.getInt(1);
-    if (maxAllowedPacket < 21_000_000) { //to avoid OutOfMemory
-      String query = "INSERT INTO PreparedStatementTest1 VALUES (null, ?)"
-          + (notRewritable ? " ON DUPLICATE KEY UPDATE id=?" : "");
-      //to have query exacting maxAllowedPacket size :
+    if (maxAllowedPacket < 21_000_000) { // to avoid OutOfMemory
+      String query =
+          "INSERT INTO PreparedStatementTest1 VALUES (null, ?)"
+              + (notRewritable ? " ON DUPLICATE KEY UPDATE id=?" : "");
+      // to have query exacting maxAllowedPacket size :
       // query size minus the ?
       // add first byte COM_QUERY
       // add 2 bytes (2 QUOTES for string parameter without need of escaping)
@@ -375,8 +377,8 @@ public class PreparedStatementTest extends BaseTest {
         int[] results = pstmt.executeBatch();
         assertEquals(2, results.length);
         for (int result : results) {
-          if (!notRewritable || (isMariadbServer() && minVersion(10, 2)
-              && sharedOptions().useBulkStmts)) {
+          if (!notRewritable
+              || (isMariadbServer() && minVersion(10, 2) && sharedOptions().useBulkStmts)) {
             assertEquals(Statement.SUCCESS_NO_INFO, result);
           } else {
             assertEquals(1, result);
@@ -398,7 +400,6 @@ public class PreparedStatementTest extends BaseTest {
     }
   }
 
-
   @Test
   public void testRewriteValuesMaxSize2Param() throws SQLException {
     Assume.assumeTrue(!sharedIsRewrite());
@@ -423,17 +424,18 @@ public class PreparedStatementTest extends BaseTest {
     ResultSet rs = statement.executeQuery("select @@max_allowed_packet");
     assertTrue(rs.next());
     int maxAllowedPacket = rs.getInt(1);
-    if (maxAllowedPacket < 21000000) { //to avoid OutOfMemory
-      String query = "INSERT INTO PreparedStatementTest1 VALUES (null, ?)"
-          + (rewritableMulti ? "" : " ON DUPLICATE KEY UPDATE id=?");
-      //to have query with exactly 2 values exacting maxAllowedPacket size :
+    if (maxAllowedPacket < 21000000) { // to avoid OutOfMemory
+      String query =
+          "INSERT INTO PreparedStatementTest1 VALUES (null, ?)"
+              + (rewritableMulti ? "" : " ON DUPLICATE KEY UPDATE id=?");
+      // to have query with exactly 2 values exacting maxAllowedPacket size :
       char[] arr = new char[(maxAllowedPacket - (query.length() + 18)) / 2];
       for (int i = 0; i < arr.length; i++) {
         arr[i] = (char) ('a' + (i % 10));
       }
 
-      try (Connection connection = setConnection(
-          "&rewriteBatchedStatements=true&profileSql=true")) {
+      try (Connection connection =
+          setConnection("&rewriteBatchedStatements=true&profileSql=true")) {
         PreparedStatement pstmt = connection.prepareStatement(query);
         for (int i = 0; i < 4; i++) {
           pstmt.setString(1, new String(arr));
@@ -444,8 +446,9 @@ public class PreparedStatementTest extends BaseTest {
         }
         int[] results = pstmt.executeBatch();
         assertEquals(4, results.length);
-        if (rewritableMulti || sharedIsRewrite() || (sharedOptions().useBulkStmts
-            && isMariadbServer() && minVersion(10, 2))) {
+        if (rewritableMulti
+            || sharedIsRewrite()
+            || (sharedOptions().useBulkStmts && isMariadbServer() && minVersion(10, 2))) {
           for (int result : results) {
             assertEquals(Statement.SUCCESS_NO_INFO, result);
           }
@@ -478,12 +481,14 @@ public class PreparedStatementTest extends BaseTest {
   @Test
   public void clientPrepareStatementWithoutParameter() throws Throwable {
     try (Connection connection = setConnection("&rewriteBatchedStatements=true")) {
-      PreparedStatement preparedStatement = connection
-          .prepareStatement("INSERT INTO PreparedStatementTest2 (my_col) VALUES ('my_val')");
+      PreparedStatement preparedStatement =
+          connection.prepareStatement(
+              "INSERT INTO PreparedStatementTest2 (my_col) VALUES ('my_val')");
       preparedStatement.execute();
 
-      PreparedStatement preparedStatementMulti = connection.prepareStatement(
-          "INSERT INTO PreparedStatementTest2 (my_col) VALUES ('my_val1'),('my_val2')");
+      PreparedStatement preparedStatementMulti =
+          connection.prepareStatement(
+              "INSERT INTO PreparedStatementTest2 (my_col) VALUES ('my_val1'),('my_val2')");
       preparedStatementMulti.execute();
     }
   }
@@ -515,8 +520,9 @@ public class PreparedStatementTest extends BaseTest {
    */
   @Test
   public void emptyStringParameter() throws Throwable {
-    try (PreparedStatement preparedStatement = sharedConnection
-        .prepareStatement("INSERT INTO PreparedStatementTest3 (my_col) VALUES (?)")) {
+    try (PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement(
+            "INSERT INTO PreparedStatementTest3 (my_col) VALUES (?)")) {
       preparedStatement.setString(1, "");
       preparedStatement.execute();
     }
@@ -524,8 +530,9 @@ public class PreparedStatementTest extends BaseTest {
 
   @Test
   public void nullStringParameter() throws Throwable {
-    try (PreparedStatement preparedStatement = sharedConnection
-        .prepareStatement("INSERT INTO PreparedStatementTest3 (my_col) VALUES (?)")) {
+    try (PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement(
+            "INSERT INTO PreparedStatementTest3 (my_col) VALUES (?)")) {
       preparedStatement.setString(1, null);
       preparedStatement.execute();
     }
@@ -533,7 +540,7 @@ public class PreparedStatementTest extends BaseTest {
 
   @Test
   public void testInsertSelectBulk() throws SQLException {
-    //bug https://jira.mariadb.org/browse/MDEV-15133
+    // bug https://jira.mariadb.org/browse/MDEV-15133
     cancelForVersion(10, 3, 0);
     cancelForVersion(10, 3, 1);
     cancelForVersion(10, 3, 2);
@@ -545,13 +552,15 @@ public class PreparedStatementTest extends BaseTest {
       statement.execute(
           "CREATE TABLE myTable(v1 varchar(10), v2 varchar(10), v3 varchar(10), v4 varchar(10))");
 
-      String[][] val = {{null, "b1", "c1", "d1"},
-          {"a2", null, "c2", "d2"},
-          {"a3", "b3", null, "d3"},
-          {"a4", "b4", "c4", null},
-          {"a5", "b5", "c5", "d5"}};
-      try (PreparedStatement preparedStatement = sharedConnection.prepareStatement(
-          "INSERT INTO myTable VALUES (?, ?, ?, ?)")) {
+      String[][] val = {
+        {null, "b1", "c1", "d1"},
+        {"a2", null, "c2", "d2"},
+        {"a3", "b3", null, "d3"},
+        {"a4", "b4", "c4", null},
+        {"a5", "b5", "c5", "d5"}
+      };
+      try (PreparedStatement preparedStatement =
+          sharedConnection.prepareStatement("INSERT INTO myTable VALUES (?, ?, ?, ?)")) {
         for (int i = 0; i < val.length; i++) {
           for (int j = 0; j < 4; j++) {
             preparedStatement.setString(j + 1, val[i][j]);
@@ -575,4 +584,34 @@ public class PreparedStatementTest extends BaseTest {
     }
   }
 
+  @Test
+  public void largePrepareUpdate() throws SQLException {
+    createTable(
+        "largePrepareUpdate",
+        "a int not null primary key auto_increment, t varchar(256)",
+        "engine=innodb");
+    try (PreparedStatement stmt =
+        sharedConnection.prepareStatement(
+            "insert into largePrepareUpdate(t) values(?)", Statement.RETURN_GENERATED_KEYS)) {
+      stmt.setString(1, "a");
+      long updateRes = stmt.executeLargeUpdate();
+      assertEquals(1L, updateRes);
+      assertEquals(1L, stmt.getUpdateCount());
+      assertEquals(1L, stmt.getLargeUpdateCount());
+
+      stmt.setString(1, "b");
+      stmt.addBatch();
+      stmt.setString(1, "c");
+      stmt.addBatch();
+      long[] batchRes = stmt.executeLargeBatch();
+      assertArrayEquals(new long[] {1, 1}, batchRes);
+      ResultSet rs = stmt.getGeneratedKeys();
+      assertTrue(rs.next());
+      assertEquals(2, rs.getInt(1));
+
+      assertEquals(0L, stmt.getLargeMaxRows());
+      stmt.setLargeMaxRows(10_000L);
+      assertEquals(10_000L, stmt.getLargeMaxRows());
+    }
+  }
 }
