@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,41 +52,22 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import com.sun.jna.*;
+import org.junit.*;
+import org.mariadb.jdbc.tls.*;
+import org.mariadb.jdbc.util.*;
 
-import com.sun.jna.Platform;
-import java.io.BufferedReader;
-import java.io.ByteArrayOutputStream;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.InputStreamReader;
-import java.io.PrintWriter;
-import java.lang.reflect.Field;
-import java.net.InetAddress;
-import java.net.UnknownHostException;
-import java.security.KeyStore;
-import java.security.KeyStoreException;
-import java.security.NoSuchAlgorithmException;
+import javax.net.ssl.*;
+import java.io.*;
+import java.lang.reflect.*;
+import java.net.*;
+import java.security.*;
 import java.security.cert.Certificate;
-import java.security.cert.CertificateException;
-import java.security.cert.CertificateFactory;
-import java.sql.Connection;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.SQLNonTransientConnectionException;
-import java.sql.Statement;
-import java.util.Collection;
-import java.util.Properties;
-import java.util.UUID;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import java.security.cert.*;
+import java.sql.*;
+import java.util.*;
+
+import static org.junit.Assert.*;
 
 @SuppressWarnings("ResultOfMethodCallIgnored")
 public class SslTest extends BaseTest {
@@ -95,11 +76,9 @@ public class SslTest extends BaseTest {
   private String clientKeystorePath;
   private String clientKeystorePassword;
 
-  /**
-   * Enable Crypto.
-   */
+  /** Enable Crypto. */
   @BeforeClass
-  public static void enableCrypto() throws Throwable {
+  public static void enableCrypto() {
     Assume.assumeFalse(
         System.getenv("MAXSCALE_VERSION") != null || "true".equals(System.getenv("AURORA")));
     try {
@@ -107,7 +86,7 @@ public class SslTest extends BaseTest {
       field.setAccessible(true);
       field.set(null, Boolean.FALSE);
     } catch (Exception ex) {
-      //eat
+      // eat
     }
   }
 
@@ -119,15 +98,16 @@ public class SslTest extends BaseTest {
   @Before
   public void checkSsl() throws SQLException {
     boolean isJava7 = System.getProperty("java.version").contains("1.7.");
-    cancelForVersion(5, 6, 36); //has SSL issues with client authentication.
+    cancelForVersion(5, 6, 36); // has SSL issues with client authentication.
     Assume.assumeTrue(haveSsl(sharedConnection));
-    //Skip SSL test on java 7 since SSL stream size JDK-6521495).
+    // Skip SSL test on java 7 since SSL stream size JDK-6521495).
     Assume.assumeFalse(isJava7);
     try {
       InetAddress.getByName("mariadb.example.com").isReachable(3);
     } catch (UnknownHostException hostException) {
-      throw new SQLException("SSL test canceled, database host must be set has "
-          + "\"mariadb.example.com\" to permit SSL certificate Host verification");
+      throw new SQLException(
+          "SSL test canceled, database host must be set has "
+              + "\"mariadb.example.com\" to permit SSL certificate Host verification");
     } catch (IOException ioe) {
       throw new SQLException("unexpected exception :" + ioe.getMessage());
     }
@@ -146,11 +126,11 @@ public class SslTest extends BaseTest {
     try {
       stmt.execute("DROP USER 'ssltestUser'@'%'");
     } catch (SQLException e) {
-      //eat
+      // eat
     }
     boolean useOldNotation = true;
-    if ((isMariadbServer() && minVersion(10, 2, 0)) || (!isMariadbServer() && minVersion(8, 0,
-        0))) {
+    if ((isMariadbServer() && minVersion(10, 2, 0))
+        || (!isMariadbServer() && minVersion(8, 0, 0))) {
       useOldNotation = false;
     }
     if (useOldNotation) {
@@ -165,7 +145,7 @@ public class SslTest extends BaseTest {
   @Test
   public void useSsl() throws Exception {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
-    //Skip SSL test on java 7 since SSL stream size JDK-6521495).
+    // Skip SSL test on java 7 since SSL stream size JDK-6521495).
     Assume.assumeFalse(System.getProperty("java.version").contains("1.7."));
     try (Connection connection = setConnection("&useSSL=true&trustServerCertificate=true")) {
       connection.createStatement().execute("select 1");
@@ -176,12 +156,10 @@ public class SslTest extends BaseTest {
     useSslForceTls(tls, null);
   }
 
-  /**
-   * Helper method when checking/enabling secure connections for a specific TLS protocol suite.
-   **/
+  /** Helper method when checking/enabling secure connections for a specific TLS protocol suite. */
   protected void useSslForceTls(String tls, String ciphers) throws Exception {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
-    //Skip SSL test on java 7 since SSL stream size JDK-6521495).
+    // Skip SSL test on java 7 since SSL stream size JDK-6521495).
     Assume.assumeFalse(System.getProperty("java.version").contains("1.7."));
     Properties info = new Properties();
     info.setProperty("useSSL", "true");
@@ -224,13 +202,17 @@ public class SslTest extends BaseTest {
       useSslForceTls("SSLv3");
       fail("Must have thrown error since protocol is refused by server");
     } catch (SQLNonTransientConnectionException e) {
-      assertTrue(e.getMessage().contains("No appropriate protocol "
-          + "(protocol is disabled or cipher suites are inappropriate)"));
+      assertTrue(
+          e.getMessage()
+              .contains(
+                  "No appropriate protocol "
+                      + "(protocol is disabled or cipher suites are inappropriate)"));
     }
   }
 
   @Test
   public void useSslForceTlsV1() throws Exception {
+    Assume.assumeFalse(isMariadbServer() && minVersion(10, 4));
     useSslForceTls("TLSv1");
   }
 
@@ -252,11 +234,35 @@ public class SslTest extends BaseTest {
   }
 
   @Test
-  public void useSslForceTlsV12AndCipher() throws Exception {
+  public void useSslForceTlsV13() throws Exception {
     Assume.assumeFalse(Platform.isWindows());
+    Assume.assumeTrue(isMariadbServer());
+
+    List<String> possibleProtocols = getSupportedProtocols();
+    if (possibleProtocols.contains("TLSv1.3")) {
+      useSslForceTls("TLSv1.3, TLSv1.2");
+    }
+  }
+
+  private List<String> getSupportedProtocols() throws Exception {
+
+    SSLSocketFactory sslSocketFactory =
+        TlsSocketPluginLoader.get(null).getSocketFactory(new Options());
+    SSLSocket socket = (SSLSocket) sslSocketFactory.createSocket();
+    List<String> enabledProtocol = Arrays.asList(socket.getEnabledProtocols());
+    socket.close();
+    return enabledProtocol;
+  }
+
+  @Test
+  public void useSslForceTlsV12AndCipher() throws Exception {
+    Assume.assumeFalse(
+        (Platform.isWindows() && !isMariadbServer())
+            || (isMariadbServer() && Platform.isWindows() && !minVersion(10, 4)));
     // Only test with MariaDB since MySQL community is compiled with yaSSL
     if (isMariadbServer()) {
-      useSslForceTls("TLSv1.2", "TLS_DHE_RSA_WITH_AES_128_GCM_SHA256");
+      useSslForceTls(
+          "TLSv1.2", "TLS_DHE_RSA_WITH_AES_256_CBC_SHA, TLS_DHE_RSA_WITH_AES_128_GCM_SHA256");
     }
   }
 
@@ -273,19 +279,21 @@ public class SslTest extends BaseTest {
     }
   }
 
-
   @Test
   public void wrongCipherForTls11() throws Exception {
     // Only test with MariaDB since MySQL community is compiled with yaSSL
     try {
       if (isMariadbServer()) {
-        useSslForceTls("TLSv1.1",
+        useSslForceTls(
+            "TLSv1.1",
             "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256, TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256");
         fail("Must have thrown error since cipher aren't TLSv1.1 ciphers");
       }
     } catch (SQLException e) {
-      assertTrue(e.getMessage().contains(
-          "No appropriate protocol (protocol is disabled or cipher suites are inappropriate)"));
+      assertTrue(
+          e.getMessage()
+              .contains(
+                  "No appropriate protocol (protocol is disabled or cipher suites are inappropriate)"));
     }
   }
 
@@ -295,13 +303,13 @@ public class SslTest extends BaseTest {
     try {
       if (isMariadbServer()) {
         Assume.assumeTrue(haveSsl(sharedConnection));
-        //Skip SSL test on java 7 since SSL stream size JDK-6521495).
+        // Skip SSL test on java 7 since SSL stream size JDK-6521495).
         Assume.assumeFalse(System.getProperty("java.version").contains("1.7."));
         Properties info = new Properties();
         info.setProperty("useSSL", "true");
         info.setProperty("trustServerCertificate", "true");
         info.setProperty("enabledSslProtocolSuites", "TLSv1.1");
-        //enabledSSLCipherSuites, not enabledSslCipherSuites (different case)
+        // enabledSSLCipherSuites, not enabledSslCipherSuites (different case)
         info.setProperty("enabledSSLCipherSuites", "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256");
 
         try (Connection connection = setConnection(info)) {
@@ -310,12 +318,13 @@ public class SslTest extends BaseTest {
         }
       }
     } catch (SQLException e) {
-      assertTrue(e.getMessage().contains(
-          "No appropriate protocol (protocol is disabled or cipher suites are inappropriate)"));
+      assertTrue(
+          e.getMessage()
+              .contains(
+                  "No appropriate protocol (protocol is disabled or cipher suites are inappropriate)"));
     }
   }
 
-
   @Test
   public void useSslForceTlsCombination() throws Exception {
     if (isMariadbServer() && !Platform.isWindows()) {
@@ -334,7 +343,6 @@ public class SslTest extends BaseTest {
     }
   }
 
-
   @Test
   public void useSslForceTlsCombinationWithOnlySpace() throws Exception {
     if (isMariadbServer() && !Platform.isWindows()) {
@@ -345,8 +353,8 @@ public class SslTest extends BaseTest {
   }
 
   private String getServerCertificate() throws SQLException {
-    try (BufferedReader br = new BufferedReader(
-        new InputStreamReader(new FileInputStream(serverCertificatePath)))) {
+    try (BufferedReader br =
+        new BufferedReader(new InputStreamReader(new FileInputStream(serverCertificatePath)))) {
       StringBuilder sb = new StringBuilder();
       String line;
       while ((line = br.readLine()) != null) {
@@ -385,7 +393,7 @@ public class SslTest extends BaseTest {
   /**
    * Test connection.
    *
-   * @param info        connection properties
+   * @param info connection properties
    * @param sslExpected is SSL expected
    * @throws SQLException exception
    */
@@ -397,10 +405,10 @@ public class SslTest extends BaseTest {
   /**
    * Test connection.
    *
-   * @param info        connection properties
+   * @param info connection properties
    * @param sslExpected is SSL expected
-   * @param user        user
-   * @param pwd         password
+   * @param user user
+   * @param pwd password
    * @throws SQLException if exception occur
    */
   public void testConnect(Properties info, boolean sslExpected, String user, String pwd)
@@ -409,9 +417,9 @@ public class SslTest extends BaseTest {
     try (Connection conn = createConnection(info, user, pwd)) {
       // First do a basic select test:
       try (Statement stmt = conn.createStatement()) {
-        try (ResultSet rs = stmt.executeQuery("SELECT 1")) {
+        try (ResultSet rs = stmt.executeQuery("SHOW STATUS like 'Ssl_version'")) {
           assertTrue(rs.next());
-          assertTrue(rs.getInt(1) == 1);
+          System.out.println(rs.getString(1) + " " + rs.getString(2));
         }
 
         // Then check if SSL matches what is expected
@@ -423,7 +431,6 @@ public class SslTest extends BaseTest {
         }
       }
     }
-
   }
 
   @Test
@@ -472,6 +479,7 @@ public class SslTest extends BaseTest {
     Assume.assumeTrue(hasSameHost());
     Properties info = new Properties();
     info.setProperty("useSSL", "true");
+    info.setProperty("log", "true");
     info.setProperty("serverSslCert", serverCertificatePath);
     testConnect(info, true);
   }
@@ -516,21 +524,70 @@ public class SslTest extends BaseTest {
 
   @Test
   public void testTruststore()
-      throws SQLException, IOException, KeyStoreException, CertificateException, NoSuchAlgorithmException {
+      throws SQLException, IOException, KeyStoreException, CertificateException,
+          NoSuchAlgorithmException {
     Assume.assumeTrue(hasSameHost());
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
     // generate a truststore from the canned serverCertificate
     File tempKeystore = File.createTempFile("keystore", ".tmp");
     String keystorePath = tempKeystore.getAbsolutePath();
+    try {
+      generateKeystoreFromFile(serverCertificatePath, keystorePath, null);
+      Properties info = new Properties();
+      info.setProperty("useSSL", "true");
+      info.setProperty("trustStoreType", "JKS");
+      info.setProperty("trustStore", "file:///" + keystorePath);
+      testConnect(info, true);
+    } finally {
+      tempKeystore.delete();
+    }
+  }
+
+  @Test
+  public void testNoSessionResumption()
+      throws SQLException, IOException, KeyStoreException, CertificateException,
+          NoSuchAlgorithmException {
+    Assume.assumeTrue(hasSameHost());
+    Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
+    // generate a truststore from the canned serverCertificate
+    File tempKeystore = File.createTempFile("keystore2", ".tmp");
+    String keystorePath = tempKeystore.getAbsolutePath();
     try {
       generateKeystoreFromFile(serverCertificatePath, keystorePath, null);
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
-      info.setProperty("trustStore", "file://" + keystorePath);
-      testConnect(info, true);
-    } catch (SQLNonTransientConnectionException nonTransient) {
-      //java 9 doesn't accept empty keystore
+      info.setProperty("trustStoreType", "JKS");
+      info.setProperty("trustStore", "file:///" + keystorePath);
+
+      Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
+
+      long sessionsReused = 0;
+      try (Connection conn = createConnection(info, "ssltestUser", "")) {
+        // First do a basic select test:
+        Statement stmt = conn.createStatement();
+
+        try (ResultSet rs = stmt.executeQuery("SHOW STATUS LIKE 'Ssl_cipher'")) {
+          assertTrue(rs.next());
+          String sslCipher = rs.getString(2);
+          boolean sslActual = sslCipher != null && sslCipher.length() > 0;
+          assertEquals("sslExpected does not match", true, sslActual);
+        }
+
+        try (ResultSet rs = stmt.executeQuery("SHOW STATUS LIKE 'Ssl_sessions_reused'")) {
+          assertTrue(rs.next());
+          sessionsReused = rs.getLong(2);
+        }
+
+        try (Connection conn2 = createConnection(info, "ssltestUser", "")) {
+          Statement stmt2 = conn2.createStatement();
+
+          try (ResultSet rs = stmt2.executeQuery("SHOW STATUS LIKE 'Ssl_sessions_reused'")) {
+            assertTrue(rs.next());
+            assertEquals(sessionsReused, rs.getLong(2));
+          }
+        }
+      }
     } finally {
       tempKeystore.delete();
     }
@@ -538,7 +595,8 @@ public class SslTest extends BaseTest {
 
   @Test
   public void testTrustStoreWithPassword()
-      throws IOException, KeyStoreException, CertificateException, NoSuchAlgorithmException, SQLException {
+      throws IOException, KeyStoreException, CertificateException, NoSuchAlgorithmException,
+          SQLException {
     Assume.assumeTrue(hasSameHost());
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
     // generate a truststore from the canned serverCertificate
@@ -550,6 +608,7 @@ public class SslTest extends BaseTest {
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
       info.setProperty("trustStore", keystorePath);
+      info.setProperty("trustStoreType", "JKS");
       info.setProperty("trustStorePassword", "mysecret");
       testConnect(info, true);
     } finally {
@@ -576,6 +635,7 @@ public class SslTest extends BaseTest {
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
+      info.setProperty("trustStoreType", "JKS");
       testConnect(info, true);
     } finally {
       if (initialTrustStore == null) {
@@ -595,7 +655,7 @@ public class SslTest extends BaseTest {
   @Test(expected = SQLException.class)
   public void testTruststoreWithWrongPassword()
       throws IOException, KeyStoreException, CertificateException, NoSuchAlgorithmException,
-      SQLException {
+          SQLException {
     Assume.assumeTrue(hasSameHost());
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
     // generate a truststore from the canned serverCertificate
@@ -606,7 +666,8 @@ public class SslTest extends BaseTest {
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
-      info.setProperty("trustStore", "file://" + keystorePath);
+      info.setProperty("trustStore", "file:///" + keystorePath);
+      info.setProperty("trustStoreType", "JKS");
       info.setProperty("trustStorePassword", "notthepassword");
       testConnect(info, true);
     } finally {
@@ -616,7 +677,8 @@ public class SslTest extends BaseTest {
 
   @Test(expected = SQLException.class)
   public void testTruststoreWithWrongCert()
-      throws IOException, KeyStoreException, CertificateException, NoSuchAlgorithmException, SQLException {
+      throws IOException, KeyStoreException, CertificateException, NoSuchAlgorithmException,
+          SQLException {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
     // generate a truststore from the canned serverCertificate
     File tempKeystore = File.createTempFile("keystore", ".tmp");
@@ -626,7 +688,8 @@ public class SslTest extends BaseTest {
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
-      info.setProperty("trustStore", "file://" + keystorePath);
+      info.setProperty("trustStoreType", "JKS");
+      info.setProperty("trustStore", "file:///" + keystorePath);
       info.setProperty("trustStorePassword", "mysecret");
       testConnect(info, true);
     } finally {
@@ -637,11 +700,13 @@ public class SslTest extends BaseTest {
   @Test
   public void testTruststoreAndClientKeystore()
       throws SQLException, IOException, KeyStoreException, CertificateException,
-      NoSuchAlgorithmException {
+          NoSuchAlgorithmException {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
-    // This test only runs if a client keystore and password have been passed in as properties (-DkeystorePath and -DkeystorePassword)
+    // This test only runs if a client keystore and password have been passed in as properties
+    // (-DkeystorePath and -DkeystorePassword)
     // You can create a keystore as follows:
-    // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}" -out "${clientKeystoreFile}"
+    // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}" -out
+    // "${clientKeystoreFile}"
     //   -name "mysqlAlias" -pass stdin
     Assume.assumeTrue(clientKeystorePathDefined());
 
@@ -657,27 +722,28 @@ public class SslTest extends BaseTest {
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
-      info.setProperty("trustStore", "file://" + truststorePath);
-      info.setProperty("keyStore", "file://" + clientKeystorePath);
+      info.setProperty("trustStore", "file:///" + truststorePath);
+      info.setProperty("trustStoreType", "JKS");
+      info.setProperty("keyStoreType", "JKS");
+      info.setProperty("keyStore", "file:///" + clientKeystorePath);
       info.setProperty("keyStorePassword", clientKeystorePassword);
       testConnect(info, true, testUser, "ssltestpassword");
-    } catch (SQLNonTransientConnectionException nonTransient) {
-      //java 9 doesn't accept empty keystore
     } finally {
       tempTruststore.delete();
       deleteSslTestUser(testUser);
     }
   }
 
-
   @Test
   public void testAliases()
       throws SQLException, IOException, KeyStoreException, CertificateException,
-      NoSuchAlgorithmException {
+          NoSuchAlgorithmException {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
-    // This test only runs if a client keystore and password have been passed in as properties (-DkeystorePath and -DkeystorePassword)
+    // This test only runs if a client keystore and password have been passed in as properties
+    // (-DkeystorePath and -DkeystorePassword)
     // You can create a keystore as follows:
-    // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}" -out "${clientKeystoreFile}"
+    // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}" -out
+    // "${clientKeystoreFile}"
     //   -name "mysqlAlias" -pass stdin
     Assume.assumeTrue(clientKeystorePathDefined());
 
@@ -693,10 +759,12 @@ public class SslTest extends BaseTest {
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
-      info.setProperty("trustCertificateKeyStoreUrl", "file://" + truststorePath);
+      info.setProperty("trustCertificateKeyStoreUrl", "file:///" + truststorePath);
       info.setProperty("trustCertificateKeyStorePassword", "trustPwd");
-      info.setProperty("clientCertificateKeyStoreUrl", "file://" + clientKeystorePath);
+      info.setProperty("trustCertificateKeyStoreType", "JKS");
+      info.setProperty("clientCertificateKeyStoreUrl", "file:///" + clientKeystorePath);
       info.setProperty("clientCertificateKeyStorePassword", clientKeystorePassword);
+      info.setProperty("clientCertificateKeyStoreType", "JKS");
       testConnect(info, true, testUser, "ssltestpassword");
     } finally {
       tempTruststore.delete();
@@ -704,13 +772,14 @@ public class SslTest extends BaseTest {
     }
   }
 
-
   @Test
   public void testClientKeystore() throws SQLException {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
-    // This test only runs if a client keystore and password have been passed in as properties (-DkeystorePath and -DkeystorePassword)
+    // This test only runs if a client keystore and password have been passed in as properties
+    // (-DkeystorePath and -DkeystorePassword)
     // You can create a keystore as follows:
-    // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}" -out "${clientKeystoreFile}"
+    // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}" -out
+    // "${clientKeystoreFile}"
     //   -name "mysqlAlias" -pass stdin
     Assume.assumeTrue(clientKeystorePathDefined());
 
@@ -722,7 +791,7 @@ public class SslTest extends BaseTest {
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
       info.setProperty("serverSslCert", serverCertificatePath);
-      info.setProperty("keyStore", "file://" + clientKeystorePath);
+      info.setProperty("keyStore", "file:///" + clientKeystorePath);
       info.setProperty("keyStorePassword", clientKeystorePassword);
       testConnect(info, true, testUser, "ssltestpassword");
     } finally {
@@ -741,19 +810,20 @@ public class SslTest extends BaseTest {
     String clientKeyStore2Path = System.getProperty("keystore2Path");
     String clientKeyStore2Password = System.getProperty("keystore2Password");
     String clientKeyPassword = System.getProperty("keyPassword");
-    Assume.assumeTrue(clientKeyPassword != null
-        && clientKeyStore2Password != null
-        && clientKeyStore2Path != null);
+    Assume.assumeTrue(
+        clientKeyPassword != null
+            && clientKeyStore2Password != null
+            && clientKeyStore2Path != null);
     String testUser = "testKeystore";
     // For this testcase, the testUser must be configured with ssl_type=X509
     createSslTestUser(testUser);
 
-    //without keyPassword
+    // without keyPassword
     try {
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
       info.setProperty("serverSslCert", serverCertificatePath);
-      info.setProperty("keyStore", "file://" + clientKeyStore2Path);
+      info.setProperty("keyStore", "file:///" + clientKeyStore2Path);
       info.setProperty("keyStorePassword", clientKeyStore2Password);
       testConnect(info, true, testUser, "ssltestpassword");
 
@@ -768,7 +838,7 @@ public class SslTest extends BaseTest {
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
       info.setProperty("serverSslCert", serverCertificatePath);
-      info.setProperty("keyStore", "file://" + clientKeyStore2Path);
+      info.setProperty("keyStore", "file:///" + clientKeyStore2Path);
       info.setProperty("keyStorePassword", clientKeyStore2Password);
       info.setProperty("keyPassword", clientKeyPassword);
       testConnect(info, true, testUser, "ssltestpassword");
@@ -796,7 +866,7 @@ public class SslTest extends BaseTest {
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
       info.setProperty("serverSslCert", serverCertificatePath);
-      info.setProperty("keyStore", "file://" + clientKeyStore2Path);
+      info.setProperty("keyStore", "file:///" + clientKeyStore2Path);
       info.setProperty("keyStorePassword", clientKeyStore2Password);
       testConnect(info, true, testUser, "ssltestpassword");
     } finally {
@@ -804,7 +874,6 @@ public class SslTest extends BaseTest {
     }
   }
 
-
   @Test
   public void testKeyStoreWithProperties() throws Exception {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
@@ -832,6 +901,8 @@ public class SslTest extends BaseTest {
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
+      info.setProperty("trustStoreType", "JKS");
+      info.setProperty("keyStoreType", "JKS");
       testConnect(info, true, testUser, "ssltestpassword");
     } finally {
       if (initialTrustStore == null) {
@@ -886,6 +957,8 @@ public class SslTest extends BaseTest {
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
       info.setProperty("trustServerCertificate", "true");
+      info.setProperty("keyStoreType", "JKS");
+      info.setProperty("trustStoreType", "JKS");
 
       testConnect(info, true, testUser, "ssltestpassword");
     } finally {
@@ -909,14 +982,16 @@ public class SslTest extends BaseTest {
     }
   }
 
-
   @Test
   public void testClientKeyStoreProperties()
-      throws SQLException, IOException, KeyStoreException, CertificateException, NoSuchAlgorithmException {
+      throws SQLException, IOException, KeyStoreException, CertificateException,
+          NoSuchAlgorithmException {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
-    // This test only runs if a client keystore and password have been passed in as properties (-DkeystorePath and -DkeystorePassword)
+    // This test only runs if a client keystore and password have been passed in as properties
+    // (-DkeystorePath and -DkeystorePassword)
     // You can create a keystore as follows:
-    // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}" -out "${clientKeystoreFile}"
+    // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}" -out
+    // "${clientKeystoreFile}"
     //   -name "mysqlAlias" -pass stdin
     Assume.assumeTrue(clientKeystorePathDefined());
 
@@ -936,8 +1011,10 @@ public class SslTest extends BaseTest {
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
-      info.setProperty("keyStore", "file://" + clientKeystorePath);
+      info.setProperty("keyStore", "file:///" + clientKeystorePath);
       info.setProperty("keyStorePassword", clientKeystorePassword);
+      info.setProperty("trustStoreType", "JKS");
+      info.setProperty("keyStoreType", "JKS");
 
       testConnect(info, true, testUser, "ssltestpassword");
     } finally {
@@ -959,9 +1036,10 @@ public class SslTest extends BaseTest {
   @Test(expected = SQLException.class)
   public void testTruststoreAndClientKeystoreWrongPassword()
       throws SQLException, IOException, KeyStoreException, CertificateException,
-      NoSuchAlgorithmException {
+          NoSuchAlgorithmException {
     Assume.assumeTrue(haveSsl(sharedConnection) && isMariadbServer());
-    // This test only runs if a client keystore and password have been passed in as properties (-DkeystorePath and -DkeystorePassword)
+    // This test only runs if a client keystore and password have been passed in as properties
+    // (-DkeystorePath and -DkeystorePassword)
     // You can create a keystore as follows:
     // echo "kspass" | openssl pkcs12 -export -in "${clientCertFile}" -inkey "${clientKeyFile}"
     // -out "${clientKeystoreFile}" -name "mysqlAlias" -pass stdin
@@ -979,8 +1057,10 @@ public class SslTest extends BaseTest {
 
       Properties info = new Properties();
       info.setProperty("useSSL", "true");
-      info.setProperty("trustStore", "file://" + truststorePath);
-      info.setProperty("keyStore", "file://" + clientKeystorePath);
+      info.setProperty("trustStoreType", "JKS");
+      info.setProperty("keyStoreType", "JKS");
+      info.setProperty("trustStore", "file:///" + truststorePath);
+      info.setProperty("keyStore", "file:///" + clientKeystorePath);
       info.setProperty("keyStorePassword", "notthekeystorepass");
       testConnect(info, true, testUser, "ssltestpassword");
     } finally {
@@ -990,14 +1070,16 @@ public class SslTest extends BaseTest {
   }
 
   private boolean clientKeystorePathDefined() {
-    return clientKeystorePath != null && !clientKeystorePath.isEmpty()
-        && clientKeystorePassword != null && !clientKeystorePassword.isEmpty();
+    return clientKeystorePath != null
+        && !clientKeystorePath.isEmpty()
+        && clientKeystorePassword != null
+        && !clientKeystorePassword.isEmpty();
   }
 
   private void createSslTestUser(String user) throws SQLException {
     boolean useOldNotation = true;
-    if ((isMariadbServer() && minVersion(10, 2, 0)) || (!isMariadbServer() && minVersion(8, 0,
-        0))) {
+    if ((isMariadbServer() && minVersion(10, 2, 0))
+        || (!isMariadbServer() && minVersion(8, 0, 0))) {
       useOldNotation = false;
     }
 
@@ -1005,13 +1087,15 @@ public class SslTest extends BaseTest {
     try {
       st.execute("DROP USER '" + user + "'@'%'");
     } catch (SQLException e) {
-      //eat
+      // eat
     }
     st.execute("FLUSH PRIVILEGES");
     if (useOldNotation) {
       st.execute("CREATE USER '" + user + "'@'%'");
-      st.execute("grant all privileges on *.* to '" + user
-          + "'@'%' identified by 'ssltestpassword' REQUIRE X509");
+      st.execute(
+          "grant all privileges on *.* to '"
+              + user
+              + "'@'%' identified by 'ssltestpassword' REQUIRE X509");
     } else {
       st.execute("CREATE USER '" + user + "'@'%' identified by 'ssltestpassword' REQUIRE X509");
       st.execute("grant all privileges on *.* to '" + user + "'@'%'");
@@ -1023,12 +1107,11 @@ public class SslTest extends BaseTest {
     st.execute("drop user '" + user + "'@'%'");
   }
 
-  private void generateKeystoreFromFile(String certificateFile, String keystoreFile,
-      String password)
-      throws KeyStoreException, CertificateException,
-      IOException, NoSuchAlgorithmException {
+  private void generateKeystoreFromFile(
+      String certificateFile, String keystoreFile, String password)
+      throws KeyStoreException, CertificateException, IOException, NoSuchAlgorithmException {
     InputStream inStream;
-    final KeyStore ks = KeyStore.getInstance(KeyStore.getDefaultType());
+    final KeyStore ks = KeyStore.getInstance("JKS");
 
     // generate a keystore from the provided cert
     if (certificateFile.startsWith("classpath:")) {
@@ -1062,5 +1145,4 @@ public class SslTest extends BaseTest {
       }
     }
   }
-
 }
