@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,30 +52,15 @@
 
 package org.mariadb.jdbc;
 
-import static org.hamcrest.CoreMatchers.equalTo;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.io.ByteArrayInputStream;
-import java.nio.charset.StandardCharsets;
-import java.sql.Connection;
-import java.sql.DriverManager;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.SQLFeatureNotSupportedException;
-import java.sql.SQLWarning;
-import java.sql.Statement;
-import java.sql.Timestamp;
-import java.util.Properties;
-import org.junit.Assume;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import java.io.*;
+import java.nio.charset.*;
+import java.sql.*;
+import java.util.*;
+
+import static org.hamcrest.CoreMatchers.*;
+import static org.junit.Assert.*;
 
 public class StatementTest extends BaseTest {
 
@@ -97,7 +82,6 @@ public class StatementTest extends BaseTest {
   private static final String ER_LOAD_DATA_INVALID_COLUMN_STATE = "HY000";
   private static final String ER_ADD_PARTITION_NO_NEW_PARTITION_STATE = "HY000";
 
-
   /**
    * Initializing tables.
    *
@@ -109,11 +93,8 @@ public class StatementTest extends BaseTest {
     createTable("vendor_code_test2", "a INT", "PARTITION BY KEY (a) (PARTITION x0, PARTITION x1)");
     createTable("vendor_code_test3", "a INT", "PARTITION BY LIST(a) (PARTITION p0 VALUES IN (1))");
     createTable("StatementTestt1", "c1 INT, c2 VARCHAR(255)");
-
-
   }
 
-
   @Test
   public void wrapperTest() throws SQLException {
     try (Statement statement = sharedConnection.createStatement()) {
@@ -124,7 +105,7 @@ public class StatementTest extends BaseTest {
         statement.unwrap(SQLException.class);
         fail("MariaDbStatement class unwrapped as SQLException class");
       } catch (SQLException sqle) {
-        //normal exception
+        // normal exception
       } catch (Exception e) {
         fail();
       }
@@ -163,8 +144,10 @@ public class StatementTest extends BaseTest {
   public void testColumnsDoNotExist() {
 
     try {
-      sharedConnection.createStatement().executeQuery(
-          "select * from vendor_code_test where crazy_column_that_does_not_exist = 1");
+      sharedConnection
+          .createStatement()
+          .executeQuery(
+              "select * from vendor_code_test where crazy_column_that_does_not_exist = 1");
       fail("The above statement should result in an exception");
     } catch (SQLException sqlException) {
       assertEquals(ER_BAD_FIELD_ERROR, sqlException.getErrorCode());
@@ -224,12 +207,13 @@ public class StatementTest extends BaseTest {
   @Test
   public void testNonUpdateableColumn() throws SQLException {
     Statement statement = sharedConnection.createStatement();
-    statement.execute("create or replace view vendor_code_test_view as select *,"
-        + " 1 as derived_column_that_does_no_exist from vendor_code_test");
+    statement.execute(
+        "create or replace view vendor_code_test_view as select *,"
+            + " 1 as derived_column_that_does_no_exist from vendor_code_test");
 
     try {
-      statement
-          .executeQuery("UPDATE vendor_code_test_view SET derived_column_that_does_no_exist = 1");
+      statement.executeQuery(
+          "UPDATE vendor_code_test_view SET derived_column_that_does_no_exist = 1");
       fail("The above statement should result in an exception");
     } catch (SQLException sqlException) {
       assertEquals(ER_NONUPDATEABLE_COLUMN, sqlException.getErrorCode());
@@ -277,14 +261,13 @@ public class StatementTest extends BaseTest {
   @Test
   public void testLoadDataInvalidColumn() throws SQLException {
     Assume.assumeFalse(
-            (isMariadbServer() && minVersion(10, 4, 0))
-                    || (!isMariadbServer() && minVersion(8, 0, 3)));
+        (isMariadbServer() && minVersion(10, 4, 0)) || (!isMariadbServer() && minVersion(8, 0, 3)));
     try (Connection connection = setConnection("&allowLocalInfile=true")) {
       Statement statement = connection.createStatement();
       try {
         statement.execute("drop view if exists v2");
       } catch (SQLException e) {
-        //if view doesn't exist, and mode throw warning as error
+        // if view doesn't exist, and mode throw warning as error
       }
       statement.execute("CREATE VIEW v2 AS SELECT 1 + 2 AS c0, c1, c2 FROM StatementTestt1;");
       try {
@@ -295,12 +278,12 @@ public class StatementTest extends BaseTest {
           throw new SQLException("Mariadb JDBC adaptor must be used");
         }
         try {
-          String data = "\"1\", \"string1\"\n"
-                  + "\"2\", \"string2\"\n"
-                  + "\"3\", \"string3\"\n";
-          ByteArrayInputStream loadDataInfileFile = new ByteArrayInputStream(data.getBytes(StandardCharsets.UTF_8));
+          String data = "\"1\", \"string1\"\n" + "\"2\", \"string2\"\n" + "\"3\", \"string3\"\n";
+          ByteArrayInputStream loadDataInfileFile =
+              new ByteArrayInputStream(data.getBytes(StandardCharsets.UTF_8));
           mysqlStatement.setLocalInfileInputStream(loadDataInfileFile);
-          mysqlStatement.executeUpdate("LOAD DATA LOCAL INFILE 'dummyFileName' INTO TABLE v2 "
+          mysqlStatement.executeUpdate(
+              "LOAD DATA LOCAL INFILE 'dummyFileName' INTO TABLE v2 "
                   + "FIELDS ESCAPED BY '\\\\' "
                   + "TERMINATED BY ',' "
                   + "ENCLOSED BY '\"'"
@@ -308,22 +291,22 @@ public class StatementTest extends BaseTest {
           fail("The above statement should result in an exception");
         } catch (SQLException sqlException) {
           if (sqlException.getErrorCode() != ER_LOAD_DATA_INVALID_COLUMN
-                  && sqlException.getErrorCode() != ER_NONUPDATEABLE_COLUMN) {
+              && sqlException.getErrorCode() != ER_NONUPDATEABLE_COLUMN) {
             fail();
           }
           assertEquals(ER_LOAD_DATA_INVALID_COLUMN_STATE, sqlException.getSQLState());
 
-          //otherwise, localInfileInputStream will not be null,
+          // otherwise, localInfileInputStream will not be null,
           // which cause false logic in readLocalInfilePacket
-          // and test like LocalInfileInputStreamTest#testLocalInfileUnValidInterceptor will fail if run after it
+          // and test like LocalInfileInputStreamTest#testLocalInfileUnValidInterceptor will fail if
+          // run after it
           mysqlStatement.setLocalInfileInputStream(null);
-
         }
       } finally {
         try {
           statement.execute("drop view if exists v2");
         } catch (SQLException e) {
-          //if view doesn't exist, and mode throw warning as error
+          // if view doesn't exist, and mode throw warning as error
         }
       }
     }
@@ -375,8 +358,8 @@ public class StatementTest extends BaseTest {
 
     createTable("testFractionalTimeBatch", "tt TIMESTAMP(6)");
     Timestamp currTime = new Timestamp(System.currentTimeMillis());
-    try (PreparedStatement preparedStatement = sharedConnection.prepareStatement(
-        "INSERT INTO testFractionalTimeBatch (tt) values (?)")) {
+    try (PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement("INSERT INTO testFractionalTimeBatch (tt) values (?)")) {
       for (int i = 0; i < 2; i++) {
         preparedStatement.setTimestamp(1, currTime);
         preparedStatement.addBatch();
@@ -399,15 +382,15 @@ public class StatementTest extends BaseTest {
     createTable("testFallbackBatchUpdate", "col int");
     Statement statement = sharedConnection.createStatement();
 
-    //add 100 data
+    // add 100 data
     StringBuilder sb = new StringBuilder("INSERT INTO testFallbackBatchUpdate(col) VALUES (0)");
     for (int i = 1; i < 100; i++) {
       sb.append(",(").append(i).append(")");
     }
     statement.execute(sb.toString());
 
-    try (PreparedStatement preparedStatement = sharedConnection.prepareStatement(
-        "DELETE FROM testFallbackBatchUpdate WHERE col = ?")) {
+    try (PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement("DELETE FROM testFallbackBatchUpdate WHERE col = ?")) {
       preparedStatement.setInt(1, 10);
       preparedStatement.addBatch();
 
@@ -418,7 +401,7 @@ public class StatementTest extends BaseTest {
       assertEquals(2, results.length);
     }
 
-    //check results
+    // check results
     try (ResultSet rs = statement.executeQuery("SELECT * FROM testFallbackBatchUpdate")) {
       for (int i = 0; i < 100; i++) {
         if (i == 10 || i == 15) {
@@ -438,16 +421,17 @@ public class StatementTest extends BaseTest {
     createTable("testProperBatchUpdate", "col int, col2 int");
     Statement statement = sharedConnection.createStatement();
 
-    //add 100 data
-    StringBuilder sb = new StringBuilder(
-        "INSERT INTO testProperBatchUpdate(col, col2) VALUES (0,0)");
+    // add 100 data
+    StringBuilder sb =
+        new StringBuilder("INSERT INTO testProperBatchUpdate(col, col2) VALUES (0,0)");
     for (int i = 1; i < 100; i++) {
       sb.append(",(").append(i).append(",0)");
     }
     statement.execute(sb.toString());
 
-    try (PreparedStatement preparedStatement = sharedConnection.prepareStatement(
-        "UPDATE testProperBatchUpdate set col2 = ? WHERE col = ? ")) {
+    try (PreparedStatement preparedStatement =
+        sharedConnection.prepareStatement(
+            "UPDATE testProperBatchUpdate set col2 = ? WHERE col = ? ")) {
       preparedStatement.setInt(1, 10);
       preparedStatement.setInt(2, 10);
       preparedStatement.addBatch();
@@ -460,7 +444,7 @@ public class StatementTest extends BaseTest {
       assertEquals(2, results.length);
     }
 
-    //check results
+    // check results
     try (ResultSet rs = statement.executeQuery("SELECT * FROM testProperBatchUpdate")) {
       for (int i = 0; i < 100; i++) {
         assertTrue(rs.next());
@@ -477,28 +461,30 @@ public class StatementTest extends BaseTest {
     Statement stmt = sharedConnection.createStatement();
     stmt.execute("insert into deadlock(a) values(0), (1)");
 
-    try (Connection conn1 = setConnection(
-        "&includeInnodbStatusInDeadlockExceptions&includeThreadDumpInDeadlockExceptions")) {
+    try (Connection conn1 =
+        setConnection(
+            "&includeInnodbStatusInDeadlockExceptions&includeThreadDumpInDeadlockExceptions")) {
 
       conn1.setTransactionIsolation(Connection.TRANSACTION_SERIALIZABLE);
       Statement stmt1 = conn1.createStatement();
       try {
         stmt1.execute("SET SESSION idle_transaction_timeout=2");
       } catch (SQLException e) {
-        //eat ( for mariadb >= 10.3)
+        // eat ( for mariadb >= 10.3)
       }
       stmt.execute("start transaction");
       stmt.execute("update deadlock set a = 2 where a <> 0");
 
-      try (Connection conn2 = setConnection(
-          "&includeInnodbStatusInDeadlockExceptions&includeThreadDumpInDeadlockExceptions")) {
+      try (Connection conn2 =
+          setConnection(
+              "&includeInnodbStatusInDeadlockExceptions&includeThreadDumpInDeadlockExceptions")) {
 
         Statement stmt2 = conn2.createStatement();
         conn2.setTransactionIsolation(Connection.TRANSACTION_SERIALIZABLE);
         try {
           stmt2.execute("SET SESSION idle_transaction_timeout=2");
         } catch (SQLException e) {
-          //eat ( for mariadb >= 10.3)
+          // eat ( for mariadb >= 10.3)
         }
         stmt2.execute("start transaction");
         try {
@@ -514,28 +500,36 @@ public class StatementTest extends BaseTest {
 
   @Test
   public void largeUpdate() throws SQLException {
-    createTable("largeUpdate", "a int not null primary key auto_increment, t varchar(256)", "engine=innodb");
+    createTable(
+        "largeUpdate",
+        "a int not null primary key auto_increment, t varchar(256)",
+        "engine=innodb");
     Statement stmt = sharedConnection.createStatement();
 
     long updateRes = stmt.executeLargeUpdate("insert into largeUpdate(t) values('a'), ('b')");
     assertEquals(2L, updateRes);
     assertEquals(2L, stmt.getLargeUpdateCount());
 
-    updateRes = stmt.executeLargeUpdate("insert into largeUpdate(t) values('c'), ('d')", Statement.RETURN_GENERATED_KEYS);
+    updateRes =
+        stmt.executeLargeUpdate(
+            "insert into largeUpdate(t) values('c'), ('d')", Statement.RETURN_GENERATED_KEYS);
     assertEquals(2L, updateRes);
     ResultSet rs = stmt.getGeneratedKeys();
     assertEquals(2L, stmt.getLargeUpdateCount());
     assertTrue(rs.next());
     assertEquals(3, rs.getInt(1));
 
-    updateRes = stmt.executeLargeUpdate("insert into largeUpdate(t) values('e'), ('f')", new int[] {1});
+    updateRes =
+        stmt.executeLargeUpdate("insert into largeUpdate(t) values('e'), ('f')", new int[] {1});
     assertEquals(2L, updateRes);
     assertEquals(2L, stmt.getLargeUpdateCount());
     rs = stmt.getGeneratedKeys();
     assertTrue(rs.next());
     assertEquals(5, rs.getInt(1));
 
-    updateRes = stmt.executeLargeUpdate("insert into largeUpdate(t) values('g'), ('h')", new String[] {"1"});
+    updateRes =
+        stmt.executeLargeUpdate(
+            "insert into largeUpdate(t) values('g'), ('h')", new String[] {"1"});
     assertEquals(2L, updateRes);
     rs = stmt.getGeneratedKeys();
     assertTrue(rs.next());
@@ -544,10 +538,8 @@ public class StatementTest extends BaseTest {
     assertEquals(0L, stmt.getLargeMaxRows());
     stmt.setLargeMaxRows(10_000L);
     assertEquals(10_000L, stmt.getLargeMaxRows());
-
   }
 
-
   @Test
   public void closedStatement() throws SQLException {
 
@@ -582,16 +574,18 @@ public class StatementTest extends BaseTest {
 
   @Test
   public void largePrepareUpdate() throws SQLException {
-    createTable("largePrepareUpdate", "a int not null primary key auto_increment, t varchar(256)", "engine=innodb");
+    createTable(
+        "largePrepareUpdate",
+        "a int not null primary key auto_increment, t varchar(256)",
+        "engine=innodb");
     Statement stmt = sharedConnection.createStatement();
     stmt.addBatch("insert into largePrepareUpdate(t) values('a')");
     stmt.addBatch("insert into largePrepareUpdate(t) values('b')");
     stmt.addBatch("insert into largePrepareUpdate(t) values('b')");
     long[] batchRes = stmt.executeLargeBatch();
-    assertArrayEquals(new long[] {1,1,1}, batchRes);
+    assertArrayEquals(new long[] {1, 1, 1}, batchRes);
   }
 
-
   @Test
   public void wrongParameterValues() throws SQLException {
     Statement stmt = sharedConnection.createStatement();
@@ -609,7 +603,6 @@ public class StatementTest extends BaseTest {
       e.getMessage().contains("max rows cannot be negative");
     }
 
-
     try {
       stmt.setQueryTimeout(-1);
       fail();
@@ -674,11 +667,12 @@ public class StatementTest extends BaseTest {
   public void scrollType() throws SQLException {
     Statement stmt = sharedConnection.createStatement();
     assertEquals(ResultSet.TYPE_FORWARD_ONLY, stmt.getResultSetType());
-    stmt = sharedConnection.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
+    stmt =
+        sharedConnection.createStatement(
+            ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
     assertEquals(ResultSet.TYPE_SCROLL_INSENSITIVE, stmt.getResultSetType());
   }
 
-
   @Test
   public void addBatchNull() throws SQLException {
     Statement stmt = sharedConnection.createStatement();
@@ -688,4 +682,37 @@ public class StatementTest extends BaseTest {
       assertTrue(e.getMessage().contains("null cannot be set to addBatch( String sql)"));
     }
   }
-}
\ No newline at end of file
+
+  @Test
+  public void statementIdentifier() throws SQLException {
+    MariaDbStatement stmt = (MariaDbStatement) sharedConnection.createStatement();
+    assertTrue(stmt.isSimpleIdentifier("good_$one"));
+    assertTrue(stmt.isSimpleIdentifier("anotherçone"));
+    assertFalse(stmt.isSimpleIdentifier("another'çone"));
+  }
+
+  @Test
+  public void statementEnquoteIdentifier() throws SQLException {
+    MariaDbStatement stmt = (MariaDbStatement) sharedConnection.createStatement();
+
+    assertEquals("good_$one", stmt.enquoteIdentifier("good_$one", false));
+    assertEquals("`good_$one`", stmt.enquoteIdentifier("good_$one", true));
+    assertEquals("`🌟s`", stmt.enquoteIdentifier("🌟s", false));
+    assertEquals("`good_``è``one`", stmt.enquoteIdentifier("good_`è`one", false));
+    try {
+      stmt.enquoteIdentifier("\u0000ff", true);
+      fail("must have thrown exception");
+    } catch (SQLException e) {
+      // expected
+    }
+  }
+
+  @Test
+  public void statementEnquoteString() throws SQLException {
+    MariaDbStatement stmt = (MariaDbStatement) sharedConnection.createStatement();
+
+    assertEquals("'good_$one'", stmt.enquoteLiteral("good_$one"));
+    assertEquals(
+        "'another\\Z\\'\\\"one\\n \\b test'", stmt.enquoteLiteral("another\u001A'\"one\n \b test"));
+  }
+}
