@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,23 +52,15 @@
 
 package org.mariadb.jdbc;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.SQLNonTransientConnectionException;
-import java.sql.Statement;
-import org.junit.Assume;
-import org.junit.Test;
+import java.sql.*;
+
+import static org.junit.Assert.*;
 
 public class TimeoutTest extends BaseTest {
 
-  private static int selectValue(Connection conn, int value)
-      throws SQLException {
+  private static int selectValue(Connection conn, int value) throws SQLException {
     try (Statement stmt = conn.createStatement()) {
       try (ResultSet rs = stmt.executeQuery("select " + value)) {
         if (rs.next()) {
@@ -80,12 +72,10 @@ public class TimeoutTest extends BaseTest {
     }
   }
 
-  /**
-   * Conj-79.
-   */
+  /** Conj-79. */
   @Test
   public void resultSetAfterSocketTimeoutTest() {
-    //appveyor vm are very slow, cannot compare time
+    // appveyor vm are very slow, cannot compare time
     Assume.assumeTrue(System.getenv("APPVEYOR") == null && System.getenv("DOCKER_SOCKET") == null);
 
     Assume.assumeFalse(sharedIsAurora());
@@ -105,14 +95,14 @@ public class TimeoutTest extends BaseTest {
             }
             went++;
           } catch (SQLNonTransientConnectionException e) {
-            //error due to socketTimeout
+            // error due to socketTimeout
           } catch (SQLException e) {
             e.printStackTrace();
           }
         }
         assertFalse(bugReproduced); // either Exception or fine
       } catch (SQLException e) {
-        //SQLNonTransientConnectionException error
+        // SQLNonTransientConnectionException error
       }
     }
     assertTrue(went > 0);
@@ -149,7 +139,7 @@ public class TimeoutTest extends BaseTest {
         ps.execute();
         fail("Connection must have thrown error");
       } catch (SQLException e) {
-        //normal exception
+        // normal exception
       }
 
       // the connection should  be closed
@@ -173,7 +163,7 @@ public class TimeoutTest extends BaseTest {
           statement.execute("SELECT 1");
           fail("Connection must have thrown error");
         } catch (SQLException e) {
-          //normal exception
+          // normal exception
         }
       }
     }
@@ -198,9 +188,8 @@ public class TimeoutTest extends BaseTest {
         assertTrue(rs.next());
         fail("Connection must have thrown error");
       } catch (SQLException e) {
-        //normal exception
+        // normal exception
       }
     }
   }
-
-}
\ No newline at end of file
+}
