@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,22 +52,25 @@
 
 package org.mariadb.jdbc;
 
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.SQLFeatureNotSupportedException;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.*;
 
+import java.sql.*;
 
 public class UpdateResultSetMethodsTest extends BaseTest {
 
   private ResultSet rs;
 
+  /**
+   * Initialisation.
+   *
+   * @throws SQLException exception
+   */
   @Before
   public void before() throws SQLException {
-    rs = sharedConnection.createStatement(ResultSet.TYPE_FORWARD_ONLY, ResultSet.CONCUR_UPDATABLE)
-        .executeQuery("select 1");
+    rs =
+        sharedConnection
+            .createStatement(ResultSet.TYPE_FORWARD_ONLY, ResultSet.CONCUR_UPDATABLE)
+            .executeQuery("select 1");
   }
 
   @Test
@@ -76,13 +79,13 @@ public class UpdateResultSetMethodsTest extends BaseTest {
   }
 
   @Test
-  public void testDeleteRow() throws SQLException {
+  public void testDeleteRow() {
     try {
       rs.deleteRow();
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
@@ -92,13 +95,13 @@ public class UpdateResultSetMethodsTest extends BaseTest {
   }
 
   @Test
-  public void testRefreshRow() throws SQLException {
+  public void testRefreshRow() {
     try {
       rs.refreshRow();
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
@@ -108,13 +111,13 @@ public class UpdateResultSetMethodsTest extends BaseTest {
   }
 
   @Test
-  public void testMoveToInsertRow() throws SQLException {
+  public void testMoveToInsertRow() {
     try {
       rs.moveToInsertRow();
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
@@ -124,906 +127,904 @@ public class UpdateResultSetMethodsTest extends BaseTest {
   }
 
   @Test
-  public void testupdateBinaryStream() throws SQLException {
+  public void testupdateBinaryStream() {
     try {
       rs.updateBinaryStream(1, null, 0);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBinaryStream2() throws SQLException {
+  public void testupdateBinaryStream2() {
     try {
       rs.updateBinaryStream("", null, 0);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateObject() throws SQLException {
+  public void testupdateObject() {
     try {
       rs.updateObject(1, null, 0);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateObject2() throws SQLException {
+  public void testupdateObject2() {
     try {
       rs.updateObject("", null, 0);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateCharStream() throws SQLException {
+  public void testupdateCharStream() {
     try {
       rs.updateCharacterStream(1, null, 0);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateCharStream2() throws SQLException {
+  public void testupdateCharStream2() {
     try {
       rs.updateCharacterStream("", null, 0);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateAsciiStream() throws SQLException {
+  public void testupdateAsciiStream() {
     try {
       rs.updateAsciiStream(1, null, 0);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateAsciiStream2() throws SQLException {
+  public void testupdateAsciiStream2() {
     try {
       rs.updateAsciiStream("a", null, 0);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNull0() throws SQLException {
+  public void testupdateNull0() {
     try {
       rs.updateNull(1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNull1() throws SQLException {
+  public void testupdateNull1() {
     try {
       rs.updateNull("a");
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBoolean2() throws SQLException {
+  public void testupdateBoolean2() {
     try {
       rs.updateBoolean(1, false);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBoolean3() throws SQLException {
+  public void testupdateBoolean3() {
     try {
       rs.updateBoolean("a", false);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateByte4() throws SQLException {
+  public void testupdateByte4() {
     try {
       rs.updateByte(1, (byte) 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateByte5() throws SQLException {
+  public void testupdateByte5() {
     try {
       rs.updateByte("a", (byte) 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateShort6() throws SQLException {
+  public void testupdateShort6() {
     try {
       rs.updateShort(1, (short) 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateShort7() throws SQLException {
+  public void testupdateShort7() {
     try {
       rs.updateShort("a", (short) 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateInt8() throws SQLException {
+  public void testupdateInt8() {
     try {
       rs.updateInt(1, 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateInt9() throws SQLException {
+  public void testupdateInt9() {
     try {
       rs.updateInt("a", 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateLong10() throws SQLException {
+  public void testupdateLong10() {
     try {
-      rs.updateLong(1, (long) 1);
+      rs.updateLong(1, 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateLong11() throws SQLException {
+  public void testupdateLong11() {
     try {
-      rs.updateLong("a", (long) 1);
+      rs.updateLong("a", 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateFloat12() throws SQLException {
+  public void testupdateFloat12() {
     try {
       rs.updateFloat(1, (float) 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateFloat13() throws SQLException {
+  public void testupdateFloat13() {
     try {
       rs.updateFloat("a", (float) 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateDouble14() throws SQLException {
+  public void testupdateDouble14() {
     try {
-      rs.updateDouble(1, (double) 1);
+      rs.updateDouble(1, 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateDouble15() throws SQLException {
+  public void testupdateDouble15() {
     try {
-      rs.updateDouble("a", (double) 1);
+      rs.updateDouble("a", 1);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBigDecimal16() throws SQLException {
+  public void testupdateBigDecimal16() {
     try {
       rs.updateBigDecimal(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBigDecimal17() throws SQLException {
+  public void testupdateBigDecimal17() {
     try {
       rs.updateBigDecimal("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateString18() throws SQLException {
+  public void testupdateString18() {
     try {
       rs.updateString(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateString19() throws SQLException {
+  public void testupdateString19() {
     try {
       rs.updateString("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBytes20() throws SQLException {
+  public void testupdateBytes20() {
     try {
       rs.updateBytes(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBytes21() throws SQLException {
+  public void testupdateBytes21() {
     try {
       rs.updateBytes("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateDate22() throws SQLException {
+  public void testupdateDate22() {
     try {
       rs.updateDate(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateDate23() throws SQLException {
+  public void testupdateDate23() {
     try {
       rs.updateDate("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateTime24() throws SQLException {
+  public void testupdateTime24() {
     try {
       rs.updateTime(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateTime25() throws SQLException {
+  public void testupdateTime25() {
     try {
       rs.updateTime("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateTimestamp26() throws SQLException {
+  public void testupdateTimestamp26() {
     try {
       rs.updateTimestamp(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateTimestamp27() throws SQLException {
+  public void testupdateTimestamp27() {
     try {
       rs.updateTimestamp("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateAsciiStream28() throws SQLException {
+  public void testupdateAsciiStream28() {
     try {
       rs.updateAsciiStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateAsciiStream29() throws SQLException {
+  public void testupdateAsciiStream29() {
     try {
       rs.updateAsciiStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateAsciiStream30() throws SQLException {
+  public void testupdateAsciiStream30() {
     try {
       rs.updateAsciiStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateAsciiStream31() throws SQLException {
+  public void testupdateAsciiStream31() {
     try {
       rs.updateAsciiStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateAsciiStream32() throws SQLException {
+  public void testupdateAsciiStream32() {
     try {
       rs.updateAsciiStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateAsciiStream33() throws SQLException {
+  public void testupdateAsciiStream33() {
     try {
       rs.updateAsciiStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBinaryStream34() throws SQLException {
+  public void testupdateBinaryStream34() {
     try {
       rs.updateBinaryStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBinaryStream35() throws SQLException {
+  public void testupdateBinaryStream35() {
     try {
       rs.updateBinaryStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBinaryStream36() throws SQLException {
+  public void testupdateBinaryStream36() {
     try {
       rs.updateBinaryStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBinaryStream37() throws SQLException {
+  public void testupdateBinaryStream37() {
     try {
       rs.updateBinaryStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBinaryStream38() throws SQLException {
+  public void testupdateBinaryStream38() {
     try {
       rs.updateBinaryStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBinaryStream39() throws SQLException {
+  public void testupdateBinaryStream39() {
     try {
       rs.updateBinaryStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateCharacterStream40() throws SQLException {
+  public void testupdateCharacterStream40() {
     try {
       rs.updateCharacterStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateCharacterStream41() throws SQLException {
+  public void testupdateCharacterStream41() {
     try {
       rs.updateCharacterStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateCharacterStream42() throws SQLException {
+  public void testupdateCharacterStream42() {
     try {
       rs.updateCharacterStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateCharacterStream43() throws SQLException {
+  public void testupdateCharacterStream43() {
     try {
       rs.updateCharacterStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateCharacterStream44() throws SQLException {
+  public void testupdateCharacterStream44() {
     try {
       rs.updateCharacterStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateCharacterStream45() throws SQLException {
+  public void testupdateCharacterStream45() {
     try {
       rs.updateCharacterStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateObject46() throws SQLException {
+  public void testupdateObject46() {
     try {
       rs.updateObject(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateObject47() throws SQLException {
+  public void testupdateObject47() {
     try {
       rs.updateObject(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateObject48() throws SQLException {
+  public void testupdateObject48() {
     try {
       rs.updateObject("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateObject49() throws SQLException {
+  public void testupdateObject49() {
     try {
       rs.updateObject("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBlob52() throws SQLException {
+  public void testupdateBlob52() {
     try {
       rs.updateBlob(1, (java.sql.Blob) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBlob53() throws SQLException {
+  public void testupdateBlob53() {
     try {
       rs.updateBlob("a", (java.sql.Blob) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBlob54() throws SQLException {
+  public void testupdateBlob54() {
     try {
       rs.updateBlob(1, (java.io.InputStream) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBlob55() throws SQLException {
+  public void testupdateBlob55() {
     try {
       rs.updateBlob("a", (java.io.InputStream) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBlob56() throws SQLException {
+  public void testupdateBlob56() {
     try {
       rs.updateBlob(1, (java.io.InputStream) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateBlob57() throws SQLException {
+  public void testupdateBlob57() {
     try {
       rs.updateBlob("a", (java.io.InputStream) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateClob58() throws SQLException {
+  public void testupdateClob58() {
     try {
       rs.updateClob(1, (java.sql.Clob) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateClob59() throws SQLException {
+  public void testupdateClob59() {
     try {
       rs.updateClob("a", (java.sql.Clob) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateClob60() throws SQLException {
+  public void testupdateClob60() {
     try {
       rs.updateClob(1, (java.io.Reader) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateClob61() throws SQLException {
+  public void testupdateClob61() {
     try {
       rs.updateClob("a", (java.io.Reader) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateClob62() throws SQLException {
+  public void testupdateClob62() {
     try {
       rs.updateClob(1, (java.io.Reader) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateClob63() throws SQLException {
+  public void testupdateClob63() {
     try {
       rs.updateClob("a", (java.io.Reader) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNString68() throws SQLException {
+  public void testupdateNString68() {
     try {
       rs.updateNString(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNString69() throws SQLException {
+  public void testupdateNString69() {
     try {
       rs.updateNString("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNClob70() throws SQLException {
+  public void testupdateNClob70() {
     try {
       rs.updateNClob(1, (java.sql.NClob) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNClob71() throws SQLException {
+  public void testupdateNClob71() {
     try {
       rs.updateNClob("a", (java.sql.NClob) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNClob72() throws SQLException {
+  public void testupdateNClob72() {
     try {
       rs.updateNClob(1, (java.io.Reader) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNClob73() throws SQLException {
+  public void testupdateNClob73() {
     try {
       rs.updateNClob("a", (java.io.Reader) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNClob74() throws SQLException {
+  public void testupdateNClob74() {
     try {
       rs.updateNClob(1, (java.io.Reader) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNClob75() throws SQLException {
+  public void testupdateNClob75() {
     try {
       rs.updateNClob("a", (java.io.Reader) null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNCharacterStream78() throws SQLException {
+  public void testupdateNCharacterStream78() {
     try {
       rs.updateNCharacterStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNCharacterStream79() throws SQLException {
+  public void testupdateNCharacterStream79() {
     try {
       rs.updateNCharacterStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNCharacterStream80() throws SQLException {
+  public void testupdateNCharacterStream80() {
     try {
       rs.updateNCharacterStream(1, null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
 
   @Test
-  public void testupdateNCharacterStream81() throws SQLException {
+  public void testupdateNCharacterStream81() {
     try {
       rs.updateNCharacterStream("a", null);
     } catch (SQLFeatureNotSupportedException sqle) {
       Assert.fail();
     } catch (SQLException sqlee) {
-      //eat
+      // eat
     }
   }
-
-
 }
