@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,25 +52,14 @@
 
 package org.mariadb.jdbc.failover;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.*;
+import org.mariadb.jdbc.internal.protocol.*;
+import org.mariadb.jdbc.internal.util.constant.*;
 
-import java.sql.Connection;
-import java.sql.DriverManager;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.util.concurrent.TimeUnit;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.mariadb.jdbc.internal.protocol.Protocol;
-import org.mariadb.jdbc.internal.util.constant.HaMode;
+import java.sql.*;
+import java.util.concurrent.*;
+
+import static org.junit.Assert.*;
 
 /**
  * Aurora test suite. Some environment parameter must be set : - defaultAuroraUrl : example
@@ -78,23 +67,18 @@ import org.mariadb.jdbc.internal.util.constant.HaMode;
  * - AURORA_ACCESS_KEY = access key - AURORA_SECRET_KEY = secret key - AURORA_CLUSTER_IDENTIFIER =
  * cluster identifier. example : -DAURORA_CLUSTER_IDENTIFIER=instance-1-cluster
  *
- * <p>"AURORA" environment variable must be set to a value</p>
- *
+ * <p>"AURORA" environment variable must be set to a value
  */
 public class AuroraFailoverTest extends BaseReplication {
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @BeforeClass()
   public static void beforeClass2() {
     proxyUrl = proxyAuroraUrl;
     Assume.assumeTrue(initialAuroraUrl != null);
   }
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @Before
   public void init() {
     defaultUrl = initialAuroraUrl;
@@ -106,8 +90,10 @@ public class AuroraFailoverTest extends BaseReplication {
     try (Connection connection = getNewConnection(false)) {
       Statement stmt = connection.createStatement();
       stmt.execute("drop table  if exists auroraDelete" + jobId);
-      stmt.execute("create table auroraDelete" + jobId
-          + " (id int not null primary key auto_increment, test VARCHAR(10))");
+      stmt.execute(
+          "create table auroraDelete"
+              + jobId
+              + " (id int not null primary key auto_increment, test VARCHAR(10))");
       connection.setReadOnly(true);
       assertTrue(connection.isReadOnly());
       try {
@@ -116,7 +102,7 @@ public class AuroraFailoverTest extends BaseReplication {
             "ERROR - > must not be able to write on slave. check if you database is start with --read-only");
         fail();
       } catch (SQLException e) {
-        //normal exception
+        // normal exception
         connection.setReadOnly(false);
         stmt.execute("drop table if exists auroraDelete" + jobId);
       }
@@ -128,10 +114,12 @@ public class AuroraFailoverTest extends BaseReplication {
     try (Connection connection = getNewConnection(false)) {
       Statement stmt = connection.createStatement();
       stmt.execute("drop table  if exists auroraReadSlave" + jobId);
-      stmt.execute("create table auroraReadSlave" + jobId
-          + " (id int not null primary key auto_increment, test VARCHAR(10))");
+      stmt.execute(
+          "create table auroraReadSlave"
+              + jobId
+              + " (id int not null primary key auto_increment, test VARCHAR(10))");
 
-      //wait to be sure slave have replicate data
+      // wait to be sure slave have replicate data
       Thread.sleep(1500);
 
       connection.setReadOnly(true);
@@ -142,12 +130,10 @@ public class AuroraFailoverTest extends BaseReplication {
     }
   }
 
-
   @Test
   public void testReadOnly() throws SQLException {
     try (Connection connection = getNewConnection(false)) {
-      ResultSet rs = connection.createStatement()
-          .executeQuery("select @@innodb_read_only");
+      ResultSet rs = connection.createStatement().executeQuery("select @@innodb_read_only");
 
       assertTrue(rs.next());
       assertEquals(0, rs.getInt(1));
@@ -155,8 +141,7 @@ public class AuroraFailoverTest extends BaseReplication {
 
       connection.setReadOnly(true);
 
-      rs = connection.createStatement()
-          .executeQuery("select @@innodb_read_only");
+      rs = connection.createStatement().executeQuery("select @@innodb_read_only");
 
       assertTrue(rs.next());
       assertNotEquals(0, rs.getInt(1));
@@ -179,7 +164,7 @@ public class AuroraFailoverTest extends BaseReplication {
           fail();
         }
       } catch (SQLException e) {
-        //normal error
+        // normal error
       }
       assertFalse(connection.isReadOnly());
       long duration = TimeUnit.NANOSECONDS.toMillis(System.nanoTime() - stopTime);
@@ -230,10 +215,7 @@ public class AuroraFailoverTest extends BaseReplication {
     }
   }
 
-  /**
-   * Conj-166 Connection error code must be thrown.
-   *
-   */
+  /** Conj-166 Connection error code must be thrown. */
   @Test
   public void testAccessDeniedErrorCode() {
     try {
@@ -256,7 +238,7 @@ public class AuroraFailoverTest extends BaseReplication {
       Statement st = connection.createStatement();
       try {
         st.execute("SELECT 1 ");
-        //switch connection to master -> slave blacklisted
+        // switch connection to master -> slave blacklisted
       } catch (SQLException e) {
         fail("must not have been here");
       }
@@ -276,13 +258,13 @@ public class AuroraFailoverTest extends BaseReplication {
       connection.setReadOnly(true);
       int current = getServerId(connection);
       protocol = getProtocolFromConnection(connection);
-      assertTrue("Blacklist would normally be zero, but was " + protocol.getProxy().getListener()
-              .getBlacklistKeys().size(),
+      assertTrue(
+          "Blacklist would normally be zero, but was "
+              + protocol.getProxy().getListener().getBlacklistKeys().size(),
           protocol.getProxy().getListener().getBlacklistKeys().size() == 0);
       stopProxy(current);
     }
-    //check that after error connection have not been put to blacklist
+    // check that after error connection have not been put to blacklist
     assertTrue(protocol.getProxy().getListener().getBlacklistKeys().size() == 0);
   }
-
 }
