@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,14 +52,12 @@
 
 package org.mariadb.jdbc.failover;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import org.junit.*;
 
-import java.sql.Connection;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.util.concurrent.TimeUnit;
-import org.junit.Test;
+import java.sql.*;
+import java.util.concurrent.*;
+
+import static org.junit.Assert.*;
 
 public abstract class BaseMonoServer extends BaseMultiHostTest {
 
@@ -68,16 +66,18 @@ public abstract class BaseMonoServer extends BaseMultiHostTest {
     try (Connection connection = getNewConnection(false)) {
       Statement stmt = connection.createStatement();
       stmt.execute("drop table  if exists auroraMultiNode" + jobId);
-      stmt.execute("create table auroraMultiNode" + jobId
-          + " (id int not null primary key auto_increment, test VARCHAR(10))");
+      stmt.execute(
+          "create table auroraMultiNode"
+              + jobId
+              + " (id int not null primary key auto_increment, test VARCHAR(10))");
       stmt.execute("drop table  if exists auroraMultiNode" + jobId);
     }
   }
 
   @Test
   public void relaunchWithoutError() throws Throwable {
-    try (Connection connection = getNewConnection("&connectTimeout=1000&socketTimeout=1000",
-        true)) {
+    try (Connection connection =
+        getNewConnection("&connectTimeout=1000&socketTimeout=1000", true)) {
       Statement st = connection.createStatement();
       int masterServerId = getServerId(connection);
       long startTime = System.currentTimeMillis();
@@ -85,8 +85,9 @@ public abstract class BaseMonoServer extends BaseMultiHostTest {
       try {
         st.execute("SELECT 1");
         if (System.currentTimeMillis() - startTime < 4 * 1000) {
-          fail("Auto-reconnection must have been done after 4000ms but was " + (
-              System.currentTimeMillis() - startTime));
+          fail(
+              "Auto-reconnection must have been done after 4000ms but was "
+                  + (System.currentTimeMillis() - startTime));
         }
       } catch (SQLException e) {
         fail("must not have thrown error");
@@ -96,12 +97,14 @@ public abstract class BaseMonoServer extends BaseMultiHostTest {
 
   @Test
   public void relaunchWithErrorWhenInTransaction() throws Throwable {
-    try (Connection connection = getNewConnection("&connectTimeout=1000&socketTimeout=1000",
-        true)) {
+    try (Connection connection =
+        getNewConnection("&connectTimeout=1000&socketTimeout=1000", true)) {
       Statement st = connection.createStatement();
       st.execute("drop table if exists baseReplicationTransaction" + jobId);
-      st.execute("create table baseReplicationTransaction" + jobId
-          + " (id int not null primary key auto_increment, test VARCHAR(10))");
+      st.execute(
+          "create table baseReplicationTransaction"
+              + jobId
+              + " (id int not null primary key auto_increment, test VARCHAR(10))");
 
       connection.setAutoCommit(false);
       st.execute("INSERT INTO baseReplicationTransaction" + jobId + "(test) VALUES ('test')");
@@ -115,7 +118,8 @@ public abstract class BaseMonoServer extends BaseMultiHostTest {
       } catch (SQLException e) {
         assertEquals(
             "error type not normal after " + (System.currentTimeMillis() - startTime) + "ms",
-            "25S03", e.getSQLState());
+            "25S03",
+            e.getSQLState());
       }
       Thread.sleep(2500);
       st.execute("drop table if exists baseReplicationTransaction" + jobId);
@@ -124,15 +128,17 @@ public abstract class BaseMonoServer extends BaseMultiHostTest {
 
   @Test
   public void failoverRelaunchedWhenSelect() throws Throwable {
-    try (Connection connection = getNewConnection(
-        "&connectTimeout=1000&socketTimeout=1000&retriesAllDown=6", true)) {
+    try (Connection connection =
+        getNewConnection("&connectTimeout=1000&socketTimeout=1000&retriesAllDown=6", true)) {
       Statement st = connection.createStatement();
 
       final int masterServerId = getServerId(connection);
       st.execute("drop table if exists selectFailover" + jobId);
-      st.execute("create table selectFailover" + jobId
-          + " (id int not null primary key , amount int not null) "
-          + "ENGINE = InnoDB");
+      st.execute(
+          "create table selectFailover"
+              + jobId
+              + " (id int not null primary key , amount int not null) "
+              + "ENGINE = InnoDB");
       stopProxy(masterServerId, 2);
       try {
         st.execute("SELECT * from selectFailover" + jobId);
@@ -152,18 +158,19 @@ public abstract class BaseMonoServer extends BaseMultiHostTest {
     }
   }
 
-
   @Test
   public void failoverRelaunchedWhenInTransaction() throws Throwable {
-    try (Connection connection = getNewConnection(
-        "&connectTimeout=1000&socketTimeout=1000&retriesAllDown=6", true)) {
+    try (Connection connection =
+        getNewConnection("&connectTimeout=1000&socketTimeout=1000&retriesAllDown=6", true)) {
       Statement st = connection.createStatement();
 
       final int masterServerId = getServerId(connection);
       st.execute("drop table if exists selectFailoverTrans" + jobId);
-      st.execute("create table selectFailoverTrans" + jobId
-          + " (id int not null primary key , amount int not null) "
-          + "ENGINE = InnoDB");
+      st.execute(
+          "create table selectFailoverTrans"
+              + jobId
+              + " (id int not null primary key , amount int not null) "
+              + "ENGINE = InnoDB");
       connection.setAutoCommit(false);
       st.execute("INSERT INTO selectFailoverTrans" + jobId + " VALUES (0,0)");
       stopProxy(masterServerId, 2);
@@ -188,8 +195,8 @@ public abstract class BaseMonoServer extends BaseMultiHostTest {
 
   @Test
   public void pingReconnectAfterRestart() throws Throwable {
-    try (Connection connection = getNewConnection(
-        "&connectTimeout=1000&socketTimeout=1000&retriesAllDown=6", true)) {
+    try (Connection connection =
+        getNewConnection("&connectTimeout=1000&socketTimeout=1000&retriesAllDown=6", true)) {
       Statement st = connection.createStatement();
       int masterServerId = getServerId(connection);
       stopProxy(masterServerId);
@@ -197,7 +204,7 @@ public abstract class BaseMonoServer extends BaseMultiHostTest {
       try {
         st.execute("SELECT 1");
       } catch (SQLException e) {
-        //normal exception
+        // normal exception
       }
       restartProxy(masterServerId);
       long restartTime = System.nanoTime();
