@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,48 +52,37 @@
 
 package org.mariadb.jdbc.failover;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import org.junit.*;
+import org.mariadb.jdbc.internal.util.constant.*;
 
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLTimeoutException;
-import java.sql.Statement;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.mariadb.jdbc.internal.util.constant.HaMode;
+import java.sql.*;
+
+import static org.junit.Assert.*;
 
 public class CancelTest extends BaseMultiHostTest {
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @BeforeClass()
   public static void beforeClass2() {
     proxyUrl = proxyGaleraUrl;
     Assume.assumeTrue(initialGaleraUrl != null);
   }
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @Before
   public void init() {
     defaultUrl = initialGaleraUrl;
     currentType = HaMode.LOADBALANCE;
   }
 
-
   @Test(expected = SQLTimeoutException.class)
   public void timeoutSleep() throws Exception {
     try (Connection connection = getNewConnection(false)) {
-      PreparedStatement stmt = connection.prepareStatement(
-          "select * from information_schema.columns as c1,"
-              + "information_schema.tables as t1, "
-              + "information_schema.tables as t2");
+      PreparedStatement stmt =
+          connection.prepareStatement(
+              "select * from information_schema.columns as c1,"
+                  + "information_schema.tables as t1, "
+                  + "information_schema.tables as t2");
       stmt.setQueryTimeout(1);
       stmt.execute();
     }
@@ -106,7 +95,6 @@ public class CancelTest extends BaseMultiHostTest {
       stmt.setQueryTimeout(1);
       stmt.execute("select sleep(0.5)");
     }
-
   }
 
   @Test
