@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,25 +52,14 @@
 
 package org.mariadb.jdbc.failover;
 
-import static org.junit.Assert.assertTrue;
+import org.junit.*;
+import org.mariadb.jdbc.*;
+import org.mariadb.jdbc.internal.util.constant.*;
 
-import java.sql.Connection;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.util.Arrays;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.mariadb.jdbc.HostAddress;
-import org.mariadb.jdbc.MariaDbConnection;
-import org.mariadb.jdbc.MariaDbPoolDataSource;
-import org.mariadb.jdbc.UrlParser;
-import org.mariadb.jdbc.internal.util.constant.HaMode;
+import java.sql.*;
+import java.util.*;
+
+import static org.junit.Assert.*;
 
 /**
  * test for galera The node must be configure with specific names : node 1 : wsrep_node_name =
@@ -79,59 +68,58 @@ import org.mariadb.jdbc.internal.util.constant.HaMode;
  */
 public class GaleraFailoverTest extends SequentialFailoverTest {
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @BeforeClass()
   public static void beforeClass2() {
     proxyUrl = proxyGaleraUrl;
     Assume.assumeTrue(initialGaleraUrl != null);
   }
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @Before
   public void init() {
     defaultUrl = initialGaleraUrl;
     currentType = HaMode.LOADBALANCE;
   }
 
-
   @Test
   public void showRep() throws Exception {
     UrlParser urlParser = UrlParser.parse(initialGaleraUrl);
     List<HostAddress> initAddresses = urlParser.getHostAddresses();
 
     for (int i = 0; i < initAddresses.size(); i++) {
-      urlParser.setHostAddresses(Arrays.asList(initAddresses.get(i)));
-      try (Connection master = MariaDbConnection.newConnection(urlParser, null)) {
+      UrlParser urlParserMono =
+          new UrlParser(
+              urlParser.getDatabase(),
+              Arrays.asList(initAddresses.get(i)),
+              urlParser.getOptions(),
+              urlParser.getHaMode());
+      try (Connection master = MariaDbConnection.newConnection(urlParserMono, null)) {
         Statement stmt = master.createStatement();
         ResultSet rs = stmt.executeQuery("show status like 'wsrep_local_state'");
         assertTrue(rs.next());
         System.out.println("host:" + initAddresses.get(i) + " status:" + rs.getString(2));
       }
     }
-
   }
 
   @Test
   public void validGaleraPing() throws Exception {
     long start = System.currentTimeMillis();
-    try (MariaDbPoolDataSource pool = new MariaDbPoolDataSource(
-        initialGaleraUrl + "&maxPoolSize=1")) {
+    try (MariaDbPoolDataSource pool =
+        new MariaDbPoolDataSource(initialGaleraUrl + "&maxPoolSize=1")) {
       try (Connection connection = pool.getConnection()) {
         Statement statement = connection.createStatement();
         statement.execute("SELECT 1 ");
       }
       Thread.sleep(2000);
-      //Galera ping must occur
+      // Galera ping must occur
       try (Connection connection = pool.getConnection()) {
         Statement statement = connection.createStatement();
         statement.execute("SELECT 1 ");
       }
     }
-    //if fail, will loop until connectTimeout = 30s
+    // if fail, will loop until connectTimeout = 30s
     assertTrue(System.currentTimeMillis() - start < 5000);
   }
 
