@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2017 MariaDB Ab.
+ * Copyright (c) 2015-2019 MariaDB Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,35 +52,26 @@
 
 package org.mariadb.jdbc.failover;
 
-import java.sql.Connection;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.util.HashMap;
-import java.util.Map;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.mariadb.jdbc.internal.util.constant.HaMode;
+import org.junit.*;
+import org.mariadb.jdbc.internal.util.constant.*;
+
+import java.sql.*;
+import java.util.*;
 
 /**
- * Exemple mvn test  -DdefaultLoadbalanceUrl=jdbc:mariadb:loadbalance//localhost:3306,localhost:3307/test?user=root.
+ * Exemple mvn test
+ * -DdefaultLoadbalanceUrl=jdbc:mariadb:loadbalance//localhost:3306,localhost:3307/test?user=root.
  */
 public class LoadBalanceFailoverTest extends BaseMultiHostTest {
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @BeforeClass()
   public static void beforeClass2() {
     proxyUrl = proxyLoadbalanceUrl;
     Assume.assumeTrue(initialLoadbalanceUrl != null);
   }
 
-  /**
-   * Initialisation.
-   */
+  /** Initialisation. */
   @Before
   public void init() {
     defaultUrl = initialLoadbalanceUrl;
@@ -98,7 +89,6 @@ public class LoadBalanceFailoverTest extends BaseMultiHostTest {
     }
   }
 
-
   @Test
   public void randomConnection() throws Throwable {
     Assume.assumeTrue(initialLoadbalanceUrl.contains("loadbalance"));
@@ -122,7 +112,6 @@ public class LoadBalanceFailoverTest extends BaseMultiHostTest {
     }
   }
 
-
   @Test
   public void testReadonly() {
     try (Connection connection = getNewConnection(false)) {
@@ -133,7 +122,7 @@ public class LoadBalanceFailoverTest extends BaseMultiHostTest {
       stmt.execute(
           "create table multinode (id int not null primary key auto_increment, test VARCHAR(10))");
     } catch (SQLException sqle) {
-      //normal exception
+      // normal exception
     }
   }
 
@@ -149,5 +138,4 @@ public class LoadBalanceFailoverTest extends BaseMultiHostTest {
       return value;
     }
   }
-
 }
